// SPDX-License-Identifier: MIT

"use strict";

window.addEventListener("DOMContentLoaded", main)

const api = "api.html";
const ext_cmds_api = "ext/commands/api.html";

function main() {
    const url = new URL(document.location.href);

    if (!url.pathname.endsWith('api.html')) return;

    /*
    * redirects_map is set by the redirects sphinx extension
    * and actually exists here at the time of loading the page
    */
    let postfix = redirects_map[url.hash.slice(1)];

    let fixed_postfix = false;

    if (!postfix) {
        if (url.pathname.endsWith(ext_cmds_api)) {
            postfix = "ext/commands/api/index.html";
        } else {
            postfix = "api/index.html";
        }
        fixed_postfix = true;
    }

    if (!fixed_postfix) {
        if (postfix.includes("disnake.ext.commands") && !url.pathname.endsWith(ext_cmds_api)) {
            postfix = "api/index.html";
        } else {
            if ((!postfix.includes("disnake.ext.commands.") && url.pathname.endsWith(ext_cmds_api))) {
                postfix = "ext/commands/api/index.html";
            }
        }
    }

    if (url.pathname.endsWith(ext_cmds_api)) {
        window.location.href = url.origin + url.pathname.slice(0, -ext_cmds_api.length) + postfix;
    } else {
        window.location.href = url.origin + url.pathname.slice(0, -api.length) + postfix;
    }
}

const redirects_map = {"disnake.abc.Snowflake": "api/abc.html#disnake.abc.Snowflake", "disnake.abc.Snowflake.id": "api/abc.html#disnake.abc.Snowflake.id", "disnake.abc.User": "api/abc.html#disnake.abc.User", "disnake.abc.User.name": "api/abc.html#disnake.abc.User.name", "disnake.abc.User.discriminator": "api/abc.html#disnake.abc.User.discriminator", "disnake.abc.User.avatar": "api/abc.html#disnake.abc.User.avatar", "disnake.abc.User.bot": "api/abc.html#disnake.abc.User.bot", "disnake.abc.User.display_name": "api/abc.html#disnake.abc.User.display_name", "disnake.abc.User.mention": "api/abc.html#disnake.abc.User.mention", "disnake.abc.PrivateChannel": "api/abc.html#disnake.abc.PrivateChannel", "disnake.abc.PrivateChannel.me": "api/abc.html#disnake.abc.PrivateChannel.me", "disnake.abc.GuildChannel": "api/abc.html#disnake.abc.GuildChannel", "disnake.abc.GuildChannel.name": "api/abc.html#disnake.abc.GuildChannel.name", "disnake.abc.GuildChannel.guild": "api/abc.html#disnake.abc.GuildChannel.guild", "disnake.abc.GuildChannel.position": "api/abc.html#disnake.abc.GuildChannel.position", "disnake.abc.GuildChannel.changed_roles": "api/abc.html#disnake.abc.GuildChannel.changed_roles", "disnake.abc.GuildChannel.mention": "api/abc.html#disnake.abc.GuildChannel.mention", "disnake.abc.GuildChannel.created_at": "api/abc.html#disnake.abc.GuildChannel.created_at", "disnake.abc.GuildChannel.overwrites_for": "api/abc.html#disnake.abc.GuildChannel.overwrites_for", "disnake.abc.GuildChannel.overwrites": "api/abc.html#disnake.abc.GuildChannel.overwrites", "disnake.abc.GuildChannel.category": "api/abc.html#disnake.abc.GuildChannel.category", "disnake.abc.GuildChannel.permissions_synced": "api/abc.html#disnake.abc.GuildChannel.permissions_synced", "disnake.abc.GuildChannel.flags": "api/abc.html#disnake.abc.GuildChannel.flags", "disnake.abc.GuildChannel.jump_url": "api/abc.html#disnake.abc.GuildChannel.jump_url", "disnake.abc.GuildChannel.permissions_for": "api/abc.html#disnake.abc.GuildChannel.permissions_for", "disnake.abc.GuildChannel.delete": "api/abc.html#disnake.abc.GuildChannel.delete", "disnake.abc.GuildChannel.set_permissions": "api/abc.html#disnake.abc.GuildChannel.set_permissions", "disnake.abc.GuildChannel.clone": "api/abc.html#disnake.abc.GuildChannel.clone", "disnake.abc.GuildChannel.move": "api/abc.html#disnake.abc.GuildChannel.move", "disnake.abc.GuildChannel.create_invite": "api/abc.html#disnake.abc.GuildChannel.create_invite", "disnake.abc.GuildChannel.invites": "api/abc.html#disnake.abc.GuildChannel.invites", "disnake.abc.Messageable": "api/abc.html#disnake.abc.Messageable", "disnake.abc.Messageable.history": "api/abc.html#disnake.abc.Messageable.history", "disnake.abc.Messageable.typing": "api/abc.html#disnake.abc.Messageable.typing", "disnake.abc.Messageable.send": "api/abc.html#disnake.abc.Messageable.send", "disnake.abc.Messageable.trigger_typing": "api/abc.html#disnake.abc.Messageable.trigger_typing", "disnake.abc.Messageable.fetch_message": "api/abc.html#disnake.abc.Messageable.fetch_message", "disnake.abc.Messageable.pins": "api/abc.html#disnake.abc.Messageable.pins", "disnake.abc.Connectable": "api/abc.html#disnake.abc.Connectable", "disnake.BaseActivity": "api/activities.html#disnake.BaseActivity", "disnake.BaseActivity.created_at": "api/activities.html#disnake.BaseActivity.created_at", "disnake.BaseActivity.end": "api/activities.html#disnake.BaseActivity.end", "disnake.BaseActivity.start": "api/activities.html#disnake.BaseActivity.start", "disnake.Activity": "api/activities.html#disnake.Activity", "disnake.Activity.application_id": "api/activities.html#disnake.Activity.application_id", "disnake.Activity.name": "api/activities.html#disnake.Activity.name", "disnake.Activity.url": "api/activities.html#disnake.Activity.url", "disnake.Activity.type": "api/activities.html#disnake.Activity.type", "disnake.Activity.state": "api/activities.html#disnake.Activity.state", "disnake.Activity.details": "api/activities.html#disnake.Activity.details", "disnake.Activity.assets": "api/activities.html#disnake.Activity.assets", "disnake.Activity.party": "api/activities.html#disnake.Activity.party", "disnake.Activity.buttons": "api/activities.html#disnake.Activity.buttons", "disnake.Activity.emoji": "api/activities.html#disnake.Activity.emoji", "disnake.Activity.large_image_url": "api/activities.html#disnake.Activity.large_image_url", "disnake.Activity.small_image_url": "api/activities.html#disnake.Activity.small_image_url", "disnake.Activity.large_image_text": "api/activities.html#disnake.Activity.large_image_text", "disnake.Activity.small_image_text": "api/activities.html#disnake.Activity.small_image_text", "disnake.Activity.created_at": "api/activities.html#disnake.Activity.created_at", "disnake.Activity.end": "api/activities.html#disnake.Activity.end", "disnake.Activity.start": "api/activities.html#disnake.Activity.start", "disnake.Spotify": "api/activities.html#disnake.Spotify", "disnake.Spotify.type": "api/activities.html#disnake.Spotify.type", "disnake.Spotify.colour": "api/activities.html#disnake.Spotify.colour", "disnake.Spotify.color": "api/activities.html#disnake.Spotify.color", "disnake.Spotify.name": "api/activities.html#disnake.Spotify.name", "disnake.Spotify.title": "api/activities.html#disnake.Spotify.title", "disnake.Spotify.artists": "api/activities.html#disnake.Spotify.artists", "disnake.Spotify.artist": "api/activities.html#disnake.Spotify.artist", "disnake.Spotify.album": "api/activities.html#disnake.Spotify.album", "disnake.Spotify.album_cover_url": "api/activities.html#disnake.Spotify.album_cover_url", "disnake.Spotify.track_id": "api/activities.html#disnake.Spotify.track_id", "disnake.Spotify.track_url": "api/activities.html#disnake.Spotify.track_url", "disnake.Spotify.duration": "api/activities.html#disnake.Spotify.duration", "disnake.Spotify.party_id": "api/activities.html#disnake.Spotify.party_id", "disnake.Spotify.created_at": "api/activities.html#disnake.Spotify.created_at", "disnake.Spotify.end": "api/activities.html#disnake.Spotify.end", "disnake.Spotify.start": "api/activities.html#disnake.Spotify.start", "disnake.Game": "api/activities.html#disnake.Game", "disnake.Game.name": "api/activities.html#disnake.Game.name", "disnake.Game.assets": "api/activities.html#disnake.Game.assets", "disnake.Game.type": "api/activities.html#disnake.Game.type", "disnake.Game.created_at": "api/activities.html#disnake.Game.created_at", "disnake.Game.end": "api/activities.html#disnake.Game.end", "disnake.Game.start": "api/activities.html#disnake.Game.start", "disnake.Streaming": "api/activities.html#disnake.Streaming", "disnake.Streaming.platform": "api/activities.html#disnake.Streaming.platform", "disnake.Streaming.name": "api/activities.html#disnake.Streaming.name", "disnake.Streaming.details": "api/activities.html#disnake.Streaming.details", "disnake.Streaming.game": "api/activities.html#disnake.Streaming.game", "disnake.Streaming.url": "api/activities.html#disnake.Streaming.url", "disnake.Streaming.assets": "api/activities.html#disnake.Streaming.assets", "disnake.Streaming.type": "api/activities.html#disnake.Streaming.type", "disnake.Streaming.twitch_name": "api/activities.html#disnake.Streaming.twitch_name", "disnake.Streaming.created_at": "api/activities.html#disnake.Streaming.created_at", "disnake.Streaming.end": "api/activities.html#disnake.Streaming.end", "disnake.Streaming.start": "api/activities.html#disnake.Streaming.start", "disnake.CustomActivity": "api/activities.html#disnake.CustomActivity", "disnake.CustomActivity.name": "api/activities.html#disnake.CustomActivity.name", "disnake.CustomActivity.emoji": "api/activities.html#disnake.CustomActivity.emoji", "disnake.CustomActivity.type": "api/activities.html#disnake.CustomActivity.type", "disnake.CustomActivity.created_at": "api/activities.html#disnake.CustomActivity.created_at", "disnake.CustomActivity.end": "api/activities.html#disnake.CustomActivity.end", "disnake.CustomActivity.start": "api/activities.html#disnake.CustomActivity.start", "disnake.ActivityType": "api/activities.html#disnake.ActivityType", "disnake.ActivityType.unknown": "api/activities.html#disnake.ActivityType.unknown", "disnake.ActivityType.playing": "api/activities.html#disnake.ActivityType.playing", "disnake.ActivityType.streaming": "api/activities.html#disnake.ActivityType.streaming", "disnake.ActivityType.listening": "api/activities.html#disnake.ActivityType.listening", "disnake.ActivityType.watching": "api/activities.html#disnake.ActivityType.watching", "disnake.ActivityType.custom": "api/activities.html#disnake.ActivityType.custom", "disnake.ActivityType.competing": "api/activities.html#disnake.ActivityType.competing", "disnake.Status": "api/activities.html#disnake.Status", "disnake.Status.online": "api/activities.html#disnake.Status.online", "disnake.Status.offline": "api/activities.html#disnake.Status.offline", "disnake.Status.idle": "api/activities.html#disnake.Status.idle", "disnake.Status.dnd": "api/activities.html#disnake.Status.dnd", "disnake.Status.do_not_disturb": "api/activities.html#disnake.Status.do_not_disturb", "disnake.Status.invisible": "api/activities.html#disnake.Status.invisible", "disnake.Status.streaming": "api/activities.html#disnake.Status.streaming", "disnake.APISlashCommand": "api/app_commands.html#disnake.APISlashCommand", "disnake.APISlashCommand.name": "api/app_commands.html#disnake.APISlashCommand.name", "disnake.APISlashCommand.name_localizations": "api/app_commands.html#disnake.APISlashCommand.name_localizations", "disnake.APISlashCommand.description": "api/app_commands.html#disnake.APISlashCommand.description", "disnake.APISlashCommand.description_localizations": "api/app_commands.html#disnake.APISlashCommand.description_localizations", "disnake.APISlashCommand.dm_permission": "api/app_commands.html#disnake.APISlashCommand.dm_permission", "disnake.APISlashCommand.id": "api/app_commands.html#disnake.APISlashCommand.id", "disnake.APISlashCommand.options": "api/app_commands.html#disnake.APISlashCommand.options", "disnake.APISlashCommand.application_id": "api/app_commands.html#disnake.APISlashCommand.application_id", "disnake.APISlashCommand.guild_id": "api/app_commands.html#disnake.APISlashCommand.guild_id", "disnake.APISlashCommand.version": "api/app_commands.html#disnake.APISlashCommand.version", "disnake.APISlashCommand.add_option": "api/app_commands.html#disnake.APISlashCommand.add_option", "disnake.APISlashCommand.default_member_permissions": "api/app_commands.html#disnake.APISlashCommand.default_member_permissions", "disnake.APIUserCommand": "api/app_commands.html#disnake.APIUserCommand", "disnake.APIUserCommand.name": "api/app_commands.html#disnake.APIUserCommand.name", "disnake.APIUserCommand.name_localizations": "api/app_commands.html#disnake.APIUserCommand.name_localizations", "disnake.APIUserCommand.dm_permission": "api/app_commands.html#disnake.APIUserCommand.dm_permission", "disnake.APIUserCommand.id": "api/app_commands.html#disnake.APIUserCommand.id", "disnake.APIUserCommand.application_id": "api/app_commands.html#disnake.APIUserCommand.application_id", "disnake.APIUserCommand.guild_id": "api/app_commands.html#disnake.APIUserCommand.guild_id", "disnake.APIUserCommand.version": "api/app_commands.html#disnake.APIUserCommand.version", "disnake.APIUserCommand.default_member_permissions": "api/app_commands.html#disnake.APIUserCommand.default_member_permissions", "disnake.APIMessageCommand": "api/app_commands.html#disnake.APIMessageCommand", "disnake.APIMessageCommand.name": "api/app_commands.html#disnake.APIMessageCommand.name", "disnake.APIMessageCommand.name_localizations": "api/app_commands.html#disnake.APIMessageCommand.name_localizations", "disnake.APIMessageCommand.dm_permission": "api/app_commands.html#disnake.APIMessageCommand.dm_permission", "disnake.APIMessageCommand.id": "api/app_commands.html#disnake.APIMessageCommand.id", "disnake.APIMessageCommand.application_id": "api/app_commands.html#disnake.APIMessageCommand.application_id", "disnake.APIMessageCommand.guild_id": "api/app_commands.html#disnake.APIMessageCommand.guild_id", "disnake.APIMessageCommand.version": "api/app_commands.html#disnake.APIMessageCommand.version", "disnake.APIMessageCommand.default_member_permissions": "api/app_commands.html#disnake.APIMessageCommand.default_member_permissions", "disnake.ApplicationCommand": "api/app_commands.html#disnake.ApplicationCommand", "disnake.ApplicationCommand.type": "api/app_commands.html#disnake.ApplicationCommand.type", "disnake.ApplicationCommand.name": "api/app_commands.html#disnake.ApplicationCommand.name", "disnake.ApplicationCommand.name_localizations": "api/app_commands.html#disnake.ApplicationCommand.name_localizations", "disnake.ApplicationCommand.dm_permission": "api/app_commands.html#disnake.ApplicationCommand.dm_permission", "disnake.ApplicationCommand.default_member_permissions": "api/app_commands.html#disnake.ApplicationCommand.default_member_permissions", "disnake.SlashCommand": "api/app_commands.html#disnake.SlashCommand", "disnake.SlashCommand.name": "api/app_commands.html#disnake.SlashCommand.name", "disnake.SlashCommand.name_localizations": "api/app_commands.html#disnake.SlashCommand.name_localizations", "disnake.SlashCommand.description": "api/app_commands.html#disnake.SlashCommand.description", "disnake.SlashCommand.description_localizations": "api/app_commands.html#disnake.SlashCommand.description_localizations", "disnake.SlashCommand.dm_permission": "api/app_commands.html#disnake.SlashCommand.dm_permission", "disnake.SlashCommand.options": "api/app_commands.html#disnake.SlashCommand.options", "disnake.SlashCommand.add_option": "api/app_commands.html#disnake.SlashCommand.add_option", "disnake.SlashCommand.default_member_permissions": "api/app_commands.html#disnake.SlashCommand.default_member_permissions", "disnake.UserCommand": "api/app_commands.html#disnake.UserCommand", "disnake.UserCommand.name": "api/app_commands.html#disnake.UserCommand.name", "disnake.UserCommand.name_localizations": "api/app_commands.html#disnake.UserCommand.name_localizations", "disnake.UserCommand.dm_permission": "api/app_commands.html#disnake.UserCommand.dm_permission", "disnake.UserCommand.default_member_permissions": "api/app_commands.html#disnake.UserCommand.default_member_permissions", "disnake.MessageCommand": "api/app_commands.html#disnake.MessageCommand", "disnake.MessageCommand.name": "api/app_commands.html#disnake.MessageCommand.name", "disnake.MessageCommand.name_localizations": "api/app_commands.html#disnake.MessageCommand.name_localizations", "disnake.MessageCommand.dm_permission": "api/app_commands.html#disnake.MessageCommand.dm_permission", "disnake.MessageCommand.default_member_permissions": "api/app_commands.html#disnake.MessageCommand.default_member_permissions", "disnake.Option": "api/app_commands.html#disnake.Option", "disnake.Option.add_choice": "api/app_commands.html#disnake.Option.add_choice", "disnake.Option.add_option": "api/app_commands.html#disnake.Option.add_option", "disnake.OptionChoice": "api/app_commands.html#disnake.OptionChoice", "disnake.ApplicationCommandPermissions": "api/app_commands.html#disnake.ApplicationCommandPermissions", "disnake.ApplicationCommandPermissions.id": "api/app_commands.html#disnake.ApplicationCommandPermissions.id", "disnake.ApplicationCommandPermissions.type": "api/app_commands.html#disnake.ApplicationCommandPermissions.type", "disnake.ApplicationCommandPermissions.permission": "api/app_commands.html#disnake.ApplicationCommandPermissions.permission", "disnake.ApplicationCommandPermissions.is_everyone": "api/app_commands.html#disnake.ApplicationCommandPermissions.is_everyone", "disnake.ApplicationCommandPermissions.is_all_channels": "api/app_commands.html#disnake.ApplicationCommandPermissions.is_all_channels", "disnake.GuildApplicationCommandPermissions": "api/app_commands.html#disnake.GuildApplicationCommandPermissions", "disnake.GuildApplicationCommandPermissions.id": "api/app_commands.html#disnake.GuildApplicationCommandPermissions.id", "disnake.GuildApplicationCommandPermissions.application_id": "api/app_commands.html#disnake.GuildApplicationCommandPermissions.application_id", "disnake.GuildApplicationCommandPermissions.guild_id": "api/app_commands.html#disnake.GuildApplicationCommandPermissions.guild_id", "disnake.GuildApplicationCommandPermissions.permissions": "api/app_commands.html#disnake.GuildApplicationCommandPermissions.permissions", "disnake.OptionType": "api/app_commands.html#disnake.OptionType", "disnake.OptionType.sub_command": "api/app_commands.html#disnake.OptionType.sub_command", "disnake.OptionType.sub_command_group": "api/app_commands.html#disnake.OptionType.sub_command_group", "disnake.OptionType.string": "api/app_commands.html#disnake.OptionType.string", "disnake.OptionType.integer": "api/app_commands.html#disnake.OptionType.integer", "disnake.OptionType.boolean": "api/app_commands.html#disnake.OptionType.boolean", "disnake.OptionType.user": "api/app_commands.html#disnake.OptionType.user", "disnake.OptionType.channel": "api/app_commands.html#disnake.OptionType.channel", "disnake.OptionType.role": "api/app_commands.html#disnake.OptionType.role", "disnake.OptionType.mentionable": "api/app_commands.html#disnake.OptionType.mentionable", "disnake.OptionType.number": "api/app_commands.html#disnake.OptionType.number", "disnake.OptionType.attachment": "api/app_commands.html#disnake.OptionType.attachment", "disnake.ApplicationCommandType": "api/app_commands.html#disnake.ApplicationCommandType", "disnake.ApplicationCommandType.chat_input": "api/app_commands.html#disnake.ApplicationCommandType.chat_input", "disnake.ApplicationCommandType.user": "api/app_commands.html#disnake.ApplicationCommandType.user", "disnake.ApplicationCommandType.message": "api/app_commands.html#disnake.ApplicationCommandType.message", "disnake.ApplicationCommandPermissionType": "api/app_commands.html#disnake.ApplicationCommandPermissionType", "disnake.ApplicationCommandPermissionType.role": "api/app_commands.html#disnake.ApplicationCommandPermissionType.role", "disnake.ApplicationCommandPermissionType.user": "api/app_commands.html#disnake.ApplicationCommandPermissionType.user", "disnake.ApplicationCommandPermissionType.channel": "api/app_commands.html#disnake.ApplicationCommandPermissionType.channel", "disnake.AppInfo": "api/app_info.html#disnake.AppInfo", "disnake.AppInfo.id": "api/app_info.html#disnake.AppInfo.id", "disnake.AppInfo.name": "api/app_info.html#disnake.AppInfo.name", "disnake.AppInfo.owner": "api/app_info.html#disnake.AppInfo.owner", "disnake.AppInfo.team": "api/app_info.html#disnake.AppInfo.team", "disnake.AppInfo.description": "api/app_info.html#disnake.AppInfo.description", "disnake.AppInfo.bot_public": "api/app_info.html#disnake.AppInfo.bot_public", "disnake.AppInfo.bot_require_code_grant": "api/app_info.html#disnake.AppInfo.bot_require_code_grant", "disnake.AppInfo.rpc_origins": "api/app_info.html#disnake.AppInfo.rpc_origins", "disnake.AppInfo.verify_key": "api/app_info.html#disnake.AppInfo.verify_key", "disnake.AppInfo.guild_id": "api/app_info.html#disnake.AppInfo.guild_id", "disnake.AppInfo.primary_sku_id": "api/app_info.html#disnake.AppInfo.primary_sku_id", "disnake.AppInfo.slug": "api/app_info.html#disnake.AppInfo.slug", "disnake.AppInfo.terms_of_service_url": "api/app_info.html#disnake.AppInfo.terms_of_service_url", "disnake.AppInfo.privacy_policy_url": "api/app_info.html#disnake.AppInfo.privacy_policy_url", "disnake.AppInfo.flags": "api/app_info.html#disnake.AppInfo.flags", "disnake.AppInfo.tags": "api/app_info.html#disnake.AppInfo.tags", "disnake.AppInfo.install_params": "api/app_info.html#disnake.AppInfo.install_params", "disnake.AppInfo.custom_install_url": "api/app_info.html#disnake.AppInfo.custom_install_url", "disnake.AppInfo.icon": "api/app_info.html#disnake.AppInfo.icon", "disnake.AppInfo.cover_image": "api/app_info.html#disnake.AppInfo.cover_image", "disnake.AppInfo.guild": "api/app_info.html#disnake.AppInfo.guild", "disnake.AppInfo.summary": "api/app_info.html#disnake.AppInfo.summary", "disnake.PartialAppInfo": "api/app_info.html#disnake.PartialAppInfo", "disnake.PartialAppInfo.id": "api/app_info.html#disnake.PartialAppInfo.id", "disnake.PartialAppInfo.name": "api/app_info.html#disnake.PartialAppInfo.name", "disnake.PartialAppInfo.description": "api/app_info.html#disnake.PartialAppInfo.description", "disnake.PartialAppInfo.rpc_origins": "api/app_info.html#disnake.PartialAppInfo.rpc_origins", "disnake.PartialAppInfo.verify_key": "api/app_info.html#disnake.PartialAppInfo.verify_key", "disnake.PartialAppInfo.terms_of_service_url": "api/app_info.html#disnake.PartialAppInfo.terms_of_service_url", "disnake.PartialAppInfo.privacy_policy_url": "api/app_info.html#disnake.PartialAppInfo.privacy_policy_url", "disnake.PartialAppInfo.icon": "api/app_info.html#disnake.PartialAppInfo.icon", "disnake.PartialAppInfo.summary": "api/app_info.html#disnake.PartialAppInfo.summary", "disnake.Team": "api/app_info.html#disnake.Team", "disnake.Team.id": "api/app_info.html#disnake.Team.id", "disnake.Team.name": "api/app_info.html#disnake.Team.name", "disnake.Team.owner_id": "api/app_info.html#disnake.Team.owner_id", "disnake.Team.members": "api/app_info.html#disnake.Team.members", "disnake.Team.icon": "api/app_info.html#disnake.Team.icon", "disnake.Team.owner": "api/app_info.html#disnake.Team.owner", "disnake.TeamMember": "api/app_info.html#disnake.TeamMember", "disnake.TeamMember.name": "api/app_info.html#disnake.TeamMember.name", "disnake.TeamMember.id": "api/app_info.html#disnake.TeamMember.id", "disnake.TeamMember.discriminator": "api/app_info.html#disnake.TeamMember.discriminator", "disnake.TeamMember.avatar": "api/app_info.html#disnake.TeamMember.avatar", "disnake.TeamMember.bot": "api/app_info.html#disnake.TeamMember.bot", "disnake.TeamMember.team": "api/app_info.html#disnake.TeamMember.team", "disnake.TeamMember.membership_state": "api/app_info.html#disnake.TeamMember.membership_state", "disnake.ApplicationFlags": "api/app_info.html#disnake.ApplicationFlags", "disnake.ApplicationFlags.value": "api/app_info.html#disnake.ApplicationFlags.value", "disnake.ApplicationFlags.gateway_presence": "api/app_info.html#disnake.ApplicationFlags.gateway_presence", "disnake.ApplicationFlags.gateway_presence_limited": "api/app_info.html#disnake.ApplicationFlags.gateway_presence_limited", "disnake.ApplicationFlags.gateway_guild_members": "api/app_info.html#disnake.ApplicationFlags.gateway_guild_members", "disnake.ApplicationFlags.gateway_guild_members_limited": "api/app_info.html#disnake.ApplicationFlags.gateway_guild_members_limited", "disnake.ApplicationFlags.verification_pending_guild_limit": "api/app_info.html#disnake.ApplicationFlags.verification_pending_guild_limit", "disnake.ApplicationFlags.embedded": "api/app_info.html#disnake.ApplicationFlags.embedded", "disnake.ApplicationFlags.gateway_message_content": "api/app_info.html#disnake.ApplicationFlags.gateway_message_content", "disnake.ApplicationFlags.gateway_message_content_limited": "api/app_info.html#disnake.ApplicationFlags.gateway_message_content_limited", "disnake.ApplicationFlags.application_command_badge": "api/app_info.html#disnake.ApplicationFlags.application_command_badge", "disnake.InstallParams": "api/app_info.html#disnake.InstallParams", "disnake.InstallParams.scopes": "api/app_info.html#disnake.InstallParams.scopes", "disnake.InstallParams.permissions": "api/app_info.html#disnake.InstallParams.permissions", "disnake.InstallParams.to_url": "api/app_info.html#disnake.InstallParams.to_url", "disnake.TeamMembershipState": "api/app_info.html#disnake.TeamMembershipState", "disnake.TeamMembershipState.invited": "api/app_info.html#disnake.TeamMembershipState.invited", "disnake.TeamMembershipState.accepted": "api/app_info.html#disnake.TeamMembershipState.accepted", "disnake.AuditLogEntry": "api/audit_logs.html#disnake.AuditLogEntry", "disnake.AuditLogEntry.action": "api/audit_logs.html#disnake.AuditLogEntry.action", "disnake.AuditLogEntry.user": "api/audit_logs.html#disnake.AuditLogEntry.user", "disnake.AuditLogEntry.id": "api/audit_logs.html#disnake.AuditLogEntry.id", "disnake.AuditLogEntry.target": "api/audit_logs.html#disnake.AuditLogEntry.target", "disnake.AuditLogEntry.extra": "api/audit_logs.html#disnake.AuditLogEntry.extra", "disnake.AuditLogEntry.reason": "api/audit_logs.html#disnake.AuditLogEntry.reason", "disnake.AuditLogEntry.created_at": "api/audit_logs.html#disnake.AuditLogEntry.created_at", "disnake.AuditLogEntry.category": "api/audit_logs.html#disnake.AuditLogEntry.category", "disnake.AuditLogEntry.changes": "api/audit_logs.html#disnake.AuditLogEntry.changes", "disnake.AuditLogEntry.before": "api/audit_logs.html#disnake.AuditLogEntry.before", "disnake.AuditLogEntry.after": "api/audit_logs.html#disnake.AuditLogEntry.after", "disnake.AuditLogChanges": "api/audit_logs.html#disnake.AuditLogChanges", "disnake.AuditLogChanges.before": "api/audit_logs.html#disnake.AuditLogChanges.before", "disnake.AuditLogChanges.after": "api/audit_logs.html#disnake.AuditLogChanges.after", "disnake.AuditLogDiff": "api/audit_logs.html#disnake.AuditLogDiff", "disnake.AuditLogDiff.name": "api/audit_logs.html#disnake.AuditLogDiff.name", "disnake.AuditLogDiff.icon": "api/audit_logs.html#disnake.AuditLogDiff.icon", "disnake.AuditLogDiff.splash": "api/audit_logs.html#disnake.AuditLogDiff.splash", "disnake.AuditLogDiff.discovery_splash": "api/audit_logs.html#disnake.AuditLogDiff.discovery_splash", "disnake.AuditLogDiff.banner": "api/audit_logs.html#disnake.AuditLogDiff.banner", "disnake.AuditLogDiff.owner": "api/audit_logs.html#disnake.AuditLogDiff.owner", "disnake.AuditLogDiff.region": "api/audit_logs.html#disnake.AuditLogDiff.region", "disnake.AuditLogDiff.afk_channel": "api/audit_logs.html#disnake.AuditLogDiff.afk_channel", "disnake.AuditLogDiff.system_channel": "api/audit_logs.html#disnake.AuditLogDiff.system_channel", "disnake.AuditLogDiff.rules_channel": "api/audit_logs.html#disnake.AuditLogDiff.rules_channel", "disnake.AuditLogDiff.public_updates_channel": "api/audit_logs.html#disnake.AuditLogDiff.public_updates_channel", "disnake.AuditLogDiff.afk_timeout": "api/audit_logs.html#disnake.AuditLogDiff.afk_timeout", "disnake.AuditLogDiff.mfa_level": "api/audit_logs.html#disnake.AuditLogDiff.mfa_level", "disnake.AuditLogDiff.widget_enabled": "api/audit_logs.html#disnake.AuditLogDiff.widget_enabled", "disnake.AuditLogDiff.widget_channel": "api/audit_logs.html#disnake.AuditLogDiff.widget_channel", "disnake.AuditLogDiff.verification_level": "api/audit_logs.html#disnake.AuditLogDiff.verification_level", "disnake.AuditLogDiff.premium_progress_bar_enabled": "api/audit_logs.html#disnake.AuditLogDiff.premium_progress_bar_enabled", "disnake.AuditLogDiff.default_notifications": "api/audit_logs.html#disnake.AuditLogDiff.default_notifications", "disnake.AuditLogDiff.explicit_content_filter": "api/audit_logs.html#disnake.AuditLogDiff.explicit_content_filter", "disnake.AuditLogDiff.default_message_notifications": "api/audit_logs.html#disnake.AuditLogDiff.default_message_notifications", "disnake.AuditLogDiff.vanity_url_code": "api/audit_logs.html#disnake.AuditLogDiff.vanity_url_code", "disnake.AuditLogDiff.preferred_locale": "api/audit_logs.html#disnake.AuditLogDiff.preferred_locale", "disnake.AuditLogDiff.position": "api/audit_logs.html#disnake.AuditLogDiff.position", "disnake.AuditLogDiff.type": "api/audit_logs.html#disnake.AuditLogDiff.type", "disnake.AuditLogDiff.topic": "api/audit_logs.html#disnake.AuditLogDiff.topic", "disnake.AuditLogDiff.bitrate": "api/audit_logs.html#disnake.AuditLogDiff.bitrate", "disnake.AuditLogDiff.overwrites": "api/audit_logs.html#disnake.AuditLogDiff.overwrites", "disnake.AuditLogDiff.privacy_level": "api/audit_logs.html#disnake.AuditLogDiff.privacy_level", "disnake.AuditLogDiff.roles": "api/audit_logs.html#disnake.AuditLogDiff.roles", "disnake.AuditLogDiff.nick": "api/audit_logs.html#disnake.AuditLogDiff.nick", "disnake.AuditLogDiff.deaf": "api/audit_logs.html#disnake.AuditLogDiff.deaf", "disnake.AuditLogDiff.mute": "api/audit_logs.html#disnake.AuditLogDiff.mute", "disnake.AuditLogDiff.permissions": "api/audit_logs.html#disnake.AuditLogDiff.permissions", "disnake.AuditLogDiff.colour": "api/audit_logs.html#disnake.AuditLogDiff.colour", "disnake.AuditLogDiff.color": "api/audit_logs.html#disnake.AuditLogDiff.color", "disnake.AuditLogDiff.hoist": "api/audit_logs.html#disnake.AuditLogDiff.hoist", "disnake.AuditLogDiff.mentionable": "api/audit_logs.html#disnake.AuditLogDiff.mentionable", "disnake.AuditLogDiff.code": "api/audit_logs.html#disnake.AuditLogDiff.code", "disnake.AuditLogDiff.channel": "api/audit_logs.html#disnake.AuditLogDiff.channel", "disnake.AuditLogDiff.inviter": "api/audit_logs.html#disnake.AuditLogDiff.inviter", "disnake.AuditLogDiff.max_uses": "api/audit_logs.html#disnake.AuditLogDiff.max_uses", "disnake.AuditLogDiff.uses": "api/audit_logs.html#disnake.AuditLogDiff.uses", "disnake.AuditLogDiff.max_age": "api/audit_logs.html#disnake.AuditLogDiff.max_age", "disnake.AuditLogDiff.temporary": "api/audit_logs.html#disnake.AuditLogDiff.temporary", "disnake.AuditLogDiff.allow": "api/audit_logs.html#disnake.AuditLogDiff.allow", "disnake.AuditLogDiff.deny": "api/audit_logs.html#disnake.AuditLogDiff.deny", "disnake.AuditLogDiff.id": "api/audit_logs.html#disnake.AuditLogDiff.id", "disnake.AuditLogDiff.avatar": "api/audit_logs.html#disnake.AuditLogDiff.avatar", "disnake.AuditLogDiff.slowmode_delay": "api/audit_logs.html#disnake.AuditLogDiff.slowmode_delay", "disnake.AuditLogDiff.default_thread_slowmode_delay": "api/audit_logs.html#disnake.AuditLogDiff.default_thread_slowmode_delay", "disnake.AuditLogDiff.rtc_region": "api/audit_logs.html#disnake.AuditLogDiff.rtc_region", "disnake.AuditLogDiff.video_quality_mode": "api/audit_logs.html#disnake.AuditLogDiff.video_quality_mode", "disnake.AuditLogDiff.user_limit": "api/audit_logs.html#disnake.AuditLogDiff.user_limit", "disnake.AuditLogDiff.nsfw": "api/audit_logs.html#disnake.AuditLogDiff.nsfw", "disnake.AuditLogDiff.format_type": "api/audit_logs.html#disnake.AuditLogDiff.format_type", "disnake.AuditLogDiff.emoji": "api/audit_logs.html#disnake.AuditLogDiff.emoji", "disnake.AuditLogDiff.description": "api/audit_logs.html#disnake.AuditLogDiff.description", "disnake.AuditLogDiff.available": "api/audit_logs.html#disnake.AuditLogDiff.available", "disnake.AuditLogDiff.archived": "api/audit_logs.html#disnake.AuditLogDiff.archived", "disnake.AuditLogDiff.locked": "api/audit_logs.html#disnake.AuditLogDiff.locked", "disnake.AuditLogDiff.auto_archive_duration": "api/audit_logs.html#disnake.AuditLogDiff.auto_archive_duration", "disnake.AuditLogDiff.default_auto_archive_duration": "api/audit_logs.html#disnake.AuditLogDiff.default_auto_archive_duration", "disnake.AuditLogDiff.invitable": "api/audit_logs.html#disnake.AuditLogDiff.invitable", "disnake.AuditLogDiff.timeout": "api/audit_logs.html#disnake.AuditLogDiff.timeout", "disnake.AuditLogDiff.entity_type": "api/audit_logs.html#disnake.AuditLogDiff.entity_type", "disnake.AuditLogDiff.location": "api/audit_logs.html#disnake.AuditLogDiff.location", "disnake.AuditLogDiff.status": "api/audit_logs.html#disnake.AuditLogDiff.status", "disnake.AuditLogDiff.image": "api/audit_logs.html#disnake.AuditLogDiff.image", "disnake.AuditLogDiff.command_permissions": "api/audit_logs.html#disnake.AuditLogDiff.command_permissions", "disnake.AuditLogDiff.application_id": "api/audit_logs.html#disnake.AuditLogDiff.application_id", "disnake.AuditLogDiff.flags": "api/audit_logs.html#disnake.AuditLogDiff.flags", "disnake.AuditLogDiff.system_channel_flags": "api/audit_logs.html#disnake.AuditLogDiff.system_channel_flags", "disnake.AuditLogDiff.enabled": "api/audit_logs.html#disnake.AuditLogDiff.enabled", "disnake.AuditLogDiff.trigger_type": "api/audit_logs.html#disnake.AuditLogDiff.trigger_type", "disnake.AuditLogDiff.event_type": "api/audit_logs.html#disnake.AuditLogDiff.event_type", "disnake.AuditLogDiff.actions": "api/audit_logs.html#disnake.AuditLogDiff.actions", "disnake.AuditLogDiff.trigger_metadata": "api/audit_logs.html#disnake.AuditLogDiff.trigger_metadata", "disnake.AuditLogDiff.exempt_roles": "api/audit_logs.html#disnake.AuditLogDiff.exempt_roles", "disnake.AuditLogDiff.exempt_channels": "api/audit_logs.html#disnake.AuditLogDiff.exempt_channels", "disnake.AuditLogDiff.applied_tags": "api/audit_logs.html#disnake.AuditLogDiff.applied_tags", "disnake.AuditLogDiff.available_tags": "api/audit_logs.html#disnake.AuditLogDiff.available_tags", "disnake.AuditLogDiff.default_reaction": "api/audit_logs.html#disnake.AuditLogDiff.default_reaction", "disnake.AuditLogDiff.default_sort_order": "api/audit_logs.html#disnake.AuditLogDiff.default_sort_order", "disnake.AuditLogAction": "api/audit_logs.html#disnake.AuditLogAction", "disnake.AuditLogAction.guild_update": "api/audit_logs.html#disnake.AuditLogAction.guild_update", "disnake.AuditLogAction.channel_create": "api/audit_logs.html#disnake.AuditLogAction.channel_create", "disnake.AuditLogAction.channel_update": "api/audit_logs.html#disnake.AuditLogAction.channel_update", "disnake.AuditLogAction.channel_delete": "api/audit_logs.html#disnake.AuditLogAction.channel_delete", "disnake.AuditLogAction.overwrite_create": "api/audit_logs.html#disnake.AuditLogAction.overwrite_create", "disnake.AuditLogAction.overwrite_update": "api/audit_logs.html#disnake.AuditLogAction.overwrite_update", "disnake.AuditLogAction.overwrite_delete": "api/audit_logs.html#disnake.AuditLogAction.overwrite_delete", "disnake.AuditLogAction.kick": "api/audit_logs.html#disnake.AuditLogAction.kick", "disnake.AuditLogAction.member_prune": "api/audit_logs.html#disnake.AuditLogAction.member_prune", "disnake.AuditLogAction.ban": "api/audit_logs.html#disnake.AuditLogAction.ban", "disnake.AuditLogAction.unban": "api/audit_logs.html#disnake.AuditLogAction.unban", "disnake.AuditLogAction.member_update": "api/audit_logs.html#disnake.AuditLogAction.member_update", "disnake.AuditLogAction.member_role_update": "api/audit_logs.html#disnake.AuditLogAction.member_role_update", "disnake.AuditLogAction.member_move": "api/audit_logs.html#disnake.AuditLogAction.member_move", "disnake.AuditLogAction.member_disconnect": "api/audit_logs.html#disnake.AuditLogAction.member_disconnect", "disnake.AuditLogAction.bot_add": "api/audit_logs.html#disnake.AuditLogAction.bot_add", "disnake.AuditLogAction.role_create": "api/audit_logs.html#disnake.AuditLogAction.role_create", "disnake.AuditLogAction.role_update": "api/audit_logs.html#disnake.AuditLogAction.role_update", "disnake.AuditLogAction.role_delete": "api/audit_logs.html#disnake.AuditLogAction.role_delete", "disnake.AuditLogAction.invite_create": "api/audit_logs.html#disnake.AuditLogAction.invite_create", "disnake.AuditLogAction.invite_update": "api/audit_logs.html#disnake.AuditLogAction.invite_update", "disnake.AuditLogAction.invite_delete": "api/audit_logs.html#disnake.AuditLogAction.invite_delete", "disnake.AuditLogAction.webhook_create": "api/audit_logs.html#disnake.AuditLogAction.webhook_create", "disnake.AuditLogAction.webhook_update": "api/audit_logs.html#disnake.AuditLogAction.webhook_update", "disnake.AuditLogAction.webhook_delete": "api/audit_logs.html#disnake.AuditLogAction.webhook_delete", "disnake.AuditLogAction.emoji_create": "api/audit_logs.html#disnake.AuditLogAction.emoji_create", "disnake.AuditLogAction.emoji_update": "api/audit_logs.html#disnake.AuditLogAction.emoji_update", "disnake.AuditLogAction.emoji_delete": "api/audit_logs.html#disnake.AuditLogAction.emoji_delete", "disnake.AuditLogAction.message_delete": "api/audit_logs.html#disnake.AuditLogAction.message_delete", "disnake.AuditLogAction.message_bulk_delete": "api/audit_logs.html#disnake.AuditLogAction.message_bulk_delete", "disnake.AuditLogAction.message_pin": "api/audit_logs.html#disnake.AuditLogAction.message_pin", "disnake.AuditLogAction.message_unpin": "api/audit_logs.html#disnake.AuditLogAction.message_unpin", "disnake.AuditLogAction.integration_create": "api/audit_logs.html#disnake.AuditLogAction.integration_create", "disnake.AuditLogAction.integration_update": "api/audit_logs.html#disnake.AuditLogAction.integration_update", "disnake.AuditLogAction.integration_delete": "api/audit_logs.html#disnake.AuditLogAction.integration_delete", "disnake.AuditLogAction.guild_scheduled_event_create": "api/audit_logs.html#disnake.AuditLogAction.guild_scheduled_event_create", "disnake.AuditLogAction.guild_scheduled_event_update": "api/audit_logs.html#disnake.AuditLogAction.guild_scheduled_event_update", "disnake.AuditLogAction.guild_scheduled_event_delete": "api/audit_logs.html#disnake.AuditLogAction.guild_scheduled_event_delete", "disnake.AuditLogAction.stage_instance_create": "api/audit_logs.html#disnake.AuditLogAction.stage_instance_create", "disnake.AuditLogAction.stage_instance_update": "api/audit_logs.html#disnake.AuditLogAction.stage_instance_update", "disnake.AuditLogAction.stage_instance_delete": "api/audit_logs.html#disnake.AuditLogAction.stage_instance_delete", "disnake.AuditLogAction.sticker_create": "api/audit_logs.html#disnake.AuditLogAction.sticker_create", "disnake.AuditLogAction.sticker_update": "api/audit_logs.html#disnake.AuditLogAction.sticker_update", "disnake.AuditLogAction.sticker_delete": "api/audit_logs.html#disnake.AuditLogAction.sticker_delete", "disnake.AuditLogAction.thread_create": "api/audit_logs.html#disnake.AuditLogAction.thread_create", "disnake.AuditLogAction.thread_update": "api/audit_logs.html#disnake.AuditLogAction.thread_update", "disnake.AuditLogAction.thread_delete": "api/audit_logs.html#disnake.AuditLogAction.thread_delete", "disnake.AuditLogAction.application_command_permission_update": "api/audit_logs.html#disnake.AuditLogAction.application_command_permission_update", "disnake.AuditLogAction.automod_rule_create": "api/audit_logs.html#disnake.AuditLogAction.automod_rule_create", "disnake.AuditLogAction.automod_rule_update": "api/audit_logs.html#disnake.AuditLogAction.automod_rule_update", "disnake.AuditLogAction.automod_rule_delete": "api/audit_logs.html#disnake.AuditLogAction.automod_rule_delete", "disnake.AuditLogAction.automod_block_message": "api/audit_logs.html#disnake.AuditLogAction.automod_block_message", "disnake.AuditLogAction.automod_send_alert_message": "api/audit_logs.html#disnake.AuditLogAction.automod_send_alert_message", "disnake.AuditLogAction.automod_timeout": "api/audit_logs.html#disnake.AuditLogAction.automod_timeout", "disnake.AuditLogActionCategory": "api/audit_logs.html#disnake.AuditLogActionCategory", "disnake.AuditLogActionCategory.create": "api/audit_logs.html#disnake.AuditLogActionCategory.create", "disnake.AuditLogActionCategory.delete": "api/audit_logs.html#disnake.AuditLogActionCategory.delete", "disnake.AuditLogActionCategory.update": "api/audit_logs.html#disnake.AuditLogActionCategory.update", "disnake.AutoModRule": "api/automod.html#disnake.AutoModRule", "disnake.AutoModRule.id": "api/automod.html#disnake.AutoModRule.id", "disnake.AutoModRule.name": "api/automod.html#disnake.AutoModRule.name", "disnake.AutoModRule.enabled": "api/automod.html#disnake.AutoModRule.enabled", "disnake.AutoModRule.guild": "api/automod.html#disnake.AutoModRule.guild", "disnake.AutoModRule.creator_id": "api/automod.html#disnake.AutoModRule.creator_id", "disnake.AutoModRule.event_type": "api/automod.html#disnake.AutoModRule.event_type", "disnake.AutoModRule.trigger_type": "api/automod.html#disnake.AutoModRule.trigger_type", "disnake.AutoModRule.trigger_metadata": "api/automod.html#disnake.AutoModRule.trigger_metadata", "disnake.AutoModRule.exempt_role_ids": "api/automod.html#disnake.AutoModRule.exempt_role_ids", "disnake.AutoModRule.exempt_channel_ids": "api/automod.html#disnake.AutoModRule.exempt_channel_ids", "disnake.AutoModRule.actions": "api/automod.html#disnake.AutoModRule.actions", "disnake.AutoModRule.creator": "api/automod.html#disnake.AutoModRule.creator", "disnake.AutoModRule.exempt_roles": "api/automod.html#disnake.AutoModRule.exempt_roles", "disnake.AutoModRule.exempt_channels": "api/automod.html#disnake.AutoModRule.exempt_channels", "disnake.AutoModRule.edit": "api/automod.html#disnake.AutoModRule.edit", "disnake.AutoModRule.delete": "api/automod.html#disnake.AutoModRule.delete", "disnake.AutoModActionExecution": "api/automod.html#disnake.AutoModActionExecution", "disnake.AutoModActionExecution.action": "api/automod.html#disnake.AutoModActionExecution.action", "disnake.AutoModActionExecution.guild": "api/automod.html#disnake.AutoModActionExecution.guild", "disnake.AutoModActionExecution.rule_id": "api/automod.html#disnake.AutoModActionExecution.rule_id", "disnake.AutoModActionExecution.rule_trigger_type": "api/automod.html#disnake.AutoModActionExecution.rule_trigger_type", "disnake.AutoModActionExecution.user_id": "api/automod.html#disnake.AutoModActionExecution.user_id", "disnake.AutoModActionExecution.channel_id": "api/automod.html#disnake.AutoModActionExecution.channel_id", "disnake.AutoModActionExecution.message_id": "api/automod.html#disnake.AutoModActionExecution.message_id", "disnake.AutoModActionExecution.alert_message_id": "api/automod.html#disnake.AutoModActionExecution.alert_message_id", "disnake.AutoModActionExecution.content": "api/automod.html#disnake.AutoModActionExecution.content", "disnake.AutoModActionExecution.matched_keyword": "api/automod.html#disnake.AutoModActionExecution.matched_keyword", "disnake.AutoModActionExecution.matched_content": "api/automod.html#disnake.AutoModActionExecution.matched_content", "disnake.AutoModActionExecution.user": "api/automod.html#disnake.AutoModActionExecution.user", "disnake.AutoModActionExecution.channel": "api/automod.html#disnake.AutoModActionExecution.channel", "disnake.AutoModActionExecution.message": "api/automod.html#disnake.AutoModActionExecution.message", "disnake.AutoModActionExecution.alert_message": "api/automod.html#disnake.AutoModActionExecution.alert_message", "disnake.AutoModKeywordPresets": "api/automod.html#disnake.AutoModKeywordPresets", "disnake.AutoModKeywordPresets.values": "api/automod.html#disnake.AutoModKeywordPresets.values", "disnake.AutoModKeywordPresets.all": "api/automod.html#disnake.AutoModKeywordPresets.all", "disnake.AutoModKeywordPresets.none": "api/automod.html#disnake.AutoModKeywordPresets.none", "disnake.AutoModKeywordPresets.profanity": "api/automod.html#disnake.AutoModKeywordPresets.profanity", "disnake.AutoModKeywordPresets.sexual_content": "api/automod.html#disnake.AutoModKeywordPresets.sexual_content", "disnake.AutoModKeywordPresets.slurs": "api/automod.html#disnake.AutoModKeywordPresets.slurs", "disnake.AutoModTriggerMetadata": "api/automod.html#disnake.AutoModTriggerMetadata", "disnake.AutoModTriggerMetadata.keyword_filter": "api/automod.html#disnake.AutoModTriggerMetadata.keyword_filter", "disnake.AutoModTriggerMetadata.presets": "api/automod.html#disnake.AutoModTriggerMetadata.presets", "disnake.AutoModTriggerMetadata.allow_list": "api/automod.html#disnake.AutoModTriggerMetadata.allow_list", "disnake.AutoModTriggerMetadata.mention_total_limit": "api/automod.html#disnake.AutoModTriggerMetadata.mention_total_limit", "disnake.AutoModTriggerMetadata.with_changes": "api/automod.html#disnake.AutoModTriggerMetadata.with_changes", "disnake.AutoModAction": "api/automod.html#disnake.AutoModAction", "disnake.AutoModAction.type": "api/automod.html#disnake.AutoModAction.type", "disnake.AutoModBlockMessageAction": "api/automod.html#disnake.AutoModBlockMessageAction", "disnake.AutoModBlockMessageAction.type": "api/automod.html#disnake.AutoModBlockMessageAction.type", "disnake.AutoModSendAlertAction": "api/automod.html#disnake.AutoModSendAlertAction", "disnake.AutoModSendAlertAction.type": "api/automod.html#disnake.AutoModSendAlertAction.type", "disnake.AutoModSendAlertAction.channel_id": "api/automod.html#disnake.AutoModSendAlertAction.channel_id", "disnake.AutoModTimeoutAction": "api/automod.html#disnake.AutoModTimeoutAction", "disnake.AutoModTimeoutAction.type": "api/automod.html#disnake.AutoModTimeoutAction.type", "disnake.AutoModTimeoutAction.duration": "api/automod.html#disnake.AutoModTimeoutAction.duration", "disnake.AutoModActionType": "api/automod.html#disnake.AutoModActionType", "disnake.AutoModActionType.block_message": "api/automod.html#disnake.AutoModActionType.block_message", "disnake.AutoModActionType.send_alert_message": "api/automod.html#disnake.AutoModActionType.send_alert_message", "disnake.AutoModActionType.timeout": "api/automod.html#disnake.AutoModActionType.timeout", "disnake.AutoModEventType": "api/automod.html#disnake.AutoModEventType", "disnake.AutoModEventType.message_send": "api/automod.html#disnake.AutoModEventType.message_send", "disnake.AutoModTriggerType": "api/automod.html#disnake.AutoModTriggerType", "disnake.AutoModTriggerType.keyword": "api/automod.html#disnake.AutoModTriggerType.keyword", "disnake.AutoModTriggerType.harmful_link": "api/automod.html#disnake.AutoModTriggerType.harmful_link", "disnake.AutoModTriggerType.spam": "api/automod.html#disnake.AutoModTriggerType.spam", "disnake.AutoModTriggerType.keyword_preset": "api/automod.html#disnake.AutoModTriggerType.keyword_preset", "disnake.AutoModTriggerType.mention_spam": "api/automod.html#disnake.AutoModTriggerType.mention_spam", "disnake.TextChannel": "api/channels.html#disnake.TextChannel", "disnake.TextChannel.name": "api/channels.html#disnake.TextChannel.name", "disnake.TextChannel.guild": "api/channels.html#disnake.TextChannel.guild", "disnake.TextChannel.id": "api/channels.html#disnake.TextChannel.id", "disnake.TextChannel.category_id": "api/channels.html#disnake.TextChannel.category_id", "disnake.TextChannel.topic": "api/channels.html#disnake.TextChannel.topic", "disnake.TextChannel.position": "api/channels.html#disnake.TextChannel.position", "disnake.TextChannel.last_message_id": "api/channels.html#disnake.TextChannel.last_message_id", "disnake.TextChannel.slowmode_delay": "api/channels.html#disnake.TextChannel.slowmode_delay", "disnake.TextChannel.nsfw": "api/channels.html#disnake.TextChannel.nsfw", "disnake.TextChannel.default_auto_archive_duration": "api/channels.html#disnake.TextChannel.default_auto_archive_duration", "disnake.TextChannel.last_pin_timestamp": "api/channels.html#disnake.TextChannel.last_pin_timestamp", "disnake.TextChannel.history": "api/channels.html#disnake.TextChannel.history", "disnake.TextChannel.typing": "api/channels.html#disnake.TextChannel.typing", "disnake.TextChannel.type": "api/channels.html#disnake.TextChannel.type", "disnake.TextChannel.permissions_for": "api/channels.html#disnake.TextChannel.permissions_for", "disnake.TextChannel.members": "api/channels.html#disnake.TextChannel.members", "disnake.TextChannel.threads": "api/channels.html#disnake.TextChannel.threads", "disnake.TextChannel.is_nsfw": "api/channels.html#disnake.TextChannel.is_nsfw", "disnake.TextChannel.is_news": "api/channels.html#disnake.TextChannel.is_news", "disnake.TextChannel.last_message": "api/channels.html#disnake.TextChannel.last_message", "disnake.TextChannel.edit": "api/channels.html#disnake.TextChannel.edit", "disnake.TextChannel.clone": "api/channels.html#disnake.TextChannel.clone", "disnake.TextChannel.delete_messages": "api/channels.html#disnake.TextChannel.delete_messages", "disnake.TextChannel.purge": "api/channels.html#disnake.TextChannel.purge", "disnake.TextChannel.webhooks": "api/channels.html#disnake.TextChannel.webhooks", "disnake.TextChannel.create_webhook": "api/channels.html#disnake.TextChannel.create_webhook", "disnake.TextChannel.follow": "api/channels.html#disnake.TextChannel.follow", "disnake.TextChannel.get_partial_message": "api/channels.html#disnake.TextChannel.get_partial_message", "disnake.TextChannel.get_thread": "api/channels.html#disnake.TextChannel.get_thread", "disnake.TextChannel.create_thread": "api/channels.html#disnake.TextChannel.create_thread", "disnake.TextChannel.archived_threads": "api/channels.html#disnake.TextChannel.archived_threads", "disnake.TextChannel.category": "api/channels.html#disnake.TextChannel.category", "disnake.TextChannel.changed_roles": "api/channels.html#disnake.TextChannel.changed_roles", "disnake.TextChannel.create_invite": "api/channels.html#disnake.TextChannel.create_invite", "disnake.TextChannel.created_at": "api/channels.html#disnake.TextChannel.created_at", "disnake.TextChannel.delete": "api/channels.html#disnake.TextChannel.delete", "disnake.TextChannel.fetch_message": "api/channels.html#disnake.TextChannel.fetch_message", "disnake.TextChannel.flags": "api/channels.html#disnake.TextChannel.flags", "disnake.TextChannel.invites": "api/channels.html#disnake.TextChannel.invites", "disnake.TextChannel.jump_url": "api/channels.html#disnake.TextChannel.jump_url", "disnake.TextChannel.mention": "api/channels.html#disnake.TextChannel.mention", "disnake.TextChannel.move": "api/channels.html#disnake.TextChannel.move", "disnake.TextChannel.overwrites": "api/channels.html#disnake.TextChannel.overwrites", "disnake.TextChannel.overwrites_for": "api/channels.html#disnake.TextChannel.overwrites_for", "disnake.TextChannel.permissions_synced": "api/channels.html#disnake.TextChannel.permissions_synced", "disnake.TextChannel.pins": "api/channels.html#disnake.TextChannel.pins", "disnake.TextChannel.send": "api/channels.html#disnake.TextChannel.send", "disnake.TextChannel.set_permissions": "api/channels.html#disnake.TextChannel.set_permissions", "disnake.TextChannel.trigger_typing": "api/channels.html#disnake.TextChannel.trigger_typing", "disnake.VoiceChannel": "api/channels.html#disnake.VoiceChannel", "disnake.VoiceChannel.name": "api/channels.html#disnake.VoiceChannel.name", "disnake.VoiceChannel.guild": "api/channels.html#disnake.VoiceChannel.guild", "disnake.VoiceChannel.id": "api/channels.html#disnake.VoiceChannel.id", "disnake.VoiceChannel.category_id": "api/channels.html#disnake.VoiceChannel.category_id", "disnake.VoiceChannel.position": "api/channels.html#disnake.VoiceChannel.position", "disnake.VoiceChannel.bitrate": "api/channels.html#disnake.VoiceChannel.bitrate", "disnake.VoiceChannel.user_limit": "api/channels.html#disnake.VoiceChannel.user_limit", "disnake.VoiceChannel.rtc_region": "api/channels.html#disnake.VoiceChannel.rtc_region", "disnake.VoiceChannel.video_quality_mode": "api/channels.html#disnake.VoiceChannel.video_quality_mode", "disnake.VoiceChannel.nsfw": "api/channels.html#disnake.VoiceChannel.nsfw", "disnake.VoiceChannel.slowmode_delay": "api/channels.html#disnake.VoiceChannel.slowmode_delay", "disnake.VoiceChannel.last_message_id": "api/channels.html#disnake.VoiceChannel.last_message_id", "disnake.VoiceChannel.type": "api/channels.html#disnake.VoiceChannel.type", "disnake.VoiceChannel.clone": "api/channels.html#disnake.VoiceChannel.clone", "disnake.VoiceChannel.is_nsfw": "api/channels.html#disnake.VoiceChannel.is_nsfw", "disnake.VoiceChannel.last_message": "api/channels.html#disnake.VoiceChannel.last_message", "disnake.VoiceChannel.get_partial_message": "api/channels.html#disnake.VoiceChannel.get_partial_message", "disnake.VoiceChannel.permissions_for": "api/channels.html#disnake.VoiceChannel.permissions_for", "disnake.VoiceChannel.edit": "api/channels.html#disnake.VoiceChannel.edit", "disnake.VoiceChannel.delete_messages": "api/channels.html#disnake.VoiceChannel.delete_messages", "disnake.VoiceChannel.purge": "api/channels.html#disnake.VoiceChannel.purge", "disnake.VoiceChannel.webhooks": "api/channels.html#disnake.VoiceChannel.webhooks", "disnake.VoiceChannel.create_webhook": "api/channels.html#disnake.VoiceChannel.create_webhook", "disnake.VoiceChannel.category": "api/channels.html#disnake.VoiceChannel.category", "disnake.VoiceChannel.changed_roles": "api/channels.html#disnake.VoiceChannel.changed_roles", "disnake.VoiceChannel.connect": "api/channels.html#disnake.VoiceChannel.connect", "disnake.VoiceChannel.create_invite": "api/channels.html#disnake.VoiceChannel.create_invite", "disnake.VoiceChannel.created_at": "api/channels.html#disnake.VoiceChannel.created_at", "disnake.VoiceChannel.delete": "api/channels.html#disnake.VoiceChannel.delete", "disnake.VoiceChannel.fetch_message": "api/channels.html#disnake.VoiceChannel.fetch_message", "disnake.VoiceChannel.flags": "api/channels.html#disnake.VoiceChannel.flags", "disnake.VoiceChannel.history": "api/channels.html#disnake.VoiceChannel.history", "disnake.VoiceChannel.invites": "api/channels.html#disnake.VoiceChannel.invites", "disnake.VoiceChannel.jump_url": "api/channels.html#disnake.VoiceChannel.jump_url", "disnake.VoiceChannel.members": "api/channels.html#disnake.VoiceChannel.members", "disnake.VoiceChannel.mention": "api/channels.html#disnake.VoiceChannel.mention", "disnake.VoiceChannel.move": "api/channels.html#disnake.VoiceChannel.move", "disnake.VoiceChannel.overwrites": "api/channels.html#disnake.VoiceChannel.overwrites", "disnake.VoiceChannel.overwrites_for": "api/channels.html#disnake.VoiceChannel.overwrites_for", "disnake.VoiceChannel.permissions_synced": "api/channels.html#disnake.VoiceChannel.permissions_synced", "disnake.VoiceChannel.pins": "api/channels.html#disnake.VoiceChannel.pins", "disnake.VoiceChannel.send": "api/channels.html#disnake.VoiceChannel.send", "disnake.VoiceChannel.set_permissions": "api/channels.html#disnake.VoiceChannel.set_permissions", "disnake.VoiceChannel.trigger_typing": "api/channels.html#disnake.VoiceChannel.trigger_typing", "disnake.VoiceChannel.typing": "api/channels.html#disnake.VoiceChannel.typing", "disnake.VoiceChannel.voice_states": "api/channels.html#disnake.VoiceChannel.voice_states", "disnake.CategoryChannel": "api/channels.html#disnake.CategoryChannel", "disnake.CategoryChannel.name": "api/channels.html#disnake.CategoryChannel.name", "disnake.CategoryChannel.guild": "api/channels.html#disnake.CategoryChannel.guild", "disnake.CategoryChannel.id": "api/channels.html#disnake.CategoryChannel.id", "disnake.CategoryChannel.position": "api/channels.html#disnake.CategoryChannel.position", "disnake.CategoryChannel.nsfw": "api/channels.html#disnake.CategoryChannel.nsfw", "disnake.CategoryChannel.type": "api/channels.html#disnake.CategoryChannel.type", "disnake.CategoryChannel.is_nsfw": "api/channels.html#disnake.CategoryChannel.is_nsfw", "disnake.CategoryChannel.clone": "api/channels.html#disnake.CategoryChannel.clone", "disnake.CategoryChannel.edit": "api/channels.html#disnake.CategoryChannel.edit", "disnake.CategoryChannel.move": "api/channels.html#disnake.CategoryChannel.move", "disnake.CategoryChannel.channels": "api/channels.html#disnake.CategoryChannel.channels", "disnake.CategoryChannel.text_channels": "api/channels.html#disnake.CategoryChannel.text_channels", "disnake.CategoryChannel.voice_channels": "api/channels.html#disnake.CategoryChannel.voice_channels", "disnake.CategoryChannel.stage_channels": "api/channels.html#disnake.CategoryChannel.stage_channels", "disnake.CategoryChannel.forum_channels": "api/channels.html#disnake.CategoryChannel.forum_channels", "disnake.CategoryChannel.create_text_channel": "api/channels.html#disnake.CategoryChannel.create_text_channel", "disnake.CategoryChannel.create_voice_channel": "api/channels.html#disnake.CategoryChannel.create_voice_channel", "disnake.CategoryChannel.create_stage_channel": "api/channels.html#disnake.CategoryChannel.create_stage_channel", "disnake.CategoryChannel.create_forum_channel": "api/channels.html#disnake.CategoryChannel.create_forum_channel", "disnake.CategoryChannel.category": "api/channels.html#disnake.CategoryChannel.category", "disnake.CategoryChannel.changed_roles": "api/channels.html#disnake.CategoryChannel.changed_roles", "disnake.CategoryChannel.create_invite": "api/channels.html#disnake.CategoryChannel.create_invite", "disnake.CategoryChannel.created_at": "api/channels.html#disnake.CategoryChannel.created_at", "disnake.CategoryChannel.delete": "api/channels.html#disnake.CategoryChannel.delete", "disnake.CategoryChannel.flags": "api/channels.html#disnake.CategoryChannel.flags", "disnake.CategoryChannel.invites": "api/channels.html#disnake.CategoryChannel.invites", "disnake.CategoryChannel.jump_url": "api/channels.html#disnake.CategoryChannel.jump_url", "disnake.CategoryChannel.mention": "api/channels.html#disnake.CategoryChannel.mention", "disnake.CategoryChannel.overwrites": "api/channels.html#disnake.CategoryChannel.overwrites", "disnake.CategoryChannel.overwrites_for": "api/channels.html#disnake.CategoryChannel.overwrites_for", "disnake.CategoryChannel.permissions_for": "api/channels.html#disnake.CategoryChannel.permissions_for", "disnake.CategoryChannel.permissions_synced": "api/channels.html#disnake.CategoryChannel.permissions_synced", "disnake.CategoryChannel.set_permissions": "api/channels.html#disnake.CategoryChannel.set_permissions", "disnake.Thread": "api/channels.html#disnake.Thread", "disnake.Thread.name": "api/channels.html#disnake.Thread.name", "disnake.Thread.guild": "api/channels.html#disnake.Thread.guild", "disnake.Thread.id": "api/channels.html#disnake.Thread.id", "disnake.Thread.parent_id": "api/channels.html#disnake.Thread.parent_id", "disnake.Thread.owner_id": "api/channels.html#disnake.Thread.owner_id", "disnake.Thread.last_message_id": "api/channels.html#disnake.Thread.last_message_id", "disnake.Thread.slowmode_delay": "api/channels.html#disnake.Thread.slowmode_delay", "disnake.Thread.message_count": "api/channels.html#disnake.Thread.message_count", "disnake.Thread.member_count": "api/channels.html#disnake.Thread.member_count", "disnake.Thread.total_message_sent": "api/channels.html#disnake.Thread.total_message_sent", "disnake.Thread.me": "api/channels.html#disnake.Thread.me", "disnake.Thread.archived": "api/channels.html#disnake.Thread.archived", "disnake.Thread.locked": "api/channels.html#disnake.Thread.locked", "disnake.Thread.invitable": "api/channels.html#disnake.Thread.invitable", "disnake.Thread.auto_archive_duration": "api/channels.html#disnake.Thread.auto_archive_duration", "disnake.Thread.archive_timestamp": "api/channels.html#disnake.Thread.archive_timestamp", "disnake.Thread.create_timestamp": "api/channels.html#disnake.Thread.create_timestamp", "disnake.Thread.last_pin_timestamp": "api/channels.html#disnake.Thread.last_pin_timestamp", "disnake.Thread.history": "api/channels.html#disnake.Thread.history", "disnake.Thread.typing": "api/channels.html#disnake.Thread.typing", "disnake.Thread.type": "api/channels.html#disnake.Thread.type", "disnake.Thread.parent": "api/channels.html#disnake.Thread.parent", "disnake.Thread.owner": "api/channels.html#disnake.Thread.owner", "disnake.Thread.mention": "api/channels.html#disnake.Thread.mention", "disnake.Thread.members": "api/channels.html#disnake.Thread.members", "disnake.Thread.last_message": "api/channels.html#disnake.Thread.last_message", "disnake.Thread.category": "api/channels.html#disnake.Thread.category", "disnake.Thread.category_id": "api/channels.html#disnake.Thread.category_id", "disnake.Thread.created_at": "api/channels.html#disnake.Thread.created_at", "disnake.Thread.flags": "api/channels.html#disnake.Thread.flags", "disnake.Thread.jump_url": "api/channels.html#disnake.Thread.jump_url", "disnake.Thread.is_private": "api/channels.html#disnake.Thread.is_private", "disnake.Thread.is_news": "api/channels.html#disnake.Thread.is_news", "disnake.Thread.is_nsfw": "api/channels.html#disnake.Thread.is_nsfw", "disnake.Thread.is_pinned": "api/channels.html#disnake.Thread.is_pinned", "disnake.Thread.applied_tags": "api/channels.html#disnake.Thread.applied_tags", "disnake.Thread.permissions_for": "api/channels.html#disnake.Thread.permissions_for", "disnake.Thread.delete_messages": "api/channels.html#disnake.Thread.delete_messages", "disnake.Thread.purge": "api/channels.html#disnake.Thread.purge", "disnake.Thread.edit": "api/channels.html#disnake.Thread.edit", "disnake.Thread.join": "api/channels.html#disnake.Thread.join", "disnake.Thread.leave": "api/channels.html#disnake.Thread.leave", "disnake.Thread.add_user": "api/channels.html#disnake.Thread.add_user", "disnake.Thread.remove_user": "api/channels.html#disnake.Thread.remove_user", "disnake.Thread.fetch_member": "api/channels.html#disnake.Thread.fetch_member", "disnake.Thread.fetch_members": "api/channels.html#disnake.Thread.fetch_members", "disnake.Thread.delete": "api/channels.html#disnake.Thread.delete", "disnake.Thread.add_tags": "api/channels.html#disnake.Thread.add_tags", "disnake.Thread.remove_tags": "api/channels.html#disnake.Thread.remove_tags", "disnake.Thread.get_partial_message": "api/channels.html#disnake.Thread.get_partial_message", "disnake.Thread.fetch_message": "api/channels.html#disnake.Thread.fetch_message", "disnake.Thread.pins": "api/channels.html#disnake.Thread.pins", "disnake.Thread.send": "api/channels.html#disnake.Thread.send", "disnake.Thread.trigger_typing": "api/channels.html#disnake.Thread.trigger_typing", "disnake.ThreadMember": "api/channels.html#disnake.ThreadMember", "disnake.ThreadMember.id": "api/channels.html#disnake.ThreadMember.id", "disnake.ThreadMember.thread_id": "api/channels.html#disnake.ThreadMember.thread_id", "disnake.ThreadMember.joined_at": "api/channels.html#disnake.ThreadMember.joined_at", "disnake.ThreadMember.thread": "api/channels.html#disnake.ThreadMember.thread", "disnake.ForumTag": "api/channels.html#disnake.ForumTag", "disnake.ForumTag.id": "api/channels.html#disnake.ForumTag.id", "disnake.ForumTag.name": "api/channels.html#disnake.ForumTag.name", "disnake.ForumTag.moderated": "api/channels.html#disnake.ForumTag.moderated", "disnake.ForumTag.emoji": "api/channels.html#disnake.ForumTag.emoji", "disnake.ForumTag.with_changes": "api/channels.html#disnake.ForumTag.with_changes", "disnake.StageChannel": "api/channels.html#disnake.StageChannel", "disnake.StageChannel.name": "api/channels.html#disnake.StageChannel.name", "disnake.StageChannel.guild": "api/channels.html#disnake.StageChannel.guild", "disnake.StageChannel.id": "api/channels.html#disnake.StageChannel.id", "disnake.StageChannel.topic": "api/channels.html#disnake.StageChannel.topic", "disnake.StageChannel.category_id": "api/channels.html#disnake.StageChannel.category_id", "disnake.StageChannel.position": "api/channels.html#disnake.StageChannel.position", "disnake.StageChannel.bitrate": "api/channels.html#disnake.StageChannel.bitrate", "disnake.StageChannel.user_limit": "api/channels.html#disnake.StageChannel.user_limit", "disnake.StageChannel.rtc_region": "api/channels.html#disnake.StageChannel.rtc_region", "disnake.StageChannel.video_quality_mode": "api/channels.html#disnake.StageChannel.video_quality_mode", "disnake.StageChannel.requesting_to_speak": "api/channels.html#disnake.StageChannel.requesting_to_speak", "disnake.StageChannel.speakers": "api/channels.html#disnake.StageChannel.speakers", "disnake.StageChannel.listeners": "api/channels.html#disnake.StageChannel.listeners", "disnake.StageChannel.moderators": "api/channels.html#disnake.StageChannel.moderators", "disnake.StageChannel.type": "api/channels.html#disnake.StageChannel.type", "disnake.StageChannel.clone": "api/channels.html#disnake.StageChannel.clone", "disnake.StageChannel.instance": "api/channels.html#disnake.StageChannel.instance", "disnake.StageChannel.permissions_for": "api/channels.html#disnake.StageChannel.permissions_for", "disnake.StageChannel.create_instance": "api/channels.html#disnake.StageChannel.create_instance", "disnake.StageChannel.fetch_instance": "api/channels.html#disnake.StageChannel.fetch_instance", "disnake.StageChannel.edit": "api/channels.html#disnake.StageChannel.edit", "disnake.StageChannel.category": "api/channels.html#disnake.StageChannel.category", "disnake.StageChannel.changed_roles": "api/channels.html#disnake.StageChannel.changed_roles", "disnake.StageChannel.connect": "api/channels.html#disnake.StageChannel.connect", "disnake.StageChannel.create_invite": "api/channels.html#disnake.StageChannel.create_invite", "disnake.StageChannel.created_at": "api/channels.html#disnake.StageChannel.created_at", "disnake.StageChannel.delete": "api/channels.html#disnake.StageChannel.delete", "disnake.StageChannel.flags": "api/channels.html#disnake.StageChannel.flags", "disnake.StageChannel.invites": "api/channels.html#disnake.StageChannel.invites", "disnake.StageChannel.jump_url": "api/channels.html#disnake.StageChannel.jump_url", "disnake.StageChannel.members": "api/channels.html#disnake.StageChannel.members", "disnake.StageChannel.mention": "api/channels.html#disnake.StageChannel.mention", "disnake.StageChannel.move": "api/channels.html#disnake.StageChannel.move", "disnake.StageChannel.overwrites": "api/channels.html#disnake.StageChannel.overwrites", "disnake.StageChannel.overwrites_for": "api/channels.html#disnake.StageChannel.overwrites_for", "disnake.StageChannel.permissions_synced": "api/channels.html#disnake.StageChannel.permissions_synced", "disnake.StageChannel.set_permissions": "api/channels.html#disnake.StageChannel.set_permissions", "disnake.StageChannel.voice_states": "api/channels.html#disnake.StageChannel.voice_states", "disnake.ForumChannel": "api/channels.html#disnake.ForumChannel", "disnake.ForumChannel.id": "api/channels.html#disnake.ForumChannel.id", "disnake.ForumChannel.name": "api/channels.html#disnake.ForumChannel.name", "disnake.ForumChannel.guild": "api/channels.html#disnake.ForumChannel.guild", "disnake.ForumChannel.topic": "api/channels.html#disnake.ForumChannel.topic", "disnake.ForumChannel.category_id": "api/channels.html#disnake.ForumChannel.category_id", "disnake.ForumChannel.position": "api/channels.html#disnake.ForumChannel.position", "disnake.ForumChannel.nsfw": "api/channels.html#disnake.ForumChannel.nsfw", "disnake.ForumChannel.last_thread_id": "api/channels.html#disnake.ForumChannel.last_thread_id", "disnake.ForumChannel.default_auto_archive_duration": "api/channels.html#disnake.ForumChannel.default_auto_archive_duration", "disnake.ForumChannel.slowmode_delay": "api/channels.html#disnake.ForumChannel.slowmode_delay", "disnake.ForumChannel.default_thread_slowmode_delay": "api/channels.html#disnake.ForumChannel.default_thread_slowmode_delay", "disnake.ForumChannel.default_sort_order": "api/channels.html#disnake.ForumChannel.default_sort_order", "disnake.ForumChannel.typing": "api/channels.html#disnake.ForumChannel.typing", "disnake.ForumChannel.type": "api/channels.html#disnake.ForumChannel.type", "disnake.ForumChannel.permissions_for": "api/channels.html#disnake.ForumChannel.permissions_for", "disnake.ForumChannel.members": "api/channels.html#disnake.ForumChannel.members", "disnake.ForumChannel.threads": "api/channels.html#disnake.ForumChannel.threads", "disnake.ForumChannel.is_nsfw": "api/channels.html#disnake.ForumChannel.is_nsfw", "disnake.ForumChannel.requires_tag": "api/channels.html#disnake.ForumChannel.requires_tag", "disnake.ForumChannel.default_reaction": "api/channels.html#disnake.ForumChannel.default_reaction", "disnake.ForumChannel.last_thread": "api/channels.html#disnake.ForumChannel.last_thread", "disnake.ForumChannel.available_tags": "api/channels.html#disnake.ForumChannel.available_tags", "disnake.ForumChannel.trigger_typing": "api/channels.html#disnake.ForumChannel.trigger_typing", "disnake.ForumChannel.edit": "api/channels.html#disnake.ForumChannel.edit", "disnake.ForumChannel.clone": "api/channels.html#disnake.ForumChannel.clone", "disnake.ForumChannel.get_thread": "api/channels.html#disnake.ForumChannel.get_thread", "disnake.ForumChannel.create_thread": "api/channels.html#disnake.ForumChannel.create_thread", "disnake.ForumChannel.archived_threads": "api/channels.html#disnake.ForumChannel.archived_threads", "disnake.ForumChannel.webhooks": "api/channels.html#disnake.ForumChannel.webhooks", "disnake.ForumChannel.create_webhook": "api/channels.html#disnake.ForumChannel.create_webhook", "disnake.ForumChannel.get_tag": "api/channels.html#disnake.ForumChannel.get_tag", "disnake.ForumChannel.get_tag_by_name": "api/channels.html#disnake.ForumChannel.get_tag_by_name", "disnake.ForumChannel.category": "api/channels.html#disnake.ForumChannel.category", "disnake.ForumChannel.changed_roles": "api/channels.html#disnake.ForumChannel.changed_roles", "disnake.ForumChannel.create_invite": "api/channels.html#disnake.ForumChannel.create_invite", "disnake.ForumChannel.created_at": "api/channels.html#disnake.ForumChannel.created_at", "disnake.ForumChannel.delete": "api/channels.html#disnake.ForumChannel.delete", "disnake.ForumChannel.flags": "api/channels.html#disnake.ForumChannel.flags", "disnake.ForumChannel.invites": "api/channels.html#disnake.ForumChannel.invites", "disnake.ForumChannel.jump_url": "api/channels.html#disnake.ForumChannel.jump_url", "disnake.ForumChannel.mention": "api/channels.html#disnake.ForumChannel.mention", "disnake.ForumChannel.move": "api/channels.html#disnake.ForumChannel.move", "disnake.ForumChannel.overwrites": "api/channels.html#disnake.ForumChannel.overwrites", "disnake.ForumChannel.overwrites_for": "api/channels.html#disnake.ForumChannel.overwrites_for", "disnake.ForumChannel.permissions_synced": "api/channels.html#disnake.ForumChannel.permissions_synced", "disnake.ForumChannel.set_permissions": "api/channels.html#disnake.ForumChannel.set_permissions", "disnake.DMChannel": "api/channels.html#disnake.DMChannel", "disnake.DMChannel.recipient": "api/channels.html#disnake.DMChannel.recipient", "disnake.DMChannel.me": "api/channels.html#disnake.DMChannel.me", "disnake.DMChannel.id": "api/channels.html#disnake.DMChannel.id", "disnake.DMChannel.last_pin_timestamp": "api/channels.html#disnake.DMChannel.last_pin_timestamp", "disnake.DMChannel.history": "api/channels.html#disnake.DMChannel.history", "disnake.DMChannel.typing": "api/channels.html#disnake.DMChannel.typing", "disnake.DMChannel.type": "api/channels.html#disnake.DMChannel.type", "disnake.DMChannel.created_at": "api/channels.html#disnake.DMChannel.created_at", "disnake.DMChannel.jump_url": "api/channels.html#disnake.DMChannel.jump_url", "disnake.DMChannel.flags": "api/channels.html#disnake.DMChannel.flags", "disnake.DMChannel.permissions_for": "api/channels.html#disnake.DMChannel.permissions_for", "disnake.DMChannel.get_partial_message": "api/channels.html#disnake.DMChannel.get_partial_message", "disnake.DMChannel.fetch_message": "api/channels.html#disnake.DMChannel.fetch_message", "disnake.DMChannel.pins": "api/channels.html#disnake.DMChannel.pins", "disnake.DMChannel.send": "api/channels.html#disnake.DMChannel.send", "disnake.DMChannel.trigger_typing": "api/channels.html#disnake.DMChannel.trigger_typing", "disnake.GroupChannel": "api/channels.html#disnake.GroupChannel", "disnake.GroupChannel.recipients": "api/channels.html#disnake.GroupChannel.recipients", "disnake.GroupChannel.me": "api/channels.html#disnake.GroupChannel.me", "disnake.GroupChannel.id": "api/channels.html#disnake.GroupChannel.id", "disnake.GroupChannel.owner": "api/channels.html#disnake.GroupChannel.owner", "disnake.GroupChannel.owner_id": "api/channels.html#disnake.GroupChannel.owner_id", "disnake.GroupChannel.name": "api/channels.html#disnake.GroupChannel.name", "disnake.GroupChannel.history": "api/channels.html#disnake.GroupChannel.history", "disnake.GroupChannel.typing": "api/channels.html#disnake.GroupChannel.typing", "disnake.GroupChannel.fetch_message": "api/channels.html#disnake.GroupChannel.fetch_message", "disnake.GroupChannel.pins": "api/channels.html#disnake.GroupChannel.pins", "disnake.GroupChannel.send": "api/channels.html#disnake.GroupChannel.send", "disnake.GroupChannel.trigger_typing": "api/channels.html#disnake.GroupChannel.trigger_typing", "disnake.GroupChannel.type": "api/channels.html#disnake.GroupChannel.type", "disnake.GroupChannel.icon": "api/channels.html#disnake.GroupChannel.icon", "disnake.GroupChannel.created_at": "api/channels.html#disnake.GroupChannel.created_at", "disnake.GroupChannel.permissions_for": "api/channels.html#disnake.GroupChannel.permissions_for", "disnake.GroupChannel.leave": "api/channels.html#disnake.GroupChannel.leave", "disnake.PartialMessageable": "api/channels.html#disnake.PartialMessageable", "disnake.PartialMessageable.id": "api/channels.html#disnake.PartialMessageable.id", "disnake.PartialMessageable.type": "api/channels.html#disnake.PartialMessageable.type", "disnake.PartialMessageable.fetch_message": "api/channels.html#disnake.PartialMessageable.fetch_message", "disnake.PartialMessageable.history": "api/channels.html#disnake.PartialMessageable.history", "disnake.PartialMessageable.pins": "api/channels.html#disnake.PartialMessageable.pins", "disnake.PartialMessageable.send": "api/channels.html#disnake.PartialMessageable.send", "disnake.PartialMessageable.trigger_typing": "api/channels.html#disnake.PartialMessageable.trigger_typing", "disnake.PartialMessageable.typing": "api/channels.html#disnake.PartialMessageable.typing", "disnake.PartialMessageable.get_partial_message": "api/channels.html#disnake.PartialMessageable.get_partial_message", "disnake.ChannelFlags": "api/channels.html#disnake.ChannelFlags", "disnake.ChannelFlags.value": "api/channels.html#disnake.ChannelFlags.value", "disnake.ChannelFlags.pinned": "api/channels.html#disnake.ChannelFlags.pinned", "disnake.ChannelFlags.require_tag": "api/channels.html#disnake.ChannelFlags.require_tag", "disnake.RawThreadDeleteEvent": "api/channels.html#disnake.RawThreadDeleteEvent", "disnake.RawThreadDeleteEvent.thread_id": "api/channels.html#disnake.RawThreadDeleteEvent.thread_id", "disnake.RawThreadDeleteEvent.guild_id": "api/channels.html#disnake.RawThreadDeleteEvent.guild_id", "disnake.RawThreadDeleteEvent.thread_type": "api/channels.html#disnake.RawThreadDeleteEvent.thread_type", "disnake.RawThreadDeleteEvent.parent_id": "api/channels.html#disnake.RawThreadDeleteEvent.parent_id", "disnake.RawThreadDeleteEvent.thread": "api/channels.html#disnake.RawThreadDeleteEvent.thread", "disnake.RawThreadMemberRemoveEvent": "api/channels.html#disnake.RawThreadMemberRemoveEvent", "disnake.RawThreadMemberRemoveEvent.thread": "api/channels.html#disnake.RawThreadMemberRemoveEvent.thread", "disnake.RawThreadMemberRemoveEvent.member_id": "api/channels.html#disnake.RawThreadMemberRemoveEvent.member_id", "disnake.RawThreadMemberRemoveEvent.cached_member": "api/channels.html#disnake.RawThreadMemberRemoveEvent.cached_member", "disnake.ChannelType": "api/channels.html#disnake.ChannelType", "disnake.ChannelType.text": "api/channels.html#disnake.ChannelType.text", "disnake.ChannelType.voice": "api/channels.html#disnake.ChannelType.voice", "disnake.ChannelType.private": "api/channels.html#disnake.ChannelType.private", "disnake.ChannelType.group": "api/channels.html#disnake.ChannelType.group", "disnake.ChannelType.category": "api/channels.html#disnake.ChannelType.category", "disnake.ChannelType.news": "api/channels.html#disnake.ChannelType.news", "disnake.ChannelType.stage_voice": "api/channels.html#disnake.ChannelType.stage_voice", "disnake.ChannelType.news_thread": "api/channels.html#disnake.ChannelType.news_thread", "disnake.ChannelType.public_thread": "api/channels.html#disnake.ChannelType.public_thread", "disnake.ChannelType.private_thread": "api/channels.html#disnake.ChannelType.private_thread", "disnake.ChannelType.guild_directory": "api/channels.html#disnake.ChannelType.guild_directory", "disnake.ChannelType.forum": "api/channels.html#disnake.ChannelType.forum", "disnake.ThreadArchiveDuration": "api/channels.html#disnake.ThreadArchiveDuration", "disnake.ThreadArchiveDuration.hour": "api/channels.html#disnake.ThreadArchiveDuration.hour", "disnake.ThreadArchiveDuration.day": "api/channels.html#disnake.ThreadArchiveDuration.day", "disnake.ThreadArchiveDuration.three_days": "api/channels.html#disnake.ThreadArchiveDuration.three_days", "disnake.ThreadArchiveDuration.week": "api/channels.html#disnake.ThreadArchiveDuration.week", "disnake.VideoQualityMode": "api/channels.html#disnake.VideoQualityMode", "disnake.VideoQualityMode.auto": "api/channels.html#disnake.VideoQualityMode.auto", "disnake.VideoQualityMode.full": "api/channels.html#disnake.VideoQualityMode.full", "disnake.ThreadSortOrder": "api/channels.html#disnake.ThreadSortOrder", "disnake.ThreadSortOrder.latest_activity": "api/channels.html#disnake.ThreadSortOrder.latest_activity", "disnake.ThreadSortOrder.creation_date": "api/channels.html#disnake.ThreadSortOrder.creation_date", "disnake.Client": "api/clients.html#disnake.Client", "disnake.Client.ws": "api/clients.html#disnake.Client.ws", "disnake.Client.loop": "api/clients.html#disnake.Client.loop", "disnake.Client.session_start_limit": "api/clients.html#disnake.Client.session_start_limit", "disnake.Client.i18n": "api/clients.html#disnake.Client.i18n", "disnake.Client.event": "api/clients.html#disnake.Client.event", "disnake.Client.fetch_guilds": "api/clients.html#disnake.Client.fetch_guilds", "disnake.Client.latency": "api/clients.html#disnake.Client.latency", "disnake.Client.is_ws_ratelimited": "api/clients.html#disnake.Client.is_ws_ratelimited", "disnake.Client.user": "api/clients.html#disnake.Client.user", "disnake.Client.guilds": "api/clients.html#disnake.Client.guilds", "disnake.Client.emojis": "api/clients.html#disnake.Client.emojis", "disnake.Client.stickers": "api/clients.html#disnake.Client.stickers", "disnake.Client.cached_messages": "api/clients.html#disnake.Client.cached_messages", "disnake.Client.private_channels": "api/clients.html#disnake.Client.private_channels", "disnake.Client.voice_clients": "api/clients.html#disnake.Client.voice_clients", "disnake.Client.application_id": "api/clients.html#disnake.Client.application_id", "disnake.Client.application_flags": "api/clients.html#disnake.Client.application_flags", "disnake.Client.global_application_commands": "api/clients.html#disnake.Client.global_application_commands", "disnake.Client.global_slash_commands": "api/clients.html#disnake.Client.global_slash_commands", "disnake.Client.global_user_commands": "api/clients.html#disnake.Client.global_user_commands", "disnake.Client.global_message_commands": "api/clients.html#disnake.Client.global_message_commands", "disnake.Client.get_message": "api/clients.html#disnake.Client.get_message", "disnake.Client.get_or_fetch_user": "api/clients.html#disnake.Client.get_or_fetch_user", "disnake.Client.getch_user": "api/clients.html#disnake.Client.getch_user", "disnake.Client.is_ready": "api/clients.html#disnake.Client.is_ready", "disnake.Client.on_error": "api/clients.html#disnake.Client.on_error", "disnake.Client.on_gateway_error": "api/clients.html#disnake.Client.on_gateway_error", "disnake.Client.before_identify_hook": "api/clients.html#disnake.Client.before_identify_hook", "disnake.Client.login": "api/clients.html#disnake.Client.login", "disnake.Client.connect": "api/clients.html#disnake.Client.connect", "disnake.Client.close": "api/clients.html#disnake.Client.close", "disnake.Client.clear": "api/clients.html#disnake.Client.clear", "disnake.Client.start": "api/clients.html#disnake.Client.start", "disnake.Client.run": "api/clients.html#disnake.Client.run", "disnake.Client.is_closed": "api/clients.html#disnake.Client.is_closed", "disnake.Client.activity": "api/clients.html#disnake.Client.activity", "disnake.Client.status": "api/clients.html#disnake.Client.status", "disnake.Client.allowed_mentions": "api/clients.html#disnake.Client.allowed_mentions", "disnake.Client.intents": "api/clients.html#disnake.Client.intents", "disnake.Client.users": "api/clients.html#disnake.Client.users", "disnake.Client.get_channel": "api/clients.html#disnake.Client.get_channel", "disnake.Client.get_partial_messageable": "api/clients.html#disnake.Client.get_partial_messageable", "disnake.Client.get_stage_instance": "api/clients.html#disnake.Client.get_stage_instance", "disnake.Client.get_guild": "api/clients.html#disnake.Client.get_guild", "disnake.Client.get_user": "api/clients.html#disnake.Client.get_user", "disnake.Client.get_emoji": "api/clients.html#disnake.Client.get_emoji", "disnake.Client.get_sticker": "api/clients.html#disnake.Client.get_sticker", "disnake.Client.get_all_channels": "api/clients.html#disnake.Client.get_all_channels", "disnake.Client.get_all_members": "api/clients.html#disnake.Client.get_all_members", "disnake.Client.get_guild_application_commands": "api/clients.html#disnake.Client.get_guild_application_commands", "disnake.Client.get_guild_slash_commands": "api/clients.html#disnake.Client.get_guild_slash_commands", "disnake.Client.get_guild_user_commands": "api/clients.html#disnake.Client.get_guild_user_commands", "disnake.Client.get_guild_message_commands": "api/clients.html#disnake.Client.get_guild_message_commands", "disnake.Client.get_global_command": "api/clients.html#disnake.Client.get_global_command", "disnake.Client.get_guild_command": "api/clients.html#disnake.Client.get_guild_command", "disnake.Client.get_global_command_named": "api/clients.html#disnake.Client.get_global_command_named", "disnake.Client.get_guild_command_named": "api/clients.html#disnake.Client.get_guild_command_named", "disnake.Client.wait_until_ready": "api/clients.html#disnake.Client.wait_until_ready", "disnake.Client.wait_until_first_connect": "api/clients.html#disnake.Client.wait_until_first_connect", "disnake.Client.wait_for": "api/clients.html#disnake.Client.wait_for", "disnake.Client.change_presence": "api/clients.html#disnake.Client.change_presence", "disnake.Client.fetch_template": "api/clients.html#disnake.Client.fetch_template", "disnake.Client.fetch_guild": "api/clients.html#disnake.Client.fetch_guild", "disnake.Client.fetch_guild_preview": "api/clients.html#disnake.Client.fetch_guild_preview", "disnake.Client.create_guild": "api/clients.html#disnake.Client.create_guild", "disnake.Client.fetch_stage_instance": "api/clients.html#disnake.Client.fetch_stage_instance", "disnake.Client.fetch_invite": "api/clients.html#disnake.Client.fetch_invite", "disnake.Client.delete_invite": "api/clients.html#disnake.Client.delete_invite", "disnake.Client.fetch_voice_regions": "api/clients.html#disnake.Client.fetch_voice_regions", "disnake.Client.fetch_widget": "api/clients.html#disnake.Client.fetch_widget", "disnake.Client.application_info": "api/clients.html#disnake.Client.application_info", "disnake.Client.fetch_user": "api/clients.html#disnake.Client.fetch_user", "disnake.Client.fetch_channel": "api/clients.html#disnake.Client.fetch_channel", "disnake.Client.fetch_webhook": "api/clients.html#disnake.Client.fetch_webhook", "disnake.Client.fetch_sticker": "api/clients.html#disnake.Client.fetch_sticker", "disnake.Client.fetch_premium_sticker_packs": "api/clients.html#disnake.Client.fetch_premium_sticker_packs", "disnake.Client.create_dm": "api/clients.html#disnake.Client.create_dm", "disnake.Client.add_view": "api/clients.html#disnake.Client.add_view", "disnake.Client.persistent_views": "api/clients.html#disnake.Client.persistent_views", "disnake.Client.fetch_global_commands": "api/clients.html#disnake.Client.fetch_global_commands", "disnake.Client.fetch_global_command": "api/clients.html#disnake.Client.fetch_global_command", "disnake.Client.create_global_command": "api/clients.html#disnake.Client.create_global_command", "disnake.Client.edit_global_command": "api/clients.html#disnake.Client.edit_global_command", "disnake.Client.delete_global_command": "api/clients.html#disnake.Client.delete_global_command", "disnake.Client.bulk_overwrite_global_commands": "api/clients.html#disnake.Client.bulk_overwrite_global_commands", "disnake.Client.fetch_guild_commands": "api/clients.html#disnake.Client.fetch_guild_commands", "disnake.Client.fetch_guild_command": "api/clients.html#disnake.Client.fetch_guild_command", "disnake.Client.create_guild_command": "api/clients.html#disnake.Client.create_guild_command", "disnake.Client.edit_guild_command": "api/clients.html#disnake.Client.edit_guild_command", "disnake.Client.delete_guild_command": "api/clients.html#disnake.Client.delete_guild_command", "disnake.Client.bulk_overwrite_guild_commands": "api/clients.html#disnake.Client.bulk_overwrite_guild_commands", "disnake.Client.bulk_fetch_command_permissions": "api/clients.html#disnake.Client.bulk_fetch_command_permissions", "disnake.Client.fetch_command_permissions": "api/clients.html#disnake.Client.fetch_command_permissions", "disnake.AutoShardedClient": "api/clients.html#disnake.AutoShardedClient", "disnake.AutoShardedClient.shard_ids": "api/clients.html#disnake.AutoShardedClient.shard_ids", "disnake.AutoShardedClient.latency": "api/clients.html#disnake.AutoShardedClient.latency", "disnake.AutoShardedClient.latencies": "api/clients.html#disnake.AutoShardedClient.latencies", "disnake.AutoShardedClient.get_shard": "api/clients.html#disnake.AutoShardedClient.get_shard", "disnake.AutoShardedClient.shards": "api/clients.html#disnake.AutoShardedClient.shards", "disnake.AutoShardedClient.connect": "api/clients.html#disnake.AutoShardedClient.connect", "disnake.AutoShardedClient.close": "api/clients.html#disnake.AutoShardedClient.close", "disnake.AutoShardedClient.change_presence": "api/clients.html#disnake.AutoShardedClient.change_presence", "disnake.AutoShardedClient.is_ws_ratelimited": "api/clients.html#disnake.AutoShardedClient.is_ws_ratelimited", "disnake.ClientUser": "api/clients.html#disnake.ClientUser", "disnake.ClientUser.name": "api/clients.html#disnake.ClientUser.name", "disnake.ClientUser.id": "api/clients.html#disnake.ClientUser.id", "disnake.ClientUser.discriminator": "api/clients.html#disnake.ClientUser.discriminator", "disnake.ClientUser.bot": "api/clients.html#disnake.ClientUser.bot", "disnake.ClientUser.system": "api/clients.html#disnake.ClientUser.system", "disnake.ClientUser.verified": "api/clients.html#disnake.ClientUser.verified", "disnake.ClientUser.locale": "api/clients.html#disnake.ClientUser.locale", "disnake.ClientUser.mfa_enabled": "api/clients.html#disnake.ClientUser.mfa_enabled", "disnake.ClientUser.edit": "api/clients.html#disnake.ClientUser.edit", "disnake.ClientUser.accent_color": "api/clients.html#disnake.ClientUser.accent_color", "disnake.ClientUser.accent_colour": "api/clients.html#disnake.ClientUser.accent_colour", "disnake.ClientUser.avatar": "api/clients.html#disnake.ClientUser.avatar", "disnake.ClientUser.banner": "api/clients.html#disnake.ClientUser.banner", "disnake.ClientUser.color": "api/clients.html#disnake.ClientUser.color", "disnake.ClientUser.colour": "api/clients.html#disnake.ClientUser.colour", "disnake.ClientUser.created_at": "api/clients.html#disnake.ClientUser.created_at", "disnake.ClientUser.default_avatar": "api/clients.html#disnake.ClientUser.default_avatar", "disnake.ClientUser.display_avatar": "api/clients.html#disnake.ClientUser.display_avatar", "disnake.ClientUser.display_name": "api/clients.html#disnake.ClientUser.display_name", "disnake.ClientUser.mention": "api/clients.html#disnake.ClientUser.mention", "disnake.ClientUser.mentioned_in": "api/clients.html#disnake.ClientUser.mentioned_in", "disnake.ClientUser.public_flags": "api/clients.html#disnake.ClientUser.public_flags", "disnake.ShardInfo": "api/clients.html#disnake.ShardInfo", "disnake.ShardInfo.id": "api/clients.html#disnake.ShardInfo.id", "disnake.ShardInfo.shard_count": "api/clients.html#disnake.ShardInfo.shard_count", "disnake.ShardInfo.is_closed": "api/clients.html#disnake.ShardInfo.is_closed", "disnake.ShardInfo.disconnect": "api/clients.html#disnake.ShardInfo.disconnect", "disnake.ShardInfo.reconnect": "api/clients.html#disnake.ShardInfo.reconnect", "disnake.ShardInfo.connect": "api/clients.html#disnake.ShardInfo.connect", "disnake.ShardInfo.latency": "api/clients.html#disnake.ShardInfo.latency", "disnake.ShardInfo.is_ws_ratelimited": "api/clients.html#disnake.ShardInfo.is_ws_ratelimited", "disnake.SessionStartLimit": "api/clients.html#disnake.SessionStartLimit", "disnake.SessionStartLimit.total": "api/clients.html#disnake.SessionStartLimit.total", "disnake.SessionStartLimit.remaining": "api/clients.html#disnake.SessionStartLimit.remaining", "disnake.SessionStartLimit.reset_after": "api/clients.html#disnake.SessionStartLimit.reset_after", "disnake.SessionStartLimit.max_concurrency": "api/clients.html#disnake.SessionStartLimit.max_concurrency", "disnake.SessionStartLimit.reset_time": "api/clients.html#disnake.SessionStartLimit.reset_time", "disnake.GatewayParams": "api/clients.html#disnake.GatewayParams", "disnake.Intents": "api/clients.html#disnake.Intents", "disnake.Intents.value": "api/clients.html#disnake.Intents.value", "disnake.Intents.all": "api/clients.html#disnake.Intents.all", "disnake.Intents.none": "api/clients.html#disnake.Intents.none", "disnake.Intents.default": "api/clients.html#disnake.Intents.default", "disnake.Intents.guilds": "api/clients.html#disnake.Intents.guilds", "disnake.Intents.members": "api/clients.html#disnake.Intents.members", "disnake.Intents.bans": "api/clients.html#disnake.Intents.bans", "disnake.Intents.emojis": "api/clients.html#disnake.Intents.emojis", "disnake.Intents.emojis_and_stickers": "api/clients.html#disnake.Intents.emojis_and_stickers", "disnake.Intents.integrations": "api/clients.html#disnake.Intents.integrations", "disnake.Intents.webhooks": "api/clients.html#disnake.Intents.webhooks", "disnake.Intents.invites": "api/clients.html#disnake.Intents.invites", "disnake.Intents.voice_states": "api/clients.html#disnake.Intents.voice_states", "disnake.Intents.presences": "api/clients.html#disnake.Intents.presences", "disnake.Intents.messages": "api/clients.html#disnake.Intents.messages", "disnake.Intents.guild_messages": "api/clients.html#disnake.Intents.guild_messages", "disnake.Intents.dm_messages": "api/clients.html#disnake.Intents.dm_messages", "disnake.Intents.message_content": "api/clients.html#disnake.Intents.message_content", "disnake.Intents.reactions": "api/clients.html#disnake.Intents.reactions", "disnake.Intents.guild_reactions": "api/clients.html#disnake.Intents.guild_reactions", "disnake.Intents.dm_reactions": "api/clients.html#disnake.Intents.dm_reactions", "disnake.Intents.typing": "api/clients.html#disnake.Intents.typing", "disnake.Intents.guild_typing": "api/clients.html#disnake.Intents.guild_typing", "disnake.Intents.dm_typing": "api/clients.html#disnake.Intents.dm_typing", "disnake.Intents.guild_scheduled_events": "api/clients.html#disnake.Intents.guild_scheduled_events", "disnake.Intents.automod_configuration": "api/clients.html#disnake.Intents.automod_configuration", "disnake.Intents.automod_execution": "api/clients.html#disnake.Intents.automod_execution", "disnake.Intents.automod": "api/clients.html#disnake.Intents.automod", "disnake.MemberCacheFlags": "api/clients.html#disnake.MemberCacheFlags", "disnake.MemberCacheFlags.value": "api/clients.html#disnake.MemberCacheFlags.value", "disnake.MemberCacheFlags.all": "api/clients.html#disnake.MemberCacheFlags.all", "disnake.MemberCacheFlags.none": "api/clients.html#disnake.MemberCacheFlags.none", "disnake.MemberCacheFlags.voice": "api/clients.html#disnake.MemberCacheFlags.voice", "disnake.MemberCacheFlags.joined": "api/clients.html#disnake.MemberCacheFlags.joined", "disnake.MemberCacheFlags.from_intents": "api/clients.html#disnake.MemberCacheFlags.from_intents", "disnake.Component": "api/components.html#disnake.Component", "disnake.Component.type": "api/components.html#disnake.Component.type", "disnake.ActionRow": "api/components.html#disnake.ActionRow", "disnake.ActionRow.type": "api/components.html#disnake.ActionRow.type", "disnake.ActionRow.children": "api/components.html#disnake.ActionRow.children", "disnake.Button": "api/components.html#disnake.Button", "disnake.Button.style": "api/components.html#disnake.Button.style", "disnake.Button.custom_id": "api/components.html#disnake.Button.custom_id", "disnake.Button.url": "api/components.html#disnake.Button.url", "disnake.Button.disabled": "api/components.html#disnake.Button.disabled", "disnake.Button.label": "api/components.html#disnake.Button.label", "disnake.Button.emoji": "api/components.html#disnake.Button.emoji", "disnake.BaseSelectMenu": "api/components.html#disnake.BaseSelectMenu", "disnake.BaseSelectMenu.custom_id": "api/components.html#disnake.BaseSelectMenu.custom_id", "disnake.BaseSelectMenu.placeholder": "api/components.html#disnake.BaseSelectMenu.placeholder", "disnake.BaseSelectMenu.min_values": "api/components.html#disnake.BaseSelectMenu.min_values", "disnake.BaseSelectMenu.max_values": "api/components.html#disnake.BaseSelectMenu.max_values", "disnake.BaseSelectMenu.options": "api/components.html#disnake.BaseSelectMenu.options", "disnake.BaseSelectMenu.disabled": "api/components.html#disnake.BaseSelectMenu.disabled", "disnake.SelectMenu": "api/components.html#disnake.SelectMenu", "disnake.SelectMenu.custom_id": "api/components.html#disnake.SelectMenu.custom_id", "disnake.SelectMenu.placeholder": "api/components.html#disnake.SelectMenu.placeholder", "disnake.SelectMenu.min_values": "api/components.html#disnake.SelectMenu.min_values", "disnake.SelectMenu.max_values": "api/components.html#disnake.SelectMenu.max_values", "disnake.SelectMenu.disabled": "api/components.html#disnake.SelectMenu.disabled", "disnake.SelectMenu.options": "api/components.html#disnake.SelectMenu.options", "disnake.SelectOption": "api/components.html#disnake.SelectOption", "disnake.SelectOption.label": "api/components.html#disnake.SelectOption.label", "disnake.SelectOption.value": "api/components.html#disnake.SelectOption.value", "disnake.SelectOption.description": "api/components.html#disnake.SelectOption.description", "disnake.SelectOption.emoji": "api/components.html#disnake.SelectOption.emoji", "disnake.SelectOption.default": "api/components.html#disnake.SelectOption.default", "disnake.TextInput": "api/components.html#disnake.TextInput", "disnake.TextInput.style": "api/components.html#disnake.TextInput.style", "disnake.TextInput.label": "api/components.html#disnake.TextInput.label", "disnake.TextInput.custom_id": "api/components.html#disnake.TextInput.custom_id", "disnake.TextInput.placeholder": "api/components.html#disnake.TextInput.placeholder", "disnake.TextInput.value": "api/components.html#disnake.TextInput.value", "disnake.TextInput.required": "api/components.html#disnake.TextInput.required", "disnake.TextInput.min_length": "api/components.html#disnake.TextInput.min_length", "disnake.TextInput.max_length": "api/components.html#disnake.TextInput.max_length", "disnake.ComponentType": "api/components.html#disnake.ComponentType", "disnake.ComponentType.action_row": "api/components.html#disnake.ComponentType.action_row", "disnake.ComponentType.button": "api/components.html#disnake.ComponentType.button", "disnake.ComponentType.select": "api/components.html#disnake.ComponentType.select", "disnake.ComponentType.text_input": "api/components.html#disnake.ComponentType.text_input", "disnake.ButtonStyle": "api/components.html#disnake.ButtonStyle", "disnake.ButtonStyle.primary": "api/components.html#disnake.ButtonStyle.primary", "disnake.ButtonStyle.secondary": "api/components.html#disnake.ButtonStyle.secondary", "disnake.ButtonStyle.success": "api/components.html#disnake.ButtonStyle.success", "disnake.ButtonStyle.danger": "api/components.html#disnake.ButtonStyle.danger", "disnake.ButtonStyle.link": "api/components.html#disnake.ButtonStyle.link", "disnake.ButtonStyle.blurple": "api/components.html#disnake.ButtonStyle.blurple", "disnake.ButtonStyle.grey": "api/components.html#disnake.ButtonStyle.grey", "disnake.ButtonStyle.gray": "api/components.html#disnake.ButtonStyle.gray", "disnake.ButtonStyle.green": "api/components.html#disnake.ButtonStyle.green", "disnake.ButtonStyle.red": "api/components.html#disnake.ButtonStyle.red", "disnake.ButtonStyle.url": "api/components.html#disnake.ButtonStyle.url", "disnake.TextInputStyle": "api/components.html#disnake.TextInputStyle", "disnake.TextInputStyle.short": "api/components.html#disnake.TextInputStyle.short", "disnake.TextInputStyle.paragraph": "api/components.html#disnake.TextInputStyle.paragraph", "disnake.TextInputStyle.single_line": "api/components.html#disnake.TextInputStyle.single_line", "disnake.TextInputStyle.multi_line": "api/components.html#disnake.TextInputStyle.multi_line", "disnake.TextInputStyle.long": "api/components.html#disnake.TextInputStyle.long", "disnake.Emoji": "api/emoji.html#disnake.Emoji", "disnake.Emoji.name": "api/emoji.html#disnake.Emoji.name", "disnake.Emoji.id": "api/emoji.html#disnake.Emoji.id", "disnake.Emoji.require_colons": "api/emoji.html#disnake.Emoji.require_colons", "disnake.Emoji.animated": "api/emoji.html#disnake.Emoji.animated", "disnake.Emoji.managed": "api/emoji.html#disnake.Emoji.managed", "disnake.Emoji.guild_id": "api/emoji.html#disnake.Emoji.guild_id", "disnake.Emoji.available": "api/emoji.html#disnake.Emoji.available", "disnake.Emoji.user": "api/emoji.html#disnake.Emoji.user", "disnake.Emoji.created_at": "api/emoji.html#disnake.Emoji.created_at", "disnake.Emoji.url": "api/emoji.html#disnake.Emoji.url", "disnake.Emoji.roles": "api/emoji.html#disnake.Emoji.roles", "disnake.Emoji.guild": "api/emoji.html#disnake.Emoji.guild", "disnake.Emoji.is_usable": "api/emoji.html#disnake.Emoji.is_usable", "disnake.Emoji.delete": "api/emoji.html#disnake.Emoji.delete", "disnake.Emoji.edit": "api/emoji.html#disnake.Emoji.edit", "disnake.Emoji.read": "api/emoji.html#disnake.Emoji.read", "disnake.Emoji.save": "api/emoji.html#disnake.Emoji.save", "disnake.Emoji.to_file": "api/emoji.html#disnake.Emoji.to_file", "disnake.PartialEmoji": "api/emoji.html#disnake.PartialEmoji", "disnake.PartialEmoji.name": "api/emoji.html#disnake.PartialEmoji.name", "disnake.PartialEmoji.animated": "api/emoji.html#disnake.PartialEmoji.animated", "disnake.PartialEmoji.id": "api/emoji.html#disnake.PartialEmoji.id", "disnake.PartialEmoji.from_str": "api/emoji.html#disnake.PartialEmoji.from_str", "disnake.PartialEmoji.is_custom_emoji": "api/emoji.html#disnake.PartialEmoji.is_custom_emoji", "disnake.PartialEmoji.is_unicode_emoji": "api/emoji.html#disnake.PartialEmoji.is_unicode_emoji", "disnake.PartialEmoji.created_at": "api/emoji.html#disnake.PartialEmoji.created_at", "disnake.PartialEmoji.url": "api/emoji.html#disnake.PartialEmoji.url", "disnake.PartialEmoji.read": "api/emoji.html#disnake.PartialEmoji.read", "disnake.PartialEmoji.save": "api/emoji.html#disnake.PartialEmoji.save", "disnake.PartialEmoji.to_file": "api/emoji.html#disnake.PartialEmoji.to_file", "disnake.on_connect": "api/events.html#disnake.on_connect", "disnake.on_disconnect": "api/events.html#disnake.on_disconnect", "disnake.on_error": "api/events.html#disnake.on_error", "disnake.on_ready": "api/events.html#disnake.on_ready", "disnake.on_resumed": "api/events.html#disnake.on_resumed", "disnake.on_shard_connect": "api/events.html#disnake.on_shard_connect", "disnake.on_shard_disconnect": "api/events.html#disnake.on_shard_disconnect", "disnake.on_shard_ready": "api/events.html#disnake.on_shard_ready", "disnake.on_shard_resumed": "api/events.html#disnake.on_shard_resumed", "disnake.on_socket_event_type": "api/events.html#disnake.on_socket_event_type", "disnake.on_socket_raw_receive": "api/events.html#disnake.on_socket_raw_receive", "disnake.on_socket_raw_send": "api/events.html#disnake.on_socket_raw_send", "disnake.on_gateway_error": "api/events.html#disnake.on_gateway_error", "disnake.on_guild_channel_delete": "api/events.html#disnake.on_guild_channel_delete", "disnake.on_guild_channel_create": "api/events.html#disnake.on_guild_channel_create", "disnake.on_guild_channel_update": "api/events.html#disnake.on_guild_channel_update", "disnake.on_guild_channel_pins_update": "api/events.html#disnake.on_guild_channel_pins_update", "disnake.on_private_channel_update": "api/events.html#disnake.on_private_channel_update", "disnake.on_private_channel_pins_update": "api/events.html#disnake.on_private_channel_pins_update", "disnake.on_thread_create": "api/events.html#disnake.on_thread_create", "disnake.on_thread_join": "api/events.html#disnake.on_thread_join", "disnake.on_thread_member_join": "api/events.html#disnake.on_thread_member_join", "disnake.on_thread_member_remove": "api/events.html#disnake.on_thread_member_remove", "disnake.on_thread_remove": "api/events.html#disnake.on_thread_remove", "disnake.on_thread_update": "api/events.html#disnake.on_thread_update", "disnake.on_thread_delete": "api/events.html#disnake.on_thread_delete", "disnake.on_raw_thread_member_remove": "api/events.html#disnake.on_raw_thread_member_remove", "disnake.on_raw_thread_update": "api/events.html#disnake.on_raw_thread_update", "disnake.on_raw_thread_delete": "api/events.html#disnake.on_raw_thread_delete", "disnake.on_webhooks_update": "api/events.html#disnake.on_webhooks_update", "disnake.on_guild_join": "api/events.html#disnake.on_guild_join", "disnake.on_guild_remove": "api/events.html#disnake.on_guild_remove", "disnake.on_guild_update": "api/events.html#disnake.on_guild_update", "disnake.on_guild_available": "api/events.html#disnake.on_guild_available", "disnake.on_guild_unavailable": "api/events.html#disnake.on_guild_unavailable", "disnake.on_application_command_permissions_update": "api/events.html#disnake.on_application_command_permissions_update", "disnake.on_automod_action_execution": "api/events.html#disnake.on_automod_action_execution", "disnake.on_automod_rule_create": "api/events.html#disnake.on_automod_rule_create", "disnake.on_automod_rule_update": "api/events.html#disnake.on_automod_rule_update", "disnake.on_automod_rule_delete": "api/events.html#disnake.on_automod_rule_delete", "disnake.on_guild_emojis_update": "api/events.html#disnake.on_guild_emojis_update", "disnake.on_guild_integrations_update": "api/events.html#disnake.on_guild_integrations_update", "disnake.on_integration_create": "api/events.html#disnake.on_integration_create", "disnake.on_integration_update": "api/events.html#disnake.on_integration_update", "disnake.on_raw_integration_delete": "api/events.html#disnake.on_raw_integration_delete", "disnake.on_invite_create": "api/events.html#disnake.on_invite_create", "disnake.on_invite_delete": "api/events.html#disnake.on_invite_delete", "disnake.on_member_join": "api/events.html#disnake.on_member_join", "disnake.on_member_remove": "api/events.html#disnake.on_member_remove", "disnake.on_member_update": "api/events.html#disnake.on_member_update", "disnake.on_raw_member_remove": "api/events.html#disnake.on_raw_member_remove", "disnake.on_raw_member_update": "api/events.html#disnake.on_raw_member_update", "disnake.on_member_ban": "api/events.html#disnake.on_member_ban", "disnake.on_member_unban": "api/events.html#disnake.on_member_unban", "disnake.on_presence_update": "api/events.html#disnake.on_presence_update", "disnake.on_user_update": "api/events.html#disnake.on_user_update", "disnake.on_guild_scheduled_event_create": "api/events.html#disnake.on_guild_scheduled_event_create", "disnake.on_guild_scheduled_event_delete": "api/events.html#disnake.on_guild_scheduled_event_delete", "disnake.on_guild_scheduled_event_update": "api/events.html#disnake.on_guild_scheduled_event_update", "disnake.on_guild_scheduled_event_subscribe": "api/events.html#disnake.on_guild_scheduled_event_subscribe", "disnake.on_guild_scheduled_event_unsubscribe": "api/events.html#disnake.on_guild_scheduled_event_unsubscribe", "disnake.on_raw_guild_scheduled_event_subscribe": "api/events.html#disnake.on_raw_guild_scheduled_event_subscribe", "disnake.on_raw_guild_scheduled_event_unsubscribe": "api/events.html#disnake.on_raw_guild_scheduled_event_unsubscribe", "disnake.on_stage_instance_create": "api/events.html#disnake.on_stage_instance_create", "disnake.on_stage_instance_delete": "api/events.html#disnake.on_stage_instance_delete", "disnake.on_stage_instance_update": "api/events.html#disnake.on_stage_instance_update", "disnake.on_guild_stickers_update": "api/events.html#disnake.on_guild_stickers_update", "disnake.on_guild_role_create": "api/events.html#disnake.on_guild_role_create", "disnake.on_guild_role_delete": "api/events.html#disnake.on_guild_role_delete", "disnake.on_guild_role_update": "api/events.html#disnake.on_guild_role_update", "disnake.on_voice_state_update": "api/events.html#disnake.on_voice_state_update", "disnake.on_application_command": "api/events.html#disnake.on_application_command", "disnake.on_application_command_autocomplete": "api/events.html#disnake.on_application_command_autocomplete", "disnake.on_button_click": "api/events.html#disnake.on_button_click", "disnake.on_dropdown": "api/events.html#disnake.on_dropdown", "disnake.on_interaction": "api/events.html#disnake.on_interaction", "disnake.on_message_interaction": "api/events.html#disnake.on_message_interaction", "disnake.on_modal_submit": "api/events.html#disnake.on_modal_submit", "disnake.on_message": "api/events.html#disnake.on_message", "disnake.on_message_delete": "api/events.html#disnake.on_message_delete", "disnake.on_message_edit": "api/events.html#disnake.on_message_edit", "disnake.on_bulk_message_delete": "api/events.html#disnake.on_bulk_message_delete", "disnake.on_raw_message_delete": "api/events.html#disnake.on_raw_message_delete", "disnake.on_raw_message_edit": "api/events.html#disnake.on_raw_message_edit", "disnake.on_raw_bulk_message_delete": "api/events.html#disnake.on_raw_bulk_message_delete", "disnake.on_reaction_add": "api/events.html#disnake.on_reaction_add", "disnake.on_reaction_remove": "api/events.html#disnake.on_reaction_remove", "disnake.on_reaction_clear": "api/events.html#disnake.on_reaction_clear", "disnake.on_reaction_clear_emoji": "api/events.html#disnake.on_reaction_clear_emoji", "disnake.on_raw_reaction_add": "api/events.html#disnake.on_raw_reaction_add", "disnake.on_raw_reaction_remove": "api/events.html#disnake.on_raw_reaction_remove", "disnake.on_raw_reaction_clear": "api/events.html#disnake.on_raw_reaction_clear", "disnake.on_raw_reaction_clear_emoji": "api/events.html#disnake.on_raw_reaction_clear_emoji", "disnake.on_typing": "api/events.html#disnake.on_typing", "disnake.on_raw_typing": "api/events.html#disnake.on_raw_typing", "disnake.DiscordException": "api/exceptions.html#disnake.DiscordException", "disnake.ClientException": "api/exceptions.html#disnake.ClientException", "disnake.LoginFailure": "api/exceptions.html#disnake.LoginFailure", "disnake.NoMoreItems": "api/exceptions.html#disnake.NoMoreItems", "disnake.HTTPException": "api/exceptions.html#disnake.HTTPException", "disnake.HTTPException.response": "api/exceptions.html#disnake.HTTPException.response", "disnake.HTTPException.text": "api/exceptions.html#disnake.HTTPException.text", "disnake.HTTPException.status": "api/exceptions.html#disnake.HTTPException.status", "disnake.HTTPException.code": "api/exceptions.html#disnake.HTTPException.code", "disnake.Forbidden": "api/exceptions.html#disnake.Forbidden", "disnake.NotFound": "api/exceptions.html#disnake.NotFound", "disnake.DiscordServerError": "api/exceptions.html#disnake.DiscordServerError", "disnake.InvalidData": "api/exceptions.html#disnake.InvalidData", "disnake.WebhookTokenMissing": "api/exceptions.html#disnake.WebhookTokenMissing", "disnake.GatewayNotFound": "api/exceptions.html#disnake.GatewayNotFound", "disnake.ConnectionClosed": "api/exceptions.html#disnake.ConnectionClosed", "disnake.ConnectionClosed.code": "api/exceptions.html#disnake.ConnectionClosed.code", "disnake.ConnectionClosed.reason": "api/exceptions.html#disnake.ConnectionClosed.reason", "disnake.ConnectionClosed.shard_id": "api/exceptions.html#disnake.ConnectionClosed.shard_id", "disnake.PrivilegedIntentsRequired": "api/exceptions.html#disnake.PrivilegedIntentsRequired", "disnake.PrivilegedIntentsRequired.shard_id": "api/exceptions.html#disnake.PrivilegedIntentsRequired.shard_id", "disnake.SessionStartLimitReached": "api/exceptions.html#disnake.SessionStartLimitReached", "disnake.SessionStartLimitReached.session_start_limit": "api/exceptions.html#disnake.SessionStartLimitReached.session_start_limit", "disnake.InteractionException": "api/exceptions.html#disnake.InteractionException", "disnake.InteractionException.interaction": "api/exceptions.html#disnake.InteractionException.interaction", "disnake.InteractionResponded": "api/exceptions.html#disnake.InteractionResponded", "disnake.InteractionResponded.interaction": "api/exceptions.html#disnake.InteractionResponded.interaction", "disnake.InteractionNotResponded": "api/exceptions.html#disnake.InteractionNotResponded", "disnake.InteractionNotResponded.interaction": "api/exceptions.html#disnake.InteractionNotResponded.interaction", "disnake.InteractionTimedOut": "api/exceptions.html#disnake.InteractionTimedOut", "disnake.InteractionTimedOut.interaction": "api/exceptions.html#disnake.InteractionTimedOut.interaction", "disnake.ModalChainNotSupported": "api/exceptions.html#disnake.ModalChainNotSupported", "disnake.ModalChainNotSupported.interaction": "api/exceptions.html#disnake.ModalChainNotSupported.interaction", "disnake.LocalizationKeyError": "api/exceptions.html#disnake.LocalizationKeyError", "disnake.LocalizationKeyError.key": "api/exceptions.html#disnake.LocalizationKeyError.key", "disnake.opus.OpusError": "api/exceptions.html#disnake.opus.OpusError", "disnake.opus.OpusError.code": "api/exceptions.html#disnake.opus.OpusError.code", "disnake.opus.OpusNotLoaded": "api/exceptions.html#disnake.opus.OpusNotLoaded", "disnake.DiscordWarning": "api/exceptions.html#disnake.DiscordWarning", "disnake.ConfigWarning": "api/exceptions.html#disnake.ConfigWarning", "disnake.SyncWarning": "api/exceptions.html#disnake.SyncWarning", "disnake.LocalizationWarning": "api/exceptions.html#disnake.LocalizationWarning", "disnake.GuildScheduledEvent": "api/guild_scheduled_events.html#disnake.GuildScheduledEvent", "disnake.GuildScheduledEvent.id": "api/guild_scheduled_events.html#disnake.GuildScheduledEvent.id", "disnake.GuildScheduledEvent.guild_id": "api/guild_scheduled_events.html#disnake.GuildScheduledEvent.guild_id", "disnake.GuildScheduledEvent.channel_id": "api/guild_scheduled_events.html#disnake.GuildScheduledEvent.channel_id", "disnake.GuildScheduledEvent.creator_id": "api/guild_scheduled_events.html#disnake.GuildScheduledEvent.creator_id", "disnake.GuildScheduledEvent.creator": "api/guild_scheduled_events.html#disnake.GuildScheduledEvent.creator", "disnake.GuildScheduledEvent.name": "api/guild_scheduled_events.html#disnake.GuildScheduledEvent.name", "disnake.GuildScheduledEvent.description": "api/guild_scheduled_events.html#disnake.GuildScheduledEvent.description", "disnake.GuildScheduledEvent.scheduled_start_time": "api/guild_scheduled_events.html#disnake.GuildScheduledEvent.scheduled_start_time", "disnake.GuildScheduledEvent.scheduled_end_time": "api/guild_scheduled_events.html#disnake.GuildScheduledEvent.scheduled_end_time", "disnake.GuildScheduledEvent.privacy_level": "api/guild_scheduled_events.html#disnake.GuildScheduledEvent.privacy_level", "disnake.GuildScheduledEvent.status": "api/guild_scheduled_events.html#disnake.GuildScheduledEvent.status", "disnake.GuildScheduledEvent.entity_type": "api/guild_scheduled_events.html#disnake.GuildScheduledEvent.entity_type", "disnake.GuildScheduledEvent.entity_id": "api/guild_scheduled_events.html#disnake.GuildScheduledEvent.entity_id", "disnake.GuildScheduledEvent.entity_metadata": "api/guild_scheduled_events.html#disnake.GuildScheduledEvent.entity_metadata", "disnake.GuildScheduledEvent.user_count": "api/guild_scheduled_events.html#disnake.GuildScheduledEvent.user_count", "disnake.GuildScheduledEvent.created_at": "api/guild_scheduled_events.html#disnake.GuildScheduledEvent.created_at", "disnake.GuildScheduledEvent.url": "api/guild_scheduled_events.html#disnake.GuildScheduledEvent.url", "disnake.GuildScheduledEvent.guild": "api/guild_scheduled_events.html#disnake.GuildScheduledEvent.guild", "disnake.GuildScheduledEvent.channel": "api/guild_scheduled_events.html#disnake.GuildScheduledEvent.channel", "disnake.GuildScheduledEvent.image": "api/guild_scheduled_events.html#disnake.GuildScheduledEvent.image", "disnake.GuildScheduledEvent.delete": "api/guild_scheduled_events.html#disnake.GuildScheduledEvent.delete", "disnake.GuildScheduledEvent.edit": "api/guild_scheduled_events.html#disnake.GuildScheduledEvent.edit", "disnake.GuildScheduledEvent.start": "api/guild_scheduled_events.html#disnake.GuildScheduledEvent.start", "disnake.GuildScheduledEvent.end": "api/guild_scheduled_events.html#disnake.GuildScheduledEvent.end", "disnake.GuildScheduledEvent.cancel": "api/guild_scheduled_events.html#disnake.GuildScheduledEvent.cancel", "disnake.GuildScheduledEvent.fetch_users": "api/guild_scheduled_events.html#disnake.GuildScheduledEvent.fetch_users", "disnake.GuildScheduledEventMetadata": "api/guild_scheduled_events.html#disnake.GuildScheduledEventMetadata", "disnake.GuildScheduledEventMetadata.location": "api/guild_scheduled_events.html#disnake.GuildScheduledEventMetadata.location", "disnake.RawGuildScheduledEventUserActionEvent": "api/guild_scheduled_events.html#disnake.RawGuildScheduledEventUserActionEvent", "disnake.RawGuildScheduledEventUserActionEvent.event_id": "api/guild_scheduled_events.html#disnake.RawGuildScheduledEventUserActionEvent.event_id", "disnake.RawGuildScheduledEventUserActionEvent.user_id": "api/guild_scheduled_events.html#disnake.RawGuildScheduledEventUserActionEvent.user_id", "disnake.RawGuildScheduledEventUserActionEvent.guild_id": "api/guild_scheduled_events.html#disnake.RawGuildScheduledEventUserActionEvent.guild_id", "disnake.GuildScheduledEventEntityType": "api/guild_scheduled_events.html#disnake.GuildScheduledEventEntityType", "disnake.GuildScheduledEventEntityType.stage_instance": "api/guild_scheduled_events.html#disnake.GuildScheduledEventEntityType.stage_instance", "disnake.GuildScheduledEventEntityType.voice": "api/guild_scheduled_events.html#disnake.GuildScheduledEventEntityType.voice", "disnake.GuildScheduledEventEntityType.external": "api/guild_scheduled_events.html#disnake.GuildScheduledEventEntityType.external", "disnake.GuildScheduledEventStatus": "api/guild_scheduled_events.html#disnake.GuildScheduledEventStatus", "disnake.GuildScheduledEventStatus.scheduled": "api/guild_scheduled_events.html#disnake.GuildScheduledEventStatus.scheduled", "disnake.GuildScheduledEventStatus.active": "api/guild_scheduled_events.html#disnake.GuildScheduledEventStatus.active", "disnake.GuildScheduledEventStatus.completed": "api/guild_scheduled_events.html#disnake.GuildScheduledEventStatus.completed", "disnake.GuildScheduledEventStatus.canceled": "api/guild_scheduled_events.html#disnake.GuildScheduledEventStatus.canceled", "disnake.GuildScheduledEventStatus.cancelled": "api/guild_scheduled_events.html#disnake.GuildScheduledEventStatus.cancelled", "disnake.GuildScheduledEventPrivacyLevel": "api/guild_scheduled_events.html#disnake.GuildScheduledEventPrivacyLevel", "disnake.GuildScheduledEventPrivacyLevel.guild_only": "api/guild_scheduled_events.html#disnake.GuildScheduledEventPrivacyLevel.guild_only", "disnake.Guild": "api/guilds.html#disnake.Guild", "disnake.Guild.name": "api/guilds.html#disnake.Guild.name", "disnake.Guild.emojis": "api/guilds.html#disnake.Guild.emojis", "disnake.Guild.stickers": "api/guilds.html#disnake.Guild.stickers", "disnake.Guild.afk_timeout": "api/guilds.html#disnake.Guild.afk_timeout", "disnake.Guild.afk_channel": "api/guilds.html#disnake.Guild.afk_channel", "disnake.Guild.id": "api/guilds.html#disnake.Guild.id", "disnake.Guild.owner_id": "api/guilds.html#disnake.Guild.owner_id", "disnake.Guild.unavailable": "api/guilds.html#disnake.Guild.unavailable", "disnake.Guild.max_presences": "api/guilds.html#disnake.Guild.max_presences", "disnake.Guild.max_members": "api/guilds.html#disnake.Guild.max_members", "disnake.Guild.max_video_channel_users": "api/guilds.html#disnake.Guild.max_video_channel_users", "disnake.Guild.description": "api/guilds.html#disnake.Guild.description", "disnake.Guild.mfa_level": "api/guilds.html#disnake.Guild.mfa_level", "disnake.Guild.verification_level": "api/guilds.html#disnake.Guild.verification_level", "disnake.Guild.explicit_content_filter": "api/guilds.html#disnake.Guild.explicit_content_filter", "disnake.Guild.default_notifications": "api/guilds.html#disnake.Guild.default_notifications", "disnake.Guild.features": "api/guilds.html#disnake.Guild.features", "disnake.Guild.premium_progress_bar_enabled": "api/guilds.html#disnake.Guild.premium_progress_bar_enabled", "disnake.Guild.premium_tier": "api/guilds.html#disnake.Guild.premium_tier", "disnake.Guild.premium_subscription_count": "api/guilds.html#disnake.Guild.premium_subscription_count", "disnake.Guild.preferred_locale": "api/guilds.html#disnake.Guild.preferred_locale", "disnake.Guild.nsfw_level": "api/guilds.html#disnake.Guild.nsfw_level", "disnake.Guild.approximate_member_count": "api/guilds.html#disnake.Guild.approximate_member_count", "disnake.Guild.approximate_presence_count": "api/guilds.html#disnake.Guild.approximate_presence_count", "disnake.Guild.widget_enabled": "api/guilds.html#disnake.Guild.widget_enabled", "disnake.Guild.widget_channel_id": "api/guilds.html#disnake.Guild.widget_channel_id", "disnake.Guild.vanity_url_code": "api/guilds.html#disnake.Guild.vanity_url_code", "disnake.Guild.fetch_members": "api/guilds.html#disnake.Guild.fetch_members", "disnake.Guild.audit_logs": "api/guilds.html#disnake.Guild.audit_logs", "disnake.Guild.get_command": "api/guilds.html#disnake.Guild.get_command", "disnake.Guild.get_command_named": "api/guilds.html#disnake.Guild.get_command_named", "disnake.Guild.channels": "api/guilds.html#disnake.Guild.channels", "disnake.Guild.threads": "api/guilds.html#disnake.Guild.threads", "disnake.Guild.large": "api/guilds.html#disnake.Guild.large", "disnake.Guild.voice_channels": "api/guilds.html#disnake.Guild.voice_channels", "disnake.Guild.stage_channels": "api/guilds.html#disnake.Guild.stage_channels", "disnake.Guild.forum_channels": "api/guilds.html#disnake.Guild.forum_channels", "disnake.Guild.me": "api/guilds.html#disnake.Guild.me", "disnake.Guild.voice_client": "api/guilds.html#disnake.Guild.voice_client", "disnake.Guild.text_channels": "api/guilds.html#disnake.Guild.text_channels", "disnake.Guild.categories": "api/guilds.html#disnake.Guild.categories", "disnake.Guild.by_category": "api/guilds.html#disnake.Guild.by_category", "disnake.Guild.get_channel_or_thread": "api/guilds.html#disnake.Guild.get_channel_or_thread", "disnake.Guild.get_channel": "api/guilds.html#disnake.Guild.get_channel", "disnake.Guild.get_thread": "api/guilds.html#disnake.Guild.get_thread", "disnake.Guild.system_channel": "api/guilds.html#disnake.Guild.system_channel", "disnake.Guild.system_channel_flags": "api/guilds.html#disnake.Guild.system_channel_flags", "disnake.Guild.rules_channel": "api/guilds.html#disnake.Guild.rules_channel", "disnake.Guild.public_updates_channel": "api/guilds.html#disnake.Guild.public_updates_channel", "disnake.Guild.emoji_limit": "api/guilds.html#disnake.Guild.emoji_limit", "disnake.Guild.sticker_limit": "api/guilds.html#disnake.Guild.sticker_limit", "disnake.Guild.bitrate_limit": "api/guilds.html#disnake.Guild.bitrate_limit", "disnake.Guild.filesize_limit": "api/guilds.html#disnake.Guild.filesize_limit", "disnake.Guild.members": "api/guilds.html#disnake.Guild.members", "disnake.Guild.get_member": "api/guilds.html#disnake.Guild.get_member", "disnake.Guild.premium_subscribers": "api/guilds.html#disnake.Guild.premium_subscribers", "disnake.Guild.roles": "api/guilds.html#disnake.Guild.roles", "disnake.Guild.get_role": "api/guilds.html#disnake.Guild.get_role", "disnake.Guild.default_role": "api/guilds.html#disnake.Guild.default_role", "disnake.Guild.premium_subscriber_role": "api/guilds.html#disnake.Guild.premium_subscriber_role", "disnake.Guild.self_role": "api/guilds.html#disnake.Guild.self_role", "disnake.Guild.stage_instances": "api/guilds.html#disnake.Guild.stage_instances", "disnake.Guild.get_stage_instance": "api/guilds.html#disnake.Guild.get_stage_instance", "disnake.Guild.scheduled_events": "api/guilds.html#disnake.Guild.scheduled_events", "disnake.Guild.get_scheduled_event": "api/guilds.html#disnake.Guild.get_scheduled_event", "disnake.Guild.owner": "api/guilds.html#disnake.Guild.owner", "disnake.Guild.icon": "api/guilds.html#disnake.Guild.icon", "disnake.Guild.banner": "api/guilds.html#disnake.Guild.banner", "disnake.Guild.splash": "api/guilds.html#disnake.Guild.splash", "disnake.Guild.discovery_splash": "api/guilds.html#disnake.Guild.discovery_splash", "disnake.Guild.member_count": "api/guilds.html#disnake.Guild.member_count", "disnake.Guild.region": "api/guilds.html#disnake.Guild.region", "disnake.Guild.chunked": "api/guilds.html#disnake.Guild.chunked", "disnake.Guild.shard_id": "api/guilds.html#disnake.Guild.shard_id", "disnake.Guild.created_at": "api/guilds.html#disnake.Guild.created_at", "disnake.Guild.get_member_named": "api/guilds.html#disnake.Guild.get_member_named", "disnake.Guild.create_text_channel": "api/guilds.html#disnake.Guild.create_text_channel", "disnake.Guild.create_voice_channel": "api/guilds.html#disnake.Guild.create_voice_channel", "disnake.Guild.create_stage_channel": "api/guilds.html#disnake.Guild.create_stage_channel", "disnake.Guild.create_forum_channel": "api/guilds.html#disnake.Guild.create_forum_channel", "disnake.Guild.create_category": "api/guilds.html#disnake.Guild.create_category", "disnake.Guild.create_category_channel": "api/guilds.html#disnake.Guild.create_category_channel", "disnake.Guild.leave": "api/guilds.html#disnake.Guild.leave", "disnake.Guild.delete": "api/guilds.html#disnake.Guild.delete", "disnake.Guild.edit": "api/guilds.html#disnake.Guild.edit", "disnake.Guild.fetch_channels": "api/guilds.html#disnake.Guild.fetch_channels", "disnake.Guild.active_threads": "api/guilds.html#disnake.Guild.active_threads", "disnake.Guild.fetch_scheduled_events": "api/guilds.html#disnake.Guild.fetch_scheduled_events", "disnake.Guild.fetch_scheduled_event": "api/guilds.html#disnake.Guild.fetch_scheduled_event", "disnake.Guild.create_scheduled_event": "api/guilds.html#disnake.Guild.create_scheduled_event", "disnake.Guild.welcome_screen": "api/guilds.html#disnake.Guild.welcome_screen", "disnake.Guild.edit_welcome_screen": "api/guilds.html#disnake.Guild.edit_welcome_screen", "disnake.Guild.fetch_member": "api/guilds.html#disnake.Guild.fetch_member", "disnake.Guild.fetch_ban": "api/guilds.html#disnake.Guild.fetch_ban", "disnake.Guild.fetch_channel": "api/guilds.html#disnake.Guild.fetch_channel", "disnake.Guild.bans": "api/guilds.html#disnake.Guild.bans", "disnake.Guild.prune_members": "api/guilds.html#disnake.Guild.prune_members", "disnake.Guild.templates": "api/guilds.html#disnake.Guild.templates", "disnake.Guild.webhooks": "api/guilds.html#disnake.Guild.webhooks", "disnake.Guild.estimate_pruned_members": "api/guilds.html#disnake.Guild.estimate_pruned_members", "disnake.Guild.invites": "api/guilds.html#disnake.Guild.invites", "disnake.Guild.create_template": "api/guilds.html#disnake.Guild.create_template", "disnake.Guild.create_integration": "api/guilds.html#disnake.Guild.create_integration", "disnake.Guild.integrations": "api/guilds.html#disnake.Guild.integrations", "disnake.Guild.fetch_stickers": "api/guilds.html#disnake.Guild.fetch_stickers", "disnake.Guild.fetch_sticker": "api/guilds.html#disnake.Guild.fetch_sticker", "disnake.Guild.create_sticker": "api/guilds.html#disnake.Guild.create_sticker", "disnake.Guild.delete_sticker": "api/guilds.html#disnake.Guild.delete_sticker", "disnake.Guild.fetch_emojis": "api/guilds.html#disnake.Guild.fetch_emojis", "disnake.Guild.fetch_emoji": "api/guilds.html#disnake.Guild.fetch_emoji", "disnake.Guild.create_custom_emoji": "api/guilds.html#disnake.Guild.create_custom_emoji", "disnake.Guild.delete_emoji": "api/guilds.html#disnake.Guild.delete_emoji", "disnake.Guild.fetch_roles": "api/guilds.html#disnake.Guild.fetch_roles", "disnake.Guild.get_or_fetch_member": "api/guilds.html#disnake.Guild.get_or_fetch_member", "disnake.Guild.getch_member": "api/guilds.html#disnake.Guild.getch_member", "disnake.Guild.create_role": "api/guilds.html#disnake.Guild.create_role", "disnake.Guild.edit_role_positions": "api/guilds.html#disnake.Guild.edit_role_positions", "disnake.Guild.kick": "api/guilds.html#disnake.Guild.kick", "disnake.Guild.ban": "api/guilds.html#disnake.Guild.ban", "disnake.Guild.unban": "api/guilds.html#disnake.Guild.unban", "disnake.Guild.vanity_invite": "api/guilds.html#disnake.Guild.vanity_invite", "disnake.Guild.widget": "api/guilds.html#disnake.Guild.widget", "disnake.Guild.widget_settings": "api/guilds.html#disnake.Guild.widget_settings", "disnake.Guild.edit_widget": "api/guilds.html#disnake.Guild.edit_widget", "disnake.Guild.widget_image_url": "api/guilds.html#disnake.Guild.widget_image_url", "disnake.Guild.edit_mfa_level": "api/guilds.html#disnake.Guild.edit_mfa_level", "disnake.Guild.chunk": "api/guilds.html#disnake.Guild.chunk", "disnake.Guild.query_members": "api/guilds.html#disnake.Guild.query_members", "disnake.Guild.search_members": "api/guilds.html#disnake.Guild.search_members", "disnake.Guild.get_or_fetch_members": "api/guilds.html#disnake.Guild.get_or_fetch_members", "disnake.Guild.getch_members": "api/guilds.html#disnake.Guild.getch_members", "disnake.Guild.fetch_voice_regions": "api/guilds.html#disnake.Guild.fetch_voice_regions", "disnake.Guild.change_voice_state": "api/guilds.html#disnake.Guild.change_voice_state", "disnake.Guild.bulk_fetch_command_permissions": "api/guilds.html#disnake.Guild.bulk_fetch_command_permissions", "disnake.Guild.fetch_command_permissions": "api/guilds.html#disnake.Guild.fetch_command_permissions", "disnake.Guild.timeout": "api/guilds.html#disnake.Guild.timeout", "disnake.Guild.fetch_automod_rule": "api/guilds.html#disnake.Guild.fetch_automod_rule", "disnake.Guild.fetch_automod_rules": "api/guilds.html#disnake.Guild.fetch_automod_rules", "disnake.Guild.create_automod_rule": "api/guilds.html#disnake.Guild.create_automod_rule", "disnake.GuildPreview": "api/guilds.html#disnake.GuildPreview", "disnake.GuildPreview.name": "api/guilds.html#disnake.GuildPreview.name", "disnake.GuildPreview.emojis": "api/guilds.html#disnake.GuildPreview.emojis", "disnake.GuildPreview.stickers": "api/guilds.html#disnake.GuildPreview.stickers", "disnake.GuildPreview.id": "api/guilds.html#disnake.GuildPreview.id", "disnake.GuildPreview.description": "api/guilds.html#disnake.GuildPreview.description", "disnake.GuildPreview.features": "api/guilds.html#disnake.GuildPreview.features", "disnake.GuildPreview.approximate_member_count": "api/guilds.html#disnake.GuildPreview.approximate_member_count", "disnake.GuildPreview.approximate_presence_count": "api/guilds.html#disnake.GuildPreview.approximate_presence_count", "disnake.GuildPreview.icon": "api/guilds.html#disnake.GuildPreview.icon", "disnake.GuildPreview.splash": "api/guilds.html#disnake.GuildPreview.splash", "disnake.GuildPreview.discovery_splash": "api/guilds.html#disnake.GuildPreview.discovery_splash", "disnake.Template": "api/guilds.html#disnake.Template", "disnake.Template.code": "api/guilds.html#disnake.Template.code", "disnake.Template.uses": "api/guilds.html#disnake.Template.uses", "disnake.Template.name": "api/guilds.html#disnake.Template.name", "disnake.Template.description": "api/guilds.html#disnake.Template.description", "disnake.Template.creator": "api/guilds.html#disnake.Template.creator", "disnake.Template.created_at": "api/guilds.html#disnake.Template.created_at", "disnake.Template.updated_at": "api/guilds.html#disnake.Template.updated_at", "disnake.Template.source_guild": "api/guilds.html#disnake.Template.source_guild", "disnake.Template.is_dirty": "api/guilds.html#disnake.Template.is_dirty", "disnake.Template.create_guild": "api/guilds.html#disnake.Template.create_guild", "disnake.Template.sync": "api/guilds.html#disnake.Template.sync", "disnake.Template.edit": "api/guilds.html#disnake.Template.edit", "disnake.Template.delete": "api/guilds.html#disnake.Template.delete", "disnake.Template.url": "api/guilds.html#disnake.Template.url", "disnake.WelcomeScreen": "api/guilds.html#disnake.WelcomeScreen", "disnake.WelcomeScreen.description": "api/guilds.html#disnake.WelcomeScreen.description", "disnake.WelcomeScreen.channels": "api/guilds.html#disnake.WelcomeScreen.channels", "disnake.WelcomeScreen.enabled": "api/guilds.html#disnake.WelcomeScreen.enabled", "disnake.WelcomeScreen.edit": "api/guilds.html#disnake.WelcomeScreen.edit", "disnake.WelcomeScreenChannel": "api/guilds.html#disnake.WelcomeScreenChannel", "disnake.WelcomeScreenChannel.id": "api/guilds.html#disnake.WelcomeScreenChannel.id", "disnake.WelcomeScreenChannel.description": "api/guilds.html#disnake.WelcomeScreenChannel.description", "disnake.WelcomeScreenChannel.emoji": "api/guilds.html#disnake.WelcomeScreenChannel.emoji", "disnake.BanEntry": "api/guilds.html#disnake.BanEntry", "disnake.BanEntry.reason": "api/guilds.html#disnake.BanEntry.reason", "disnake.BanEntry.user": "api/guilds.html#disnake.BanEntry.user", "disnake.SystemChannelFlags": "api/guilds.html#disnake.SystemChannelFlags", "disnake.SystemChannelFlags.value": "api/guilds.html#disnake.SystemChannelFlags.value", "disnake.SystemChannelFlags.join_notifications": "api/guilds.html#disnake.SystemChannelFlags.join_notifications", "disnake.SystemChannelFlags.premium_subscriptions": "api/guilds.html#disnake.SystemChannelFlags.premium_subscriptions", "disnake.SystemChannelFlags.guild_reminder_notifications": "api/guilds.html#disnake.SystemChannelFlags.guild_reminder_notifications", "disnake.SystemChannelFlags.join_notification_replies": "api/guilds.html#disnake.SystemChannelFlags.join_notification_replies", "disnake.VerificationLevel": "api/guilds.html#disnake.VerificationLevel", "disnake.VerificationLevel.none": "api/guilds.html#disnake.VerificationLevel.none", "disnake.VerificationLevel.low": "api/guilds.html#disnake.VerificationLevel.low", "disnake.VerificationLevel.medium": "api/guilds.html#disnake.VerificationLevel.medium", "disnake.VerificationLevel.high": "api/guilds.html#disnake.VerificationLevel.high", "disnake.VerificationLevel.highest": "api/guilds.html#disnake.VerificationLevel.highest", "disnake.NotificationLevel": "api/guilds.html#disnake.NotificationLevel", "disnake.NotificationLevel.all_messages": "api/guilds.html#disnake.NotificationLevel.all_messages", "disnake.NotificationLevel.only_mentions": "api/guilds.html#disnake.NotificationLevel.only_mentions", "disnake.ContentFilter": "api/guilds.html#disnake.ContentFilter", "disnake.ContentFilter.disabled": "api/guilds.html#disnake.ContentFilter.disabled", "disnake.ContentFilter.no_role": "api/guilds.html#disnake.ContentFilter.no_role", "disnake.ContentFilter.all_members": "api/guilds.html#disnake.ContentFilter.all_members", "disnake.NSFWLevel": "api/guilds.html#disnake.NSFWLevel", "disnake.NSFWLevel.default": "api/guilds.html#disnake.NSFWLevel.default", "disnake.NSFWLevel.explicit": "api/guilds.html#disnake.NSFWLevel.explicit", "disnake.NSFWLevel.safe": "api/guilds.html#disnake.NSFWLevel.safe", "disnake.NSFWLevel.age_restricted": "api/guilds.html#disnake.NSFWLevel.age_restricted", "disnake.Integration": "api/integrations.html#disnake.Integration", "disnake.Integration.id": "api/integrations.html#disnake.Integration.id", "disnake.Integration.name": "api/integrations.html#disnake.Integration.name", "disnake.Integration.guild": "api/integrations.html#disnake.Integration.guild", "disnake.Integration.type": "api/integrations.html#disnake.Integration.type", "disnake.Integration.enabled": "api/integrations.html#disnake.Integration.enabled", "disnake.Integration.account": "api/integrations.html#disnake.Integration.account", "disnake.Integration.user": "api/integrations.html#disnake.Integration.user", "disnake.Integration.delete": "api/integrations.html#disnake.Integration.delete", "disnake.IntegrationAccount": "api/integrations.html#disnake.IntegrationAccount", "disnake.IntegrationAccount.id": "api/integrations.html#disnake.IntegrationAccount.id", "disnake.IntegrationAccount.name": "api/integrations.html#disnake.IntegrationAccount.name", "disnake.BotIntegration": "api/integrations.html#disnake.BotIntegration", "disnake.BotIntegration.id": "api/integrations.html#disnake.BotIntegration.id", "disnake.BotIntegration.name": "api/integrations.html#disnake.BotIntegration.name", "disnake.BotIntegration.guild": "api/integrations.html#disnake.BotIntegration.guild", "disnake.BotIntegration.type": "api/integrations.html#disnake.BotIntegration.type", "disnake.BotIntegration.enabled": "api/integrations.html#disnake.BotIntegration.enabled", "disnake.BotIntegration.user": "api/integrations.html#disnake.BotIntegration.user", "disnake.BotIntegration.account": "api/integrations.html#disnake.BotIntegration.account", "disnake.BotIntegration.application": "api/integrations.html#disnake.BotIntegration.application", "disnake.BotIntegration.scopes": "api/integrations.html#disnake.BotIntegration.scopes", "disnake.BotIntegration.delete": "api/integrations.html#disnake.BotIntegration.delete", "disnake.IntegrationApplication": "api/integrations.html#disnake.IntegrationApplication", "disnake.IntegrationApplication.id": "api/integrations.html#disnake.IntegrationApplication.id", "disnake.IntegrationApplication.name": "api/integrations.html#disnake.IntegrationApplication.name", "disnake.IntegrationApplication.icon": "api/integrations.html#disnake.IntegrationApplication.icon", "disnake.IntegrationApplication.description": "api/integrations.html#disnake.IntegrationApplication.description", "disnake.IntegrationApplication.user": "api/integrations.html#disnake.IntegrationApplication.user", "disnake.IntegrationApplication.summary": "api/integrations.html#disnake.IntegrationApplication.summary", "disnake.StreamIntegration": "api/integrations.html#disnake.StreamIntegration", "disnake.StreamIntegration.id": "api/integrations.html#disnake.StreamIntegration.id", "disnake.StreamIntegration.name": "api/integrations.html#disnake.StreamIntegration.name", "disnake.StreamIntegration.guild": "api/integrations.html#disnake.StreamIntegration.guild", "disnake.StreamIntegration.type": "api/integrations.html#disnake.StreamIntegration.type", "disnake.StreamIntegration.enabled": "api/integrations.html#disnake.StreamIntegration.enabled", "disnake.StreamIntegration.syncing": "api/integrations.html#disnake.StreamIntegration.syncing", "disnake.StreamIntegration.enable_emoticons": "api/integrations.html#disnake.StreamIntegration.enable_emoticons", "disnake.StreamIntegration.expire_behaviour": "api/integrations.html#disnake.StreamIntegration.expire_behaviour", "disnake.StreamIntegration.expire_grace_period": "api/integrations.html#disnake.StreamIntegration.expire_grace_period", "disnake.StreamIntegration.user": "api/integrations.html#disnake.StreamIntegration.user", "disnake.StreamIntegration.account": "api/integrations.html#disnake.StreamIntegration.account", "disnake.StreamIntegration.synced_at": "api/integrations.html#disnake.StreamIntegration.synced_at", "disnake.StreamIntegration.expire_behavior": "api/integrations.html#disnake.StreamIntegration.expire_behavior", "disnake.StreamIntegration.role": "api/integrations.html#disnake.StreamIntegration.role", "disnake.StreamIntegration.edit": "api/integrations.html#disnake.StreamIntegration.edit", "disnake.StreamIntegration.sync": "api/integrations.html#disnake.StreamIntegration.sync", "disnake.StreamIntegration.delete": "api/integrations.html#disnake.StreamIntegration.delete", "disnake.PartialIntegration": "api/integrations.html#disnake.PartialIntegration", "disnake.PartialIntegration.id": "api/integrations.html#disnake.PartialIntegration.id", "disnake.PartialIntegration.name": "api/integrations.html#disnake.PartialIntegration.name", "disnake.PartialIntegration.guild": "api/integrations.html#disnake.PartialIntegration.guild", "disnake.PartialIntegration.type": "api/integrations.html#disnake.PartialIntegration.type", "disnake.PartialIntegration.account": "api/integrations.html#disnake.PartialIntegration.account", "disnake.PartialIntegration.application_id": "api/integrations.html#disnake.PartialIntegration.application_id", "disnake.RawIntegrationDeleteEvent": "api/integrations.html#disnake.RawIntegrationDeleteEvent", "disnake.RawIntegrationDeleteEvent.integration_id": "api/integrations.html#disnake.RawIntegrationDeleteEvent.integration_id", "disnake.RawIntegrationDeleteEvent.application_id": "api/integrations.html#disnake.RawIntegrationDeleteEvent.application_id", "disnake.RawIntegrationDeleteEvent.guild_id": "api/integrations.html#disnake.RawIntegrationDeleteEvent.guild_id", "disnake.ExpireBehaviour": "api/integrations.html#disnake.ExpireBehaviour", "disnake.ExpireBehaviour.remove_role": "api/integrations.html#disnake.ExpireBehaviour.remove_role", "disnake.ExpireBehaviour.kick": "api/integrations.html#disnake.ExpireBehaviour.kick", "disnake.Interaction": "api/interactions.html#disnake.Interaction", "disnake.Interaction.data": "api/interactions.html#disnake.Interaction.data", "disnake.Interaction.id": "api/interactions.html#disnake.Interaction.id", "disnake.Interaction.type": "api/interactions.html#disnake.Interaction.type", "disnake.Interaction.application_id": "api/interactions.html#disnake.Interaction.application_id", "disnake.Interaction.guild_id": "api/interactions.html#disnake.Interaction.guild_id", "disnake.Interaction.guild_locale": "api/interactions.html#disnake.Interaction.guild_locale", "disnake.Interaction.channel_id": "api/interactions.html#disnake.Interaction.channel_id", "disnake.Interaction.author": "api/interactions.html#disnake.Interaction.author", "disnake.Interaction.locale": "api/interactions.html#disnake.Interaction.locale", "disnake.Interaction.token": "api/interactions.html#disnake.Interaction.token", "disnake.Interaction.client": "api/interactions.html#disnake.Interaction.client", "disnake.Interaction.original_message": "api/interactions.html#disnake.Interaction.original_message", "disnake.Interaction.edit_original_message": "api/interactions.html#disnake.Interaction.edit_original_message", "disnake.Interaction.delete_original_message": "api/interactions.html#disnake.Interaction.delete_original_message", "disnake.Interaction.bot": "api/interactions.html#disnake.Interaction.bot", "disnake.Interaction.created_at": "api/interactions.html#disnake.Interaction.created_at", "disnake.Interaction.user": "api/interactions.html#disnake.Interaction.user", "disnake.Interaction.guild": "api/interactions.html#disnake.Interaction.guild", "disnake.Interaction.me": "api/interactions.html#disnake.Interaction.me", "disnake.Interaction.channel": "api/interactions.html#disnake.Interaction.channel", "disnake.Interaction.permissions": "api/interactions.html#disnake.Interaction.permissions", "disnake.Interaction.app_permissions": "api/interactions.html#disnake.Interaction.app_permissions", "disnake.Interaction.response": "api/interactions.html#disnake.Interaction.response", "disnake.Interaction.followup": "api/interactions.html#disnake.Interaction.followup", "disnake.Interaction.expires_at": "api/interactions.html#disnake.Interaction.expires_at", "disnake.Interaction.is_expired": "api/interactions.html#disnake.Interaction.is_expired", "disnake.Interaction.original_response": "api/interactions.html#disnake.Interaction.original_response", "disnake.Interaction.edit_original_response": "api/interactions.html#disnake.Interaction.edit_original_response", "disnake.Interaction.delete_original_response": "api/interactions.html#disnake.Interaction.delete_original_response", "disnake.Interaction.send": "api/interactions.html#disnake.Interaction.send", "disnake.ApplicationCommandInteraction": "api/interactions.html#disnake.ApplicationCommandInteraction", "disnake.ApplicationCommandInteraction.id": "api/interactions.html#disnake.ApplicationCommandInteraction.id", "disnake.ApplicationCommandInteraction.type": "api/interactions.html#disnake.ApplicationCommandInteraction.type", "disnake.ApplicationCommandInteraction.application_id": "api/interactions.html#disnake.ApplicationCommandInteraction.application_id", "disnake.ApplicationCommandInteraction.guild_id": "api/interactions.html#disnake.ApplicationCommandInteraction.guild_id", "disnake.ApplicationCommandInteraction.channel_id": "api/interactions.html#disnake.ApplicationCommandInteraction.channel_id", "disnake.ApplicationCommandInteraction.author": "api/interactions.html#disnake.ApplicationCommandInteraction.author", "disnake.ApplicationCommandInteraction.locale": "api/interactions.html#disnake.ApplicationCommandInteraction.locale", "disnake.ApplicationCommandInteraction.guild_locale": "api/interactions.html#disnake.ApplicationCommandInteraction.guild_locale", "disnake.ApplicationCommandInteraction.token": "api/interactions.html#disnake.ApplicationCommandInteraction.token", "disnake.ApplicationCommandInteraction.data": "api/interactions.html#disnake.ApplicationCommandInteraction.data", "disnake.ApplicationCommandInteraction.client": "api/interactions.html#disnake.ApplicationCommandInteraction.client", "disnake.ApplicationCommandInteraction.application_command": "api/interactions.html#disnake.ApplicationCommandInteraction.application_command", "disnake.ApplicationCommandInteraction.command_failed": "api/interactions.html#disnake.ApplicationCommandInteraction.command_failed", "disnake.ApplicationCommandInteraction.original_message": "api/interactions.html#disnake.ApplicationCommandInteraction.original_message", "disnake.ApplicationCommandInteraction.edit_original_message": "api/interactions.html#disnake.ApplicationCommandInteraction.edit_original_message", "disnake.ApplicationCommandInteraction.delete_original_message": "api/interactions.html#disnake.ApplicationCommandInteraction.delete_original_message", "disnake.ApplicationCommandInteraction.target": "api/interactions.html#disnake.ApplicationCommandInteraction.target", "disnake.ApplicationCommandInteraction.options": "api/interactions.html#disnake.ApplicationCommandInteraction.options", "disnake.ApplicationCommandInteraction.filled_options": "api/interactions.html#disnake.ApplicationCommandInteraction.filled_options", "disnake.ApplicationCommandInteraction.app_permissions": "api/interactions.html#disnake.ApplicationCommandInteraction.app_permissions", "disnake.ApplicationCommandInteraction.bot": "api/interactions.html#disnake.ApplicationCommandInteraction.bot", "disnake.ApplicationCommandInteraction.channel": "api/interactions.html#disnake.ApplicationCommandInteraction.channel", "disnake.ApplicationCommandInteraction.created_at": "api/interactions.html#disnake.ApplicationCommandInteraction.created_at", "disnake.ApplicationCommandInteraction.delete_original_response": "api/interactions.html#disnake.ApplicationCommandInteraction.delete_original_response", "disnake.ApplicationCommandInteraction.edit_original_response": "api/interactions.html#disnake.ApplicationCommandInteraction.edit_original_response", "disnake.ApplicationCommandInteraction.expires_at": "api/interactions.html#disnake.ApplicationCommandInteraction.expires_at", "disnake.ApplicationCommandInteraction.followup": "api/interactions.html#disnake.ApplicationCommandInteraction.followup", "disnake.ApplicationCommandInteraction.guild": "api/interactions.html#disnake.ApplicationCommandInteraction.guild", "disnake.ApplicationCommandInteraction.is_expired": "api/interactions.html#disnake.ApplicationCommandInteraction.is_expired", "disnake.ApplicationCommandInteraction.me": "api/interactions.html#disnake.ApplicationCommandInteraction.me", "disnake.ApplicationCommandInteraction.original_response": "api/interactions.html#disnake.ApplicationCommandInteraction.original_response", "disnake.ApplicationCommandInteraction.permissions": "api/interactions.html#disnake.ApplicationCommandInteraction.permissions", "disnake.ApplicationCommandInteraction.response": "api/interactions.html#disnake.ApplicationCommandInteraction.response", "disnake.ApplicationCommandInteraction.send": "api/interactions.html#disnake.ApplicationCommandInteraction.send", "disnake.ApplicationCommandInteraction.user": "api/interactions.html#disnake.ApplicationCommandInteraction.user", "disnake.GuildCommandInteraction": "api/interactions.html#disnake.GuildCommandInteraction", "disnake.UserCommandInteraction": "api/interactions.html#disnake.UserCommandInteraction", "disnake.MessageCommandInteraction": "api/interactions.html#disnake.MessageCommandInteraction", "disnake.MessageInteraction": "api/interactions.html#disnake.MessageInteraction", "disnake.MessageInteraction.id": "api/interactions.html#disnake.MessageInteraction.id", "disnake.MessageInteraction.type": "api/interactions.html#disnake.MessageInteraction.type", "disnake.MessageInteraction.application_id": "api/interactions.html#disnake.MessageInteraction.application_id", "disnake.MessageInteraction.token": "api/interactions.html#disnake.MessageInteraction.token", "disnake.MessageInteraction.guild_id": "api/interactions.html#disnake.MessageInteraction.guild_id", "disnake.MessageInteraction.channel_id": "api/interactions.html#disnake.MessageInteraction.channel_id", "disnake.MessageInteraction.author": "api/interactions.html#disnake.MessageInteraction.author", "disnake.MessageInteraction.locale": "api/interactions.html#disnake.MessageInteraction.locale", "disnake.MessageInteraction.guild_locale": "api/interactions.html#disnake.MessageInteraction.guild_locale", "disnake.MessageInteraction.message": "api/interactions.html#disnake.MessageInteraction.message", "disnake.MessageInteraction.data": "api/interactions.html#disnake.MessageInteraction.data", "disnake.MessageInteraction.client": "api/interactions.html#disnake.MessageInteraction.client", "disnake.MessageInteraction.original_message": "api/interactions.html#disnake.MessageInteraction.original_message", "disnake.MessageInteraction.edit_original_message": "api/interactions.html#disnake.MessageInteraction.edit_original_message", "disnake.MessageInteraction.delete_original_message": "api/interactions.html#disnake.MessageInteraction.delete_original_message", "disnake.MessageInteraction.values": "api/interactions.html#disnake.MessageInteraction.values", "disnake.MessageInteraction.component": "api/interactions.html#disnake.MessageInteraction.component", "disnake.MessageInteraction.app_permissions": "api/interactions.html#disnake.MessageInteraction.app_permissions", "disnake.MessageInteraction.bot": "api/interactions.html#disnake.MessageInteraction.bot", "disnake.MessageInteraction.channel": "api/interactions.html#disnake.MessageInteraction.channel", "disnake.MessageInteraction.created_at": "api/interactions.html#disnake.MessageInteraction.created_at", "disnake.MessageInteraction.delete_original_response": "api/interactions.html#disnake.MessageInteraction.delete_original_response", "disnake.MessageInteraction.edit_original_response": "api/interactions.html#disnake.MessageInteraction.edit_original_response", "disnake.MessageInteraction.expires_at": "api/interactions.html#disnake.MessageInteraction.expires_at", "disnake.MessageInteraction.followup": "api/interactions.html#disnake.MessageInteraction.followup", "disnake.MessageInteraction.guild": "api/interactions.html#disnake.MessageInteraction.guild", "disnake.MessageInteraction.is_expired": "api/interactions.html#disnake.MessageInteraction.is_expired", "disnake.MessageInteraction.me": "api/interactions.html#disnake.MessageInteraction.me", "disnake.MessageInteraction.original_response": "api/interactions.html#disnake.MessageInteraction.original_response", "disnake.MessageInteraction.permissions": "api/interactions.html#disnake.MessageInteraction.permissions", "disnake.MessageInteraction.response": "api/interactions.html#disnake.MessageInteraction.response", "disnake.MessageInteraction.send": "api/interactions.html#disnake.MessageInteraction.send", "disnake.MessageInteraction.user": "api/interactions.html#disnake.MessageInteraction.user", "disnake.ModalInteraction": "api/interactions.html#disnake.ModalInteraction", "disnake.ModalInteraction.id": "api/interactions.html#disnake.ModalInteraction.id", "disnake.ModalInteraction.type": "api/interactions.html#disnake.ModalInteraction.type", "disnake.ModalInteraction.application_id": "api/interactions.html#disnake.ModalInteraction.application_id", "disnake.ModalInteraction.token": "api/interactions.html#disnake.ModalInteraction.token", "disnake.ModalInteraction.guild_id": "api/interactions.html#disnake.ModalInteraction.guild_id", "disnake.ModalInteraction.channel_id": "api/interactions.html#disnake.ModalInteraction.channel_id", "disnake.ModalInteraction.author": "api/interactions.html#disnake.ModalInteraction.author", "disnake.ModalInteraction.locale": "api/interactions.html#disnake.ModalInteraction.locale", "disnake.ModalInteraction.guild_locale": "api/interactions.html#disnake.ModalInteraction.guild_locale", "disnake.ModalInteraction.message": "api/interactions.html#disnake.ModalInteraction.message", "disnake.ModalInteraction.data": "api/interactions.html#disnake.ModalInteraction.data", "disnake.ModalInteraction.client": "api/interactions.html#disnake.ModalInteraction.client", "disnake.ModalInteraction.original_message": "api/interactions.html#disnake.ModalInteraction.original_message", "disnake.ModalInteraction.edit_original_message": "api/interactions.html#disnake.ModalInteraction.edit_original_message", "disnake.ModalInteraction.delete_original_message": "api/interactions.html#disnake.ModalInteraction.delete_original_message", "disnake.ModalInteraction.walk_raw_components": "api/interactions.html#disnake.ModalInteraction.walk_raw_components", "disnake.ModalInteraction.text_values": "api/interactions.html#disnake.ModalInteraction.text_values", "disnake.ModalInteraction.custom_id": "api/interactions.html#disnake.ModalInteraction.custom_id", "disnake.ModalInteraction.app_permissions": "api/interactions.html#disnake.ModalInteraction.app_permissions", "disnake.ModalInteraction.bot": "api/interactions.html#disnake.ModalInteraction.bot", "disnake.ModalInteraction.channel": "api/interactions.html#disnake.ModalInteraction.channel", "disnake.ModalInteraction.created_at": "api/interactions.html#disnake.ModalInteraction.created_at", "disnake.ModalInteraction.delete_original_response": "api/interactions.html#disnake.ModalInteraction.delete_original_response", "disnake.ModalInteraction.edit_original_response": "api/interactions.html#disnake.ModalInteraction.edit_original_response", "disnake.ModalInteraction.expires_at": "api/interactions.html#disnake.ModalInteraction.expires_at", "disnake.ModalInteraction.followup": "api/interactions.html#disnake.ModalInteraction.followup", "disnake.ModalInteraction.guild": "api/interactions.html#disnake.ModalInteraction.guild", "disnake.ModalInteraction.is_expired": "api/interactions.html#disnake.ModalInteraction.is_expired", "disnake.ModalInteraction.me": "api/interactions.html#disnake.ModalInteraction.me", "disnake.ModalInteraction.original_response": "api/interactions.html#disnake.ModalInteraction.original_response", "disnake.ModalInteraction.permissions": "api/interactions.html#disnake.ModalInteraction.permissions", "disnake.ModalInteraction.response": "api/interactions.html#disnake.ModalInteraction.response", "disnake.ModalInteraction.send": "api/interactions.html#disnake.ModalInteraction.send", "disnake.ModalInteraction.user": "api/interactions.html#disnake.ModalInteraction.user", "disnake.InteractionResponse": "api/interactions.html#disnake.InteractionResponse", "disnake.InteractionResponse.type": "api/interactions.html#disnake.InteractionResponse.type", "disnake.InteractionResponse.is_done": "api/interactions.html#disnake.InteractionResponse.is_done", "disnake.InteractionResponse.defer": "api/interactions.html#disnake.InteractionResponse.defer", "disnake.InteractionResponse.pong": "api/interactions.html#disnake.InteractionResponse.pong", "disnake.InteractionResponse.send_message": "api/interactions.html#disnake.InteractionResponse.send_message", "disnake.InteractionResponse.edit_message": "api/interactions.html#disnake.InteractionResponse.edit_message", "disnake.InteractionResponse.autocomplete": "api/interactions.html#disnake.InteractionResponse.autocomplete", "disnake.InteractionResponse.send_modal": "api/interactions.html#disnake.InteractionResponse.send_modal", "disnake.InteractionMessage": "api/interactions.html#disnake.InteractionMessage", "disnake.InteractionMessage.type": "api/interactions.html#disnake.InteractionMessage.type", "disnake.InteractionMessage.author": "api/interactions.html#disnake.InteractionMessage.author", "disnake.InteractionMessage.content": "api/interactions.html#disnake.InteractionMessage.content", "disnake.InteractionMessage.embeds": "api/interactions.html#disnake.InteractionMessage.embeds", "disnake.InteractionMessage.channel": "api/interactions.html#disnake.InteractionMessage.channel", "disnake.InteractionMessage.reference": "api/interactions.html#disnake.InteractionMessage.reference", "disnake.InteractionMessage.interaction": "api/interactions.html#disnake.InteractionMessage.interaction", "disnake.InteractionMessage.mention_everyone": "api/interactions.html#disnake.InteractionMessage.mention_everyone", "disnake.InteractionMessage.mentions": "api/interactions.html#disnake.InteractionMessage.mentions", "disnake.InteractionMessage.role_mentions": "api/interactions.html#disnake.InteractionMessage.role_mentions", "disnake.InteractionMessage.id": "api/interactions.html#disnake.InteractionMessage.id", "disnake.InteractionMessage.webhook_id": "api/interactions.html#disnake.InteractionMessage.webhook_id", "disnake.InteractionMessage.attachments": "api/interactions.html#disnake.InteractionMessage.attachments", "disnake.InteractionMessage.pinned": "api/interactions.html#disnake.InteractionMessage.pinned", "disnake.InteractionMessage.flags": "api/interactions.html#disnake.InteractionMessage.flags", "disnake.InteractionMessage.reactions": "api/interactions.html#disnake.InteractionMessage.reactions", "disnake.InteractionMessage.stickers": "api/interactions.html#disnake.InteractionMessage.stickers", "disnake.InteractionMessage.components": "api/interactions.html#disnake.InteractionMessage.components", "disnake.InteractionMessage.guild": "api/interactions.html#disnake.InteractionMessage.guild", "disnake.InteractionMessage.add_reaction": "api/interactions.html#disnake.InteractionMessage.add_reaction", "disnake.InteractionMessage.channel_mentions": "api/interactions.html#disnake.InteractionMessage.channel_mentions", "disnake.InteractionMessage.clean_content": "api/interactions.html#disnake.InteractionMessage.clean_content", "disnake.InteractionMessage.clear_reaction": "api/interactions.html#disnake.InteractionMessage.clear_reaction", "disnake.InteractionMessage.clear_reactions": "api/interactions.html#disnake.InteractionMessage.clear_reactions", "disnake.InteractionMessage.create_thread": "api/interactions.html#disnake.InteractionMessage.create_thread", "disnake.InteractionMessage.created_at": "api/interactions.html#disnake.InteractionMessage.created_at", "disnake.InteractionMessage.edited_at": "api/interactions.html#disnake.InteractionMessage.edited_at", "disnake.InteractionMessage.is_system": "api/interactions.html#disnake.InteractionMessage.is_system", "disnake.InteractionMessage.jump_url": "api/interactions.html#disnake.InteractionMessage.jump_url", "disnake.InteractionMessage.pin": "api/interactions.html#disnake.InteractionMessage.pin", "disnake.InteractionMessage.publish": "api/interactions.html#disnake.InteractionMessage.publish", "disnake.InteractionMessage.raw_channel_mentions": "api/interactions.html#disnake.InteractionMessage.raw_channel_mentions", "disnake.InteractionMessage.raw_mentions": "api/interactions.html#disnake.InteractionMessage.raw_mentions", "disnake.InteractionMessage.raw_role_mentions": "api/interactions.html#disnake.InteractionMessage.raw_role_mentions", "disnake.InteractionMessage.remove_reaction": "api/interactions.html#disnake.InteractionMessage.remove_reaction", "disnake.InteractionMessage.reply": "api/interactions.html#disnake.InteractionMessage.reply", "disnake.InteractionMessage.system_content": "api/interactions.html#disnake.InteractionMessage.system_content", "disnake.InteractionMessage.thread": "api/interactions.html#disnake.InteractionMessage.thread", "disnake.InteractionMessage.to_reference": "api/interactions.html#disnake.InteractionMessage.to_reference", "disnake.InteractionMessage.unpin": "api/interactions.html#disnake.InteractionMessage.unpin", "disnake.InteractionMessage.edit": "api/interactions.html#disnake.InteractionMessage.edit", "disnake.InteractionMessage.delete": "api/interactions.html#disnake.InteractionMessage.delete", "disnake.InteractionReference": "api/interactions.html#disnake.InteractionReference", "disnake.InteractionReference.id": "api/interactions.html#disnake.InteractionReference.id", "disnake.InteractionReference.type": "api/interactions.html#disnake.InteractionReference.type", "disnake.InteractionReference.name": "api/interactions.html#disnake.InteractionReference.name", "disnake.InteractionReference.user": "api/interactions.html#disnake.InteractionReference.user", "disnake.ApplicationCommandInteractionData": "api/interactions.html#disnake.ApplicationCommandInteractionData", "disnake.ApplicationCommandInteractionData.id": "api/interactions.html#disnake.ApplicationCommandInteractionData.id", "disnake.ApplicationCommandInteractionData.name": "api/interactions.html#disnake.ApplicationCommandInteractionData.name", "disnake.ApplicationCommandInteractionData.type": "api/interactions.html#disnake.ApplicationCommandInteractionData.type", "disnake.ApplicationCommandInteractionData.resolved": "api/interactions.html#disnake.ApplicationCommandInteractionData.resolved", "disnake.ApplicationCommandInteractionData.options": "api/interactions.html#disnake.ApplicationCommandInteractionData.options", "disnake.ApplicationCommandInteractionData.target_id": "api/interactions.html#disnake.ApplicationCommandInteractionData.target_id", "disnake.ApplicationCommandInteractionData.target": "api/interactions.html#disnake.ApplicationCommandInteractionData.target", "disnake.ApplicationCommandInteractionData.focused_option": "api/interactions.html#disnake.ApplicationCommandInteractionData.focused_option", "disnake.ApplicationCommandInteractionDataOption": "api/interactions.html#disnake.ApplicationCommandInteractionDataOption", "disnake.ApplicationCommandInteractionDataOption.name": "api/interactions.html#disnake.ApplicationCommandInteractionDataOption.name", "disnake.ApplicationCommandInteractionDataOption.type": "api/interactions.html#disnake.ApplicationCommandInteractionDataOption.type", "disnake.ApplicationCommandInteractionDataOption.value": "api/interactions.html#disnake.ApplicationCommandInteractionDataOption.value", "disnake.ApplicationCommandInteractionDataOption.options": "api/interactions.html#disnake.ApplicationCommandInteractionDataOption.options", "disnake.ApplicationCommandInteractionDataOption.focused": "api/interactions.html#disnake.ApplicationCommandInteractionDataOption.focused", "disnake.ApplicationCommandInteractionDataResolved": "api/interactions.html#disnake.ApplicationCommandInteractionDataResolved", "disnake.ApplicationCommandInteractionDataResolved.members": "api/interactions.html#disnake.ApplicationCommandInteractionDataResolved.members", "disnake.ApplicationCommandInteractionDataResolved.users": "api/interactions.html#disnake.ApplicationCommandInteractionDataResolved.users", "disnake.ApplicationCommandInteractionDataResolved.roles": "api/interactions.html#disnake.ApplicationCommandInteractionDataResolved.roles", "disnake.ApplicationCommandInteractionDataResolved.channels": "api/interactions.html#disnake.ApplicationCommandInteractionDataResolved.channels", "disnake.ApplicationCommandInteractionDataResolved.messages": "api/interactions.html#disnake.ApplicationCommandInteractionDataResolved.messages", "disnake.ApplicationCommandInteractionDataResolved.attachments": "api/interactions.html#disnake.ApplicationCommandInteractionDataResolved.attachments", "disnake.ApplicationCommandInteractionDataResolved.get": "api/interactions.html#disnake.ApplicationCommandInteractionDataResolved.get", "disnake.MessageInteractionData": "api/interactions.html#disnake.MessageInteractionData", "disnake.MessageInteractionData.custom_id": "api/interactions.html#disnake.MessageInteractionData.custom_id", "disnake.MessageInteractionData.component_type": "api/interactions.html#disnake.MessageInteractionData.component_type", "disnake.MessageInteractionData.values": "api/interactions.html#disnake.MessageInteractionData.values", "disnake.ModalInteractionData": "api/interactions.html#disnake.ModalInteractionData", "disnake.ModalInteractionData.custom_id": "api/interactions.html#disnake.ModalInteractionData.custom_id", "disnake.ModalInteractionData.components": "api/interactions.html#disnake.ModalInteractionData.components", "disnake.InteractionType": "api/interactions.html#disnake.InteractionType", "disnake.InteractionType.ping": "api/interactions.html#disnake.InteractionType.ping", "disnake.InteractionType.application_command": "api/interactions.html#disnake.InteractionType.application_command", "disnake.InteractionType.component": "api/interactions.html#disnake.InteractionType.component", "disnake.InteractionType.application_command_autocomplete": "api/interactions.html#disnake.InteractionType.application_command_autocomplete", "disnake.InteractionType.modal_submit": "api/interactions.html#disnake.InteractionType.modal_submit", "disnake.InteractionResponseType": "api/interactions.html#disnake.InteractionResponseType", "disnake.InteractionResponseType.pong": "api/interactions.html#disnake.InteractionResponseType.pong", "disnake.InteractionResponseType.channel_message": "api/interactions.html#disnake.InteractionResponseType.channel_message", "disnake.InteractionResponseType.deferred_channel_message": "api/interactions.html#disnake.InteractionResponseType.deferred_channel_message", "disnake.InteractionResponseType.deferred_message_update": "api/interactions.html#disnake.InteractionResponseType.deferred_message_update", "disnake.InteractionResponseType.message_update": "api/interactions.html#disnake.InteractionResponseType.message_update", "disnake.InteractionResponseType.application_command_autocomplete_result": "api/interactions.html#disnake.InteractionResponseType.application_command_autocomplete_result", "disnake.InteractionResponseType.modal": "api/interactions.html#disnake.InteractionResponseType.modal", "disnake.Invite": "api/invites.html#disnake.Invite", "disnake.Invite.max_age": "api/invites.html#disnake.Invite.max_age", "disnake.Invite.code": "api/invites.html#disnake.Invite.code", "disnake.Invite.guild": "api/invites.html#disnake.Invite.guild", "disnake.Invite.created_at": "api/invites.html#disnake.Invite.created_at", "disnake.Invite.temporary": "api/invites.html#disnake.Invite.temporary", "disnake.Invite.uses": "api/invites.html#disnake.Invite.uses", "disnake.Invite.max_uses": "api/invites.html#disnake.Invite.max_uses", "disnake.Invite.inviter": "api/invites.html#disnake.Invite.inviter", "disnake.Invite.approximate_member_count": "api/invites.html#disnake.Invite.approximate_member_count", "disnake.Invite.approximate_presence_count": "api/invites.html#disnake.Invite.approximate_presence_count", "disnake.Invite.expires_at": "api/invites.html#disnake.Invite.expires_at", "disnake.Invite.channel": "api/invites.html#disnake.Invite.channel", "disnake.Invite.target_type": "api/invites.html#disnake.Invite.target_type", "disnake.Invite.target_user": "api/invites.html#disnake.Invite.target_user", "disnake.Invite.target_application": "api/invites.html#disnake.Invite.target_application", "disnake.Invite.guild_scheduled_event": "api/invites.html#disnake.Invite.guild_scheduled_event", "disnake.Invite.guild_welcome_screen": "api/invites.html#disnake.Invite.guild_welcome_screen", "disnake.Invite.id": "api/invites.html#disnake.Invite.id", "disnake.Invite.url": "api/invites.html#disnake.Invite.url", "disnake.Invite.delete": "api/invites.html#disnake.Invite.delete", "disnake.PartialInviteGuild": "api/invites.html#disnake.PartialInviteGuild", "disnake.PartialInviteGuild.name": "api/invites.html#disnake.PartialInviteGuild.name", "disnake.PartialInviteGuild.id": "api/invites.html#disnake.PartialInviteGuild.id", "disnake.PartialInviteGuild.description": "api/invites.html#disnake.PartialInviteGuild.description", "disnake.PartialInviteGuild.features": "api/invites.html#disnake.PartialInviteGuild.features", "disnake.PartialInviteGuild.nsfw_level": "api/invites.html#disnake.PartialInviteGuild.nsfw_level", "disnake.PartialInviteGuild.vanity_url_code": "api/invites.html#disnake.PartialInviteGuild.vanity_url_code", "disnake.PartialInviteGuild.verification_level": "api/invites.html#disnake.PartialInviteGuild.verification_level", "disnake.PartialInviteGuild.premium_subscription_count": "api/invites.html#disnake.PartialInviteGuild.premium_subscription_count", "disnake.PartialInviteGuild.created_at": "api/invites.html#disnake.PartialInviteGuild.created_at", "disnake.PartialInviteGuild.icon": "api/invites.html#disnake.PartialInviteGuild.icon", "disnake.PartialInviteGuild.banner": "api/invites.html#disnake.PartialInviteGuild.banner", "disnake.PartialInviteGuild.splash": "api/invites.html#disnake.PartialInviteGuild.splash", "disnake.PartialInviteChannel": "api/invites.html#disnake.PartialInviteChannel", "disnake.PartialInviteChannel.name": "api/invites.html#disnake.PartialInviteChannel.name", "disnake.PartialInviteChannel.id": "api/invites.html#disnake.PartialInviteChannel.id", "disnake.PartialInviteChannel.type": "api/invites.html#disnake.PartialInviteChannel.type", "disnake.PartialInviteChannel.mention": "api/invites.html#disnake.PartialInviteChannel.mention", "disnake.PartialInviteChannel.created_at": "api/invites.html#disnake.PartialInviteChannel.created_at", "disnake.PartialInviteChannel.icon": "api/invites.html#disnake.PartialInviteChannel.icon", "disnake.InviteTarget": "api/invites.html#disnake.InviteTarget", "disnake.InviteTarget.unknown": "api/invites.html#disnake.InviteTarget.unknown", "disnake.InviteTarget.stream": "api/invites.html#disnake.InviteTarget.stream", "disnake.InviteTarget.embedded_application": "api/invites.html#disnake.InviteTarget.embedded_application", "disnake.LocalizationProtocol": "api/localization.html#disnake.LocalizationProtocol", "disnake.LocalizationProtocol.get": "api/localization.html#disnake.LocalizationProtocol.get", "disnake.LocalizationProtocol.load": "api/localization.html#disnake.LocalizationProtocol.load", "disnake.LocalizationProtocol.reload": "api/localization.html#disnake.LocalizationProtocol.reload", "disnake.LocalizationStore": "api/localization.html#disnake.LocalizationStore", "disnake.LocalizationStore.strict": "api/localization.html#disnake.LocalizationStore.strict", "disnake.LocalizationStore.get": "api/localization.html#disnake.LocalizationStore.get", "disnake.LocalizationStore.load": "api/localization.html#disnake.LocalizationStore.load", "disnake.LocalizationStore.reload": "api/localization.html#disnake.LocalizationStore.reload", "disnake.Localized": "api/localization.html#disnake.Localized", "disnake.LocalizationValue": "api/localization.html#disnake.LocalizationValue", "disnake.LocalizationValue.data": "api/localization.html#disnake.LocalizationValue.data", "disnake.Locale": "api/localization.html#disnake.Locale", "disnake.Locale.bg": "api/localization.html#disnake.Locale.bg", "disnake.Locale.cs": "api/localization.html#disnake.Locale.cs", "disnake.Locale.da": "api/localization.html#disnake.Locale.da", "disnake.Locale.de": "api/localization.html#disnake.Locale.de", "disnake.Locale.el": "api/localization.html#disnake.Locale.el", "disnake.Locale.en_GB": "api/localization.html#disnake.Locale.en_GB", "disnake.Locale.en_US": "api/localization.html#disnake.Locale.en_US", "disnake.Locale.es_ES": "api/localization.html#disnake.Locale.es_ES", "disnake.Locale.fi": "api/localization.html#disnake.Locale.fi", "disnake.Locale.fr": "api/localization.html#disnake.Locale.fr", "disnake.Locale.hi": "api/localization.html#disnake.Locale.hi", "disnake.Locale.hr": "api/localization.html#disnake.Locale.hr", "disnake.Locale.it": "api/localization.html#disnake.Locale.it", "disnake.Locale.ja": "api/localization.html#disnake.Locale.ja", "disnake.Locale.ko": "api/localization.html#disnake.Locale.ko", "disnake.Locale.lt": "api/localization.html#disnake.Locale.lt", "disnake.Locale.hu": "api/localization.html#disnake.Locale.hu", "disnake.Locale.nl": "api/localization.html#disnake.Locale.nl", "disnake.Locale.no": "api/localization.html#disnake.Locale.no", "disnake.Locale.pl": "api/localization.html#disnake.Locale.pl", "disnake.Locale.pt_BR": "api/localization.html#disnake.Locale.pt_BR", "disnake.Locale.ro": "api/localization.html#disnake.Locale.ro", "disnake.Locale.ru": "api/localization.html#disnake.Locale.ru", "disnake.Locale.sv_SE": "api/localization.html#disnake.Locale.sv_SE", "disnake.Locale.th": "api/localization.html#disnake.Locale.th", "disnake.Locale.tr": "api/localization.html#disnake.Locale.tr", "disnake.Locale.uk": "api/localization.html#disnake.Locale.uk", "disnake.Locale.vi": "api/localization.html#disnake.Locale.vi", "disnake.Locale.zh_CN": "api/localization.html#disnake.Locale.zh_CN", "disnake.Locale.zh_TW": "api/localization.html#disnake.Locale.zh_TW", "disnake.Member": "api/members.html#disnake.Member", "disnake.Member.joined_at": "api/members.html#disnake.Member.joined_at", "disnake.Member.activities": "api/members.html#disnake.Member.activities", "disnake.Member.guild": "api/members.html#disnake.Member.guild", "disnake.Member.nick": "api/members.html#disnake.Member.nick", "disnake.Member.pending": "api/members.html#disnake.Member.pending", "disnake.Member.premium_since": "api/members.html#disnake.Member.premium_since", "disnake.Member.history": "api/members.html#disnake.Member.history", "disnake.Member.typing": "api/members.html#disnake.Member.typing", "disnake.Member.name": "api/members.html#disnake.Member.name", "disnake.Member.id": "api/members.html#disnake.Member.id", "disnake.Member.bot": "api/members.html#disnake.Member.bot", "disnake.Member.system": "api/members.html#disnake.Member.system", "disnake.Member.created_at": "api/members.html#disnake.Member.created_at", "disnake.Member.default_avatar": "api/members.html#disnake.Member.default_avatar", "disnake.Member.avatar": "api/members.html#disnake.Member.avatar", "disnake.Member.dm_channel": "api/members.html#disnake.Member.dm_channel", "disnake.Member.create_dm": "api/members.html#disnake.Member.create_dm", "disnake.Member.mutual_guilds": "api/members.html#disnake.Member.mutual_guilds", "disnake.Member.public_flags": "api/members.html#disnake.Member.public_flags", "disnake.Member.banner": "api/members.html#disnake.Member.banner", "disnake.Member.accent_color": "api/members.html#disnake.Member.accent_color", "disnake.Member.accent_colour": "api/members.html#disnake.Member.accent_colour", "disnake.Member.raw_status": "api/members.html#disnake.Member.raw_status", "disnake.Member.status": "api/members.html#disnake.Member.status", "disnake.Member.mobile_status": "api/members.html#disnake.Member.mobile_status", "disnake.Member.desktop_status": "api/members.html#disnake.Member.desktop_status", "disnake.Member.web_status": "api/members.html#disnake.Member.web_status", "disnake.Member.is_on_mobile": "api/members.html#disnake.Member.is_on_mobile", "disnake.Member.colour": "api/members.html#disnake.Member.colour", "disnake.Member.color": "api/members.html#disnake.Member.color", "disnake.Member.roles": "api/members.html#disnake.Member.roles", "disnake.Member.mention": "api/members.html#disnake.Member.mention", "disnake.Member.display_name": "api/members.html#disnake.Member.display_name", "disnake.Member.display_avatar": "api/members.html#disnake.Member.display_avatar", "disnake.Member.guild_avatar": "api/members.html#disnake.Member.guild_avatar", "disnake.Member.activity": "api/members.html#disnake.Member.activity", "disnake.Member.mentioned_in": "api/members.html#disnake.Member.mentioned_in", "disnake.Member.top_role": "api/members.html#disnake.Member.top_role", "disnake.Member.role_icon": "api/members.html#disnake.Member.role_icon", "disnake.Member.guild_permissions": "api/members.html#disnake.Member.guild_permissions", "disnake.Member.voice": "api/members.html#disnake.Member.voice", "disnake.Member.current_timeout": "api/members.html#disnake.Member.current_timeout", "disnake.Member.ban": "api/members.html#disnake.Member.ban", "disnake.Member.unban": "api/members.html#disnake.Member.unban", "disnake.Member.kick": "api/members.html#disnake.Member.kick", "disnake.Member.edit": "api/members.html#disnake.Member.edit", "disnake.Member.request_to_speak": "api/members.html#disnake.Member.request_to_speak", "disnake.Member.fetch_message": "api/members.html#disnake.Member.fetch_message", "disnake.Member.move_to": "api/members.html#disnake.Member.move_to", "disnake.Member.pins": "api/members.html#disnake.Member.pins", "disnake.Member.send": "api/members.html#disnake.Member.send", "disnake.Member.trigger_typing": "api/members.html#disnake.Member.trigger_typing", "disnake.Member.add_roles": "api/members.html#disnake.Member.add_roles", "disnake.Member.remove_roles": "api/members.html#disnake.Member.remove_roles", "disnake.Member.get_role": "api/members.html#disnake.Member.get_role", "disnake.Member.timeout": "api/members.html#disnake.Member.timeout", "disnake.VoiceState": "api/members.html#disnake.VoiceState", "disnake.VoiceState.deaf": "api/members.html#disnake.VoiceState.deaf", "disnake.VoiceState.mute": "api/members.html#disnake.VoiceState.mute", "disnake.VoiceState.self_mute": "api/members.html#disnake.VoiceState.self_mute", "disnake.VoiceState.self_deaf": "api/members.html#disnake.VoiceState.self_deaf", "disnake.VoiceState.self_stream": "api/members.html#disnake.VoiceState.self_stream", "disnake.VoiceState.self_video": "api/members.html#disnake.VoiceState.self_video", "disnake.VoiceState.suppress": "api/members.html#disnake.VoiceState.suppress", "disnake.VoiceState.requested_to_speak_at": "api/members.html#disnake.VoiceState.requested_to_speak_at", "disnake.VoiceState.afk": "api/members.html#disnake.VoiceState.afk", "disnake.VoiceState.channel": "api/members.html#disnake.VoiceState.channel", "disnake.RawGuildMemberRemoveEvent": "api/members.html#disnake.RawGuildMemberRemoveEvent", "disnake.RawGuildMemberRemoveEvent.guild_id": "api/members.html#disnake.RawGuildMemberRemoveEvent.guild_id", "disnake.RawGuildMemberRemoveEvent.user": "api/members.html#disnake.RawGuildMemberRemoveEvent.user", "disnake.Message": "api/messages.html#disnake.Message", "disnake.Message.tts": "api/messages.html#disnake.Message.tts", "disnake.Message.type": "api/messages.html#disnake.Message.type", "disnake.Message.author": "api/messages.html#disnake.Message.author", "disnake.Message.content": "api/messages.html#disnake.Message.content", "disnake.Message.nonce": "api/messages.html#disnake.Message.nonce", "disnake.Message.embeds": "api/messages.html#disnake.Message.embeds", "disnake.Message.channel": "api/messages.html#disnake.Message.channel", "disnake.Message.position": "api/messages.html#disnake.Message.position", "disnake.Message.reference": "api/messages.html#disnake.Message.reference", "disnake.Message.interaction": "api/messages.html#disnake.Message.interaction", "disnake.Message.mention_everyone": "api/messages.html#disnake.Message.mention_everyone", "disnake.Message.mentions": "api/messages.html#disnake.Message.mentions", "disnake.Message.role_mentions": "api/messages.html#disnake.Message.role_mentions", "disnake.Message.id": "api/messages.html#disnake.Message.id", "disnake.Message.application_id": "api/messages.html#disnake.Message.application_id", "disnake.Message.webhook_id": "api/messages.html#disnake.Message.webhook_id", "disnake.Message.attachments": "api/messages.html#disnake.Message.attachments", "disnake.Message.pinned": "api/messages.html#disnake.Message.pinned", "disnake.Message.flags": "api/messages.html#disnake.Message.flags", "disnake.Message.reactions": "api/messages.html#disnake.Message.reactions", "disnake.Message.activity": "api/messages.html#disnake.Message.activity", "disnake.Message.application": "api/messages.html#disnake.Message.application", "disnake.Message.stickers": "api/messages.html#disnake.Message.stickers", "disnake.Message.components": "api/messages.html#disnake.Message.components", "disnake.Message.guild": "api/messages.html#disnake.Message.guild", "disnake.Message.raw_mentions": "api/messages.html#disnake.Message.raw_mentions", "disnake.Message.raw_channel_mentions": "api/messages.html#disnake.Message.raw_channel_mentions", "disnake.Message.raw_role_mentions": "api/messages.html#disnake.Message.raw_role_mentions", "disnake.Message.channel_mentions": "api/messages.html#disnake.Message.channel_mentions", "disnake.Message.clean_content": "api/messages.html#disnake.Message.clean_content", "disnake.Message.created_at": "api/messages.html#disnake.Message.created_at", "disnake.Message.edited_at": "api/messages.html#disnake.Message.edited_at", "disnake.Message.jump_url": "api/messages.html#disnake.Message.jump_url", "disnake.Message.thread": "api/messages.html#disnake.Message.thread", "disnake.Message.is_system": "api/messages.html#disnake.Message.is_system", "disnake.Message.system_content": "api/messages.html#disnake.Message.system_content", "disnake.Message.delete": "api/messages.html#disnake.Message.delete", "disnake.Message.edit": "api/messages.html#disnake.Message.edit", "disnake.Message.publish": "api/messages.html#disnake.Message.publish", "disnake.Message.pin": "api/messages.html#disnake.Message.pin", "disnake.Message.unpin": "api/messages.html#disnake.Message.unpin", "disnake.Message.add_reaction": "api/messages.html#disnake.Message.add_reaction", "disnake.Message.remove_reaction": "api/messages.html#disnake.Message.remove_reaction", "disnake.Message.clear_reaction": "api/messages.html#disnake.Message.clear_reaction", "disnake.Message.clear_reactions": "api/messages.html#disnake.Message.clear_reactions", "disnake.Message.create_thread": "api/messages.html#disnake.Message.create_thread", "disnake.Message.reply": "api/messages.html#disnake.Message.reply", "disnake.Message.to_reference": "api/messages.html#disnake.Message.to_reference", "disnake.Reaction": "api/messages.html#disnake.Reaction", "disnake.Reaction.emoji": "api/messages.html#disnake.Reaction.emoji", "disnake.Reaction.count": "api/messages.html#disnake.Reaction.count", "disnake.Reaction.me": "api/messages.html#disnake.Reaction.me", "disnake.Reaction.message": "api/messages.html#disnake.Reaction.message", "disnake.Reaction.users": "api/messages.html#disnake.Reaction.users", "disnake.Reaction.is_custom_emoji": "api/messages.html#disnake.Reaction.is_custom_emoji", "disnake.Reaction.remove": "api/messages.html#disnake.Reaction.remove", "disnake.Reaction.clear": "api/messages.html#disnake.Reaction.clear", "disnake.Attachment": "api/messages.html#disnake.Attachment", "disnake.Attachment.id": "api/messages.html#disnake.Attachment.id", "disnake.Attachment.size": "api/messages.html#disnake.Attachment.size", "disnake.Attachment.height": "api/messages.html#disnake.Attachment.height", "disnake.Attachment.width": "api/messages.html#disnake.Attachment.width", "disnake.Attachment.filename": "api/messages.html#disnake.Attachment.filename", "disnake.Attachment.url": "api/messages.html#disnake.Attachment.url", "disnake.Attachment.proxy_url": "api/messages.html#disnake.Attachment.proxy_url", "disnake.Attachment.content_type": "api/messages.html#disnake.Attachment.content_type", "disnake.Attachment.ephemeral": "api/messages.html#disnake.Attachment.ephemeral", "disnake.Attachment.description": "api/messages.html#disnake.Attachment.description", "disnake.Attachment.is_spoiler": "api/messages.html#disnake.Attachment.is_spoiler", "disnake.Attachment.save": "api/messages.html#disnake.Attachment.save", "disnake.Attachment.read": "api/messages.html#disnake.Attachment.read", "disnake.Attachment.to_file": "api/messages.html#disnake.Attachment.to_file", "disnake.DeletedReferencedMessage": "api/messages.html#disnake.DeletedReferencedMessage", "disnake.DeletedReferencedMessage.id": "api/messages.html#disnake.DeletedReferencedMessage.id", "disnake.DeletedReferencedMessage.channel_id": "api/messages.html#disnake.DeletedReferencedMessage.channel_id", "disnake.DeletedReferencedMessage.guild_id": "api/messages.html#disnake.DeletedReferencedMessage.guild_id", "disnake.Embed": "api/messages.html#disnake.Embed", "disnake.Embed.title": "api/messages.html#disnake.Embed.title", "disnake.Embed.type": "api/messages.html#disnake.Embed.type", "disnake.Embed.description": "api/messages.html#disnake.Embed.description", "disnake.Embed.url": "api/messages.html#disnake.Embed.url", "disnake.Embed.timestamp": "api/messages.html#disnake.Embed.timestamp", "disnake.Embed.colour": "api/messages.html#disnake.Embed.colour", "disnake.Embed.from_dict": "api/messages.html#disnake.Embed.from_dict", "disnake.Embed.copy": "api/messages.html#disnake.Embed.copy", "disnake.Embed.footer": "api/messages.html#disnake.Embed.footer", "disnake.Embed.set_footer": "api/messages.html#disnake.Embed.set_footer", "disnake.Embed.remove_footer": "api/messages.html#disnake.Embed.remove_footer", "disnake.Embed.image": "api/messages.html#disnake.Embed.image", "disnake.Embed.set_image": "api/messages.html#disnake.Embed.set_image", "disnake.Embed.thumbnail": "api/messages.html#disnake.Embed.thumbnail", "disnake.Embed.set_thumbnail": "api/messages.html#disnake.Embed.set_thumbnail", "disnake.Embed.video": "api/messages.html#disnake.Embed.video", "disnake.Embed.provider": "api/messages.html#disnake.Embed.provider", "disnake.Embed.author": "api/messages.html#disnake.Embed.author", "disnake.Embed.set_author": "api/messages.html#disnake.Embed.set_author", "disnake.Embed.remove_author": "api/messages.html#disnake.Embed.remove_author", "disnake.Embed.fields": "api/messages.html#disnake.Embed.fields", "disnake.Embed.add_field": "api/messages.html#disnake.Embed.add_field", "disnake.Embed.insert_field_at": "api/messages.html#disnake.Embed.insert_field_at", "disnake.Embed.clear_fields": "api/messages.html#disnake.Embed.clear_fields", "disnake.Embed.remove_field": "api/messages.html#disnake.Embed.remove_field", "disnake.Embed.set_field_at": "api/messages.html#disnake.Embed.set_field_at", "disnake.Embed.to_dict": "api/messages.html#disnake.Embed.to_dict", "disnake.Embed.set_default_colour": "api/messages.html#disnake.Embed.set_default_colour", "disnake.Embed.set_default_color": "api/messages.html#disnake.Embed.set_default_color", "disnake.Embed.get_default_colour": "api/messages.html#disnake.Embed.get_default_colour", "disnake.Embed.get_default_color": "api/messages.html#disnake.Embed.get_default_color", "disnake.Embed.check_limits": "api/messages.html#disnake.Embed.check_limits", "disnake.File": "api/messages.html#disnake.File", "disnake.File.fp": "api/messages.html#disnake.File.fp", "disnake.File.filename": "api/messages.html#disnake.File.filename", "disnake.File.spoiler": "api/messages.html#disnake.File.spoiler", "disnake.File.description": "api/messages.html#disnake.File.description", "disnake.MessageFlags": "api/messages.html#disnake.MessageFlags", "disnake.MessageFlags.value": "api/messages.html#disnake.MessageFlags.value", "disnake.MessageFlags.crossposted": "api/messages.html#disnake.MessageFlags.crossposted", "disnake.MessageFlags.is_crossposted": "api/messages.html#disnake.MessageFlags.is_crossposted", "disnake.MessageFlags.suppress_embeds": "api/messages.html#disnake.MessageFlags.suppress_embeds", "disnake.MessageFlags.source_message_deleted": "api/messages.html#disnake.MessageFlags.source_message_deleted", "disnake.MessageFlags.urgent": "api/messages.html#disnake.MessageFlags.urgent", "disnake.MessageFlags.has_thread": "api/messages.html#disnake.MessageFlags.has_thread", "disnake.MessageFlags.ephemeral": "api/messages.html#disnake.MessageFlags.ephemeral", "disnake.MessageFlags.loading": "api/messages.html#disnake.MessageFlags.loading", "disnake.MessageFlags.failed_to_mention_roles_in_thread": "api/messages.html#disnake.MessageFlags.failed_to_mention_roles_in_thread", "disnake.AllowedMentions": "api/messages.html#disnake.AllowedMentions", "disnake.AllowedMentions.everyone": "api/messages.html#disnake.AllowedMentions.everyone", "disnake.AllowedMentions.users": "api/messages.html#disnake.AllowedMentions.users", "disnake.AllowedMentions.roles": "api/messages.html#disnake.AllowedMentions.roles", "disnake.AllowedMentions.replied_user": "api/messages.html#disnake.AllowedMentions.replied_user", "disnake.AllowedMentions.all": "api/messages.html#disnake.AllowedMentions.all", "disnake.AllowedMentions.none": "api/messages.html#disnake.AllowedMentions.none", "disnake.AllowedMentions.from_message": "api/messages.html#disnake.AllowedMentions.from_message", "disnake.MessageReference": "api/messages.html#disnake.MessageReference", "disnake.MessageReference.message_id": "api/messages.html#disnake.MessageReference.message_id", "disnake.MessageReference.channel_id": "api/messages.html#disnake.MessageReference.channel_id", "disnake.MessageReference.guild_id": "api/messages.html#disnake.MessageReference.guild_id", "disnake.MessageReference.fail_if_not_exists": "api/messages.html#disnake.MessageReference.fail_if_not_exists", "disnake.MessageReference.resolved": "api/messages.html#disnake.MessageReference.resolved", "disnake.MessageReference.from_message": "api/messages.html#disnake.MessageReference.from_message", "disnake.MessageReference.cached_message": "api/messages.html#disnake.MessageReference.cached_message", "disnake.MessageReference.jump_url": "api/messages.html#disnake.MessageReference.jump_url", "disnake.PartialMessage": "api/messages.html#disnake.PartialMessage", "disnake.PartialMessage.channel": "api/messages.html#disnake.PartialMessage.channel", "disnake.PartialMessage.id": "api/messages.html#disnake.PartialMessage.id", "disnake.PartialMessage.jump_url": "api/messages.html#disnake.PartialMessage.jump_url", "disnake.PartialMessage.delete": "api/messages.html#disnake.PartialMessage.delete", "disnake.PartialMessage.publish": "api/messages.html#disnake.PartialMessage.publish", "disnake.PartialMessage.pin": "api/messages.html#disnake.PartialMessage.pin", "disnake.PartialMessage.unpin": "api/messages.html#disnake.PartialMessage.unpin", "disnake.PartialMessage.add_reaction": "api/messages.html#disnake.PartialMessage.add_reaction", "disnake.PartialMessage.remove_reaction": "api/messages.html#disnake.PartialMessage.remove_reaction", "disnake.PartialMessage.clear_reaction": "api/messages.html#disnake.PartialMessage.clear_reaction", "disnake.PartialMessage.clear_reactions": "api/messages.html#disnake.PartialMessage.clear_reactions", "disnake.PartialMessage.reply": "api/messages.html#disnake.PartialMessage.reply", "disnake.PartialMessage.to_reference": "api/messages.html#disnake.PartialMessage.to_reference", "disnake.PartialMessage.created_at": "api/messages.html#disnake.PartialMessage.created_at", "disnake.PartialMessage.guild": "api/messages.html#disnake.PartialMessage.guild", "disnake.PartialMessage.fetch": "api/messages.html#disnake.PartialMessage.fetch", "disnake.PartialMessage.edit": "api/messages.html#disnake.PartialMessage.edit", "disnake.RawTypingEvent": "api/messages.html#disnake.RawTypingEvent", "disnake.RawTypingEvent.user_id": "api/messages.html#disnake.RawTypingEvent.user_id", "disnake.RawTypingEvent.channel_id": "api/messages.html#disnake.RawTypingEvent.channel_id", "disnake.RawTypingEvent.guild_id": "api/messages.html#disnake.RawTypingEvent.guild_id", "disnake.RawTypingEvent.member": "api/messages.html#disnake.RawTypingEvent.member", "disnake.RawTypingEvent.timestamp": "api/messages.html#disnake.RawTypingEvent.timestamp", "disnake.RawMessageDeleteEvent": "api/messages.html#disnake.RawMessageDeleteEvent", "disnake.RawMessageDeleteEvent.channel_id": "api/messages.html#disnake.RawMessageDeleteEvent.channel_id", "disnake.RawMessageDeleteEvent.guild_id": "api/messages.html#disnake.RawMessageDeleteEvent.guild_id", "disnake.RawMessageDeleteEvent.message_id": "api/messages.html#disnake.RawMessageDeleteEvent.message_id", "disnake.RawMessageDeleteEvent.cached_message": "api/messages.html#disnake.RawMessageDeleteEvent.cached_message", "disnake.RawBulkMessageDeleteEvent": "api/messages.html#disnake.RawBulkMessageDeleteEvent", "disnake.RawBulkMessageDeleteEvent.message_ids": "api/messages.html#disnake.RawBulkMessageDeleteEvent.message_ids", "disnake.RawBulkMessageDeleteEvent.channel_id": "api/messages.html#disnake.RawBulkMessageDeleteEvent.channel_id", "disnake.RawBulkMessageDeleteEvent.guild_id": "api/messages.html#disnake.RawBulkMessageDeleteEvent.guild_id", "disnake.RawBulkMessageDeleteEvent.cached_messages": "api/messages.html#disnake.RawBulkMessageDeleteEvent.cached_messages", "disnake.RawMessageUpdateEvent": "api/messages.html#disnake.RawMessageUpdateEvent", "disnake.RawMessageUpdateEvent.message_id": "api/messages.html#disnake.RawMessageUpdateEvent.message_id", "disnake.RawMessageUpdateEvent.channel_id": "api/messages.html#disnake.RawMessageUpdateEvent.channel_id", "disnake.RawMessageUpdateEvent.guild_id": "api/messages.html#disnake.RawMessageUpdateEvent.guild_id", "disnake.RawMessageUpdateEvent.data": "api/messages.html#disnake.RawMessageUpdateEvent.data", "disnake.RawMessageUpdateEvent.cached_message": "api/messages.html#disnake.RawMessageUpdateEvent.cached_message", "disnake.RawReactionActionEvent": "api/messages.html#disnake.RawReactionActionEvent", "disnake.RawReactionActionEvent.message_id": "api/messages.html#disnake.RawReactionActionEvent.message_id", "disnake.RawReactionActionEvent.user_id": "api/messages.html#disnake.RawReactionActionEvent.user_id", "disnake.RawReactionActionEvent.channel_id": "api/messages.html#disnake.RawReactionActionEvent.channel_id", "disnake.RawReactionActionEvent.guild_id": "api/messages.html#disnake.RawReactionActionEvent.guild_id", "disnake.RawReactionActionEvent.emoji": "api/messages.html#disnake.RawReactionActionEvent.emoji", "disnake.RawReactionActionEvent.member": "api/messages.html#disnake.RawReactionActionEvent.member", "disnake.RawReactionActionEvent.event_type": "api/messages.html#disnake.RawReactionActionEvent.event_type", "disnake.RawReactionClearEvent": "api/messages.html#disnake.RawReactionClearEvent", "disnake.RawReactionClearEvent.message_id": "api/messages.html#disnake.RawReactionClearEvent.message_id", "disnake.RawReactionClearEvent.channel_id": "api/messages.html#disnake.RawReactionClearEvent.channel_id", "disnake.RawReactionClearEvent.guild_id": "api/messages.html#disnake.RawReactionClearEvent.guild_id", "disnake.RawReactionClearEmojiEvent": "api/messages.html#disnake.RawReactionClearEmojiEvent", "disnake.RawReactionClearEmojiEvent.message_id": "api/messages.html#disnake.RawReactionClearEmojiEvent.message_id", "disnake.RawReactionClearEmojiEvent.channel_id": "api/messages.html#disnake.RawReactionClearEmojiEvent.channel_id", "disnake.RawReactionClearEmojiEvent.guild_id": "api/messages.html#disnake.RawReactionClearEmojiEvent.guild_id", "disnake.RawReactionClearEmojiEvent.emoji": "api/messages.html#disnake.RawReactionClearEmojiEvent.emoji", "disnake.MessageType": "api/messages.html#disnake.MessageType", "disnake.MessageType.default": "api/messages.html#disnake.MessageType.default", "disnake.MessageType.recipient_add": "api/messages.html#disnake.MessageType.recipient_add", "disnake.MessageType.recipient_remove": "api/messages.html#disnake.MessageType.recipient_remove", "disnake.MessageType.call": "api/messages.html#disnake.MessageType.call", "disnake.MessageType.channel_name_change": "api/messages.html#disnake.MessageType.channel_name_change", "disnake.MessageType.channel_icon_change": "api/messages.html#disnake.MessageType.channel_icon_change", "disnake.MessageType.pins_add": "api/messages.html#disnake.MessageType.pins_add", "disnake.MessageType.new_member": "api/messages.html#disnake.MessageType.new_member", "disnake.MessageType.premium_guild_subscription": "api/messages.html#disnake.MessageType.premium_guild_subscription", "disnake.MessageType.premium_guild_tier_1": "api/messages.html#disnake.MessageType.premium_guild_tier_1", "disnake.MessageType.premium_guild_tier_2": "api/messages.html#disnake.MessageType.premium_guild_tier_2", "disnake.MessageType.premium_guild_tier_3": "api/messages.html#disnake.MessageType.premium_guild_tier_3", "disnake.MessageType.channel_follow_add": "api/messages.html#disnake.MessageType.channel_follow_add", "disnake.MessageType.guild_stream": "api/messages.html#disnake.MessageType.guild_stream", "disnake.MessageType.guild_discovery_disqualified": "api/messages.html#disnake.MessageType.guild_discovery_disqualified", "disnake.MessageType.guild_discovery_requalified": "api/messages.html#disnake.MessageType.guild_discovery_requalified", "disnake.MessageType.guild_discovery_grace_period_initial_warning": "api/messages.html#disnake.MessageType.guild_discovery_grace_period_initial_warning", "disnake.MessageType.guild_discovery_grace_period_final_warning": "api/messages.html#disnake.MessageType.guild_discovery_grace_period_final_warning", "disnake.MessageType.thread_created": "api/messages.html#disnake.MessageType.thread_created", "disnake.MessageType.reply": "api/messages.html#disnake.MessageType.reply", "disnake.MessageType.application_command": "api/messages.html#disnake.MessageType.application_command", "disnake.MessageType.guild_invite_reminder": "api/messages.html#disnake.MessageType.guild_invite_reminder", "disnake.MessageType.thread_starter_message": "api/messages.html#disnake.MessageType.thread_starter_message", "disnake.MessageType.context_menu_command": "api/messages.html#disnake.MessageType.context_menu_command", "disnake.MessageType.auto_moderation_action": "api/messages.html#disnake.MessageType.auto_moderation_action", "disnake.Asset": "api/misc.html#disnake.Asset", "disnake.Asset.url": "api/misc.html#disnake.Asset.url", "disnake.Asset.key": "api/misc.html#disnake.Asset.key", "disnake.Asset.is_animated": "api/misc.html#disnake.Asset.is_animated", "disnake.Asset.replace": "api/misc.html#disnake.Asset.replace", "disnake.Asset.with_size": "api/misc.html#disnake.Asset.with_size", "disnake.Asset.with_format": "api/misc.html#disnake.Asset.with_format", "disnake.Asset.with_static_format": "api/misc.html#disnake.Asset.with_static_format", "disnake.Asset.read": "api/misc.html#disnake.Asset.read", "disnake.Asset.save": "api/misc.html#disnake.Asset.save", "disnake.Asset.to_file": "api/misc.html#disnake.Asset.to_file", "disnake.AsyncIterator": "api/misc.html#disnake.AsyncIterator", "disnake.AsyncIterator.next": "api/misc.html#disnake.AsyncIterator.next", "disnake.AsyncIterator.get": "api/misc.html#disnake.AsyncIterator.get", "disnake.AsyncIterator.find": "api/misc.html#disnake.AsyncIterator.find", "disnake.AsyncIterator.flatten": "api/misc.html#disnake.AsyncIterator.flatten", "disnake.AsyncIterator.chunk": "api/misc.html#disnake.AsyncIterator.chunk", "disnake.AsyncIterator.map": "api/misc.html#disnake.AsyncIterator.map", "disnake.AsyncIterator.filter": "api/misc.html#disnake.AsyncIterator.filter", "disnake.Object": "api/misc.html#disnake.Object", "disnake.Object.id": "api/misc.html#disnake.Object.id", "disnake.Object.created_at": "api/misc.html#disnake.Object.created_at", "disnake.Colour": "api/misc.html#disnake.Colour", "disnake.Colour.value": "api/misc.html#disnake.Colour.value", "disnake.Colour.r": "api/misc.html#disnake.Colour.r", "disnake.Colour.g": "api/misc.html#disnake.Colour.g", "disnake.Colour.b": "api/misc.html#disnake.Colour.b", "disnake.Colour.to_rgb": "api/misc.html#disnake.Colour.to_rgb", "disnake.Colour.from_rgb": "api/misc.html#disnake.Colour.from_rgb", "disnake.Colour.from_hsv": "api/misc.html#disnake.Colour.from_hsv", "disnake.Colour.default": "api/misc.html#disnake.Colour.default", "disnake.Colour.random": "api/misc.html#disnake.Colour.random", "disnake.Colour.teal": "api/misc.html#disnake.Colour.teal", "disnake.Colour.dark_teal": "api/misc.html#disnake.Colour.dark_teal", "disnake.Colour.brand_green": "api/misc.html#disnake.Colour.brand_green", "disnake.Colour.green": "api/misc.html#disnake.Colour.green", "disnake.Colour.dark_green": "api/misc.html#disnake.Colour.dark_green", "disnake.Colour.blue": "api/misc.html#disnake.Colour.blue", "disnake.Colour.dark_blue": "api/misc.html#disnake.Colour.dark_blue", "disnake.Colour.purple": "api/misc.html#disnake.Colour.purple", "disnake.Colour.dark_purple": "api/misc.html#disnake.Colour.dark_purple", "disnake.Colour.magenta": "api/misc.html#disnake.Colour.magenta", "disnake.Colour.dark_magenta": "api/misc.html#disnake.Colour.dark_magenta", "disnake.Colour.gold": "api/misc.html#disnake.Colour.gold", "disnake.Colour.dark_gold": "api/misc.html#disnake.Colour.dark_gold", "disnake.Colour.orange": "api/misc.html#disnake.Colour.orange", "disnake.Colour.dark_orange": "api/misc.html#disnake.Colour.dark_orange", "disnake.Colour.brand_red": "api/misc.html#disnake.Colour.brand_red", "disnake.Colour.red": "api/misc.html#disnake.Colour.red", "disnake.Colour.dark_red": "api/misc.html#disnake.Colour.dark_red", "disnake.Colour.lighter_grey": "api/misc.html#disnake.Colour.lighter_grey", "disnake.Colour.lighter_gray": "api/misc.html#disnake.Colour.lighter_gray", "disnake.Colour.dark_grey": "api/misc.html#disnake.Colour.dark_grey", "disnake.Colour.dark_gray": "api/misc.html#disnake.Colour.dark_gray", "disnake.Colour.light_grey": "api/misc.html#disnake.Colour.light_grey", "disnake.Colour.light_gray": "api/misc.html#disnake.Colour.light_gray", "disnake.Colour.darker_grey": "api/misc.html#disnake.Colour.darker_grey", "disnake.Colour.darker_gray": "api/misc.html#disnake.Colour.darker_gray", "disnake.Colour.og_blurple": "api/misc.html#disnake.Colour.og_blurple", "disnake.Colour.old_blurple": "api/misc.html#disnake.Colour.old_blurple", "disnake.Colour.blurple": "api/misc.html#disnake.Colour.blurple", "disnake.Colour.greyple": "api/misc.html#disnake.Colour.greyple", "disnake.Colour.dark_theme": "api/misc.html#disnake.Colour.dark_theme", "disnake.Colour.fuchsia": "api/misc.html#disnake.Colour.fuchsia", "disnake.Colour.yellow": "api/misc.html#disnake.Colour.yellow", "disnake.version_info": "api/misc.html#disnake.version_info", "disnake.__version__": "api/misc.html#disnake.__version__", "disnake.Permissions": "api/permissions.html#disnake.Permissions", "disnake.Permissions.value": "api/permissions.html#disnake.Permissions.value", "disnake.Permissions.is_subset": "api/permissions.html#disnake.Permissions.is_subset", "disnake.Permissions.is_superset": "api/permissions.html#disnake.Permissions.is_superset", "disnake.Permissions.is_strict_subset": "api/permissions.html#disnake.Permissions.is_strict_subset", "disnake.Permissions.is_strict_superset": "api/permissions.html#disnake.Permissions.is_strict_superset", "disnake.Permissions.none": "api/permissions.html#disnake.Permissions.none", "disnake.Permissions.all": "api/permissions.html#disnake.Permissions.all", "disnake.Permissions.all_channel": "api/permissions.html#disnake.Permissions.all_channel", "disnake.Permissions.general": "api/permissions.html#disnake.Permissions.general", "disnake.Permissions.membership": "api/permissions.html#disnake.Permissions.membership", "disnake.Permissions.text": "api/permissions.html#disnake.Permissions.text", "disnake.Permissions.voice": "api/permissions.html#disnake.Permissions.voice", "disnake.Permissions.stage": "api/permissions.html#disnake.Permissions.stage", "disnake.Permissions.stage_moderator": "api/permissions.html#disnake.Permissions.stage_moderator", "disnake.Permissions.events": "api/permissions.html#disnake.Permissions.events", "disnake.Permissions.advanced": "api/permissions.html#disnake.Permissions.advanced", "disnake.Permissions.private_channel": "api/permissions.html#disnake.Permissions.private_channel", "disnake.Permissions.update": "api/permissions.html#disnake.Permissions.update", "disnake.Permissions.create_instant_invite": "api/permissions.html#disnake.Permissions.create_instant_invite", "disnake.Permissions.kick_members": "api/permissions.html#disnake.Permissions.kick_members", "disnake.Permissions.ban_members": "api/permissions.html#disnake.Permissions.ban_members", "disnake.Permissions.administrator": "api/permissions.html#disnake.Permissions.administrator", "disnake.Permissions.manage_channels": "api/permissions.html#disnake.Permissions.manage_channels", "disnake.Permissions.manage_guild": "api/permissions.html#disnake.Permissions.manage_guild", "disnake.Permissions.add_reactions": "api/permissions.html#disnake.Permissions.add_reactions", "disnake.Permissions.view_audit_log": "api/permissions.html#disnake.Permissions.view_audit_log", "disnake.Permissions.priority_speaker": "api/permissions.html#disnake.Permissions.priority_speaker", "disnake.Permissions.stream": "api/permissions.html#disnake.Permissions.stream", "disnake.Permissions.view_channel": "api/permissions.html#disnake.Permissions.view_channel", "disnake.Permissions.read_messages": "api/permissions.html#disnake.Permissions.read_messages", "disnake.Permissions.send_messages": "api/permissions.html#disnake.Permissions.send_messages", "disnake.Permissions.create_forum_threads": "api/permissions.html#disnake.Permissions.create_forum_threads", "disnake.Permissions.send_tts_messages": "api/permissions.html#disnake.Permissions.send_tts_messages", "disnake.Permissions.manage_messages": "api/permissions.html#disnake.Permissions.manage_messages", "disnake.Permissions.embed_links": "api/permissions.html#disnake.Permissions.embed_links", "disnake.Permissions.attach_files": "api/permissions.html#disnake.Permissions.attach_files", "disnake.Permissions.read_message_history": "api/permissions.html#disnake.Permissions.read_message_history", "disnake.Permissions.mention_everyone": "api/permissions.html#disnake.Permissions.mention_everyone", "disnake.Permissions.external_emojis": "api/permissions.html#disnake.Permissions.external_emojis", "disnake.Permissions.use_external_emojis": "api/permissions.html#disnake.Permissions.use_external_emojis", "disnake.Permissions.view_guild_insights": "api/permissions.html#disnake.Permissions.view_guild_insights", "disnake.Permissions.connect": "api/permissions.html#disnake.Permissions.connect", "disnake.Permissions.speak": "api/permissions.html#disnake.Permissions.speak", "disnake.Permissions.mute_members": "api/permissions.html#disnake.Permissions.mute_members", "disnake.Permissions.deafen_members": "api/permissions.html#disnake.Permissions.deafen_members", "disnake.Permissions.move_members": "api/permissions.html#disnake.Permissions.move_members", "disnake.Permissions.use_voice_activation": "api/permissions.html#disnake.Permissions.use_voice_activation", "disnake.Permissions.change_nickname": "api/permissions.html#disnake.Permissions.change_nickname", "disnake.Permissions.manage_nicknames": "api/permissions.html#disnake.Permissions.manage_nicknames", "disnake.Permissions.manage_roles": "api/permissions.html#disnake.Permissions.manage_roles", "disnake.Permissions.manage_permissions": "api/permissions.html#disnake.Permissions.manage_permissions", "disnake.Permissions.manage_webhooks": "api/permissions.html#disnake.Permissions.manage_webhooks", "disnake.Permissions.manage_emojis": "api/permissions.html#disnake.Permissions.manage_emojis", "disnake.Permissions.manage_emojis_and_stickers": "api/permissions.html#disnake.Permissions.manage_emojis_and_stickers", "disnake.Permissions.use_application_commands": "api/permissions.html#disnake.Permissions.use_application_commands", "disnake.Permissions.use_slash_commands": "api/permissions.html#disnake.Permissions.use_slash_commands", "disnake.Permissions.request_to_speak": "api/permissions.html#disnake.Permissions.request_to_speak", "disnake.Permissions.manage_events": "api/permissions.html#disnake.Permissions.manage_events", "disnake.Permissions.manage_threads": "api/permissions.html#disnake.Permissions.manage_threads", "disnake.Permissions.create_public_threads": "api/permissions.html#disnake.Permissions.create_public_threads", "disnake.Permissions.create_private_threads": "api/permissions.html#disnake.Permissions.create_private_threads", "disnake.Permissions.external_stickers": "api/permissions.html#disnake.Permissions.external_stickers", "disnake.Permissions.use_external_stickers": "api/permissions.html#disnake.Permissions.use_external_stickers", "disnake.Permissions.send_messages_in_threads": "api/permissions.html#disnake.Permissions.send_messages_in_threads", "disnake.Permissions.use_embedded_activities": "api/permissions.html#disnake.Permissions.use_embedded_activities", "disnake.Permissions.start_embedded_activities": "api/permissions.html#disnake.Permissions.start_embedded_activities", "disnake.Permissions.moderate_members": "api/permissions.html#disnake.Permissions.moderate_members", "disnake.PermissionOverwrite": "api/permissions.html#disnake.PermissionOverwrite", "disnake.PermissionOverwrite.pair": "api/permissions.html#disnake.PermissionOverwrite.pair", "disnake.PermissionOverwrite.from_pair": "api/permissions.html#disnake.PermissionOverwrite.from_pair", "disnake.PermissionOverwrite.is_empty": "api/permissions.html#disnake.PermissionOverwrite.is_empty", "disnake.PermissionOverwrite.update": "api/permissions.html#disnake.PermissionOverwrite.update", "disnake.Role": "api/roles.html#disnake.Role", "disnake.Role.id": "api/roles.html#disnake.Role.id", "disnake.Role.name": "api/roles.html#disnake.Role.name", "disnake.Role.guild": "api/roles.html#disnake.Role.guild", "disnake.Role.hoist": "api/roles.html#disnake.Role.hoist", "disnake.Role.position": "api/roles.html#disnake.Role.position", "disnake.Role.managed": "api/roles.html#disnake.Role.managed", "disnake.Role.mentionable": "api/roles.html#disnake.Role.mentionable", "disnake.Role.tags": "api/roles.html#disnake.Role.tags", "disnake.Role.is_default": "api/roles.html#disnake.Role.is_default", "disnake.Role.is_bot_managed": "api/roles.html#disnake.Role.is_bot_managed", "disnake.Role.is_premium_subscriber": "api/roles.html#disnake.Role.is_premium_subscriber", "disnake.Role.is_integration": "api/roles.html#disnake.Role.is_integration", "disnake.Role.is_assignable": "api/roles.html#disnake.Role.is_assignable", "disnake.Role.permissions": "api/roles.html#disnake.Role.permissions", "disnake.Role.colour": "api/roles.html#disnake.Role.colour", "disnake.Role.color": "api/roles.html#disnake.Role.color", "disnake.Role.icon": "api/roles.html#disnake.Role.icon", "disnake.Role.emoji": "api/roles.html#disnake.Role.emoji", "disnake.Role.created_at": "api/roles.html#disnake.Role.created_at", "disnake.Role.mention": "api/roles.html#disnake.Role.mention", "disnake.Role.members": "api/roles.html#disnake.Role.members", "disnake.Role.edit": "api/roles.html#disnake.Role.edit", "disnake.Role.delete": "api/roles.html#disnake.Role.delete", "disnake.RoleTags": "api/roles.html#disnake.RoleTags", "disnake.RoleTags.bot_id": "api/roles.html#disnake.RoleTags.bot_id", "disnake.RoleTags.integration_id": "api/roles.html#disnake.RoleTags.integration_id", "disnake.RoleTags.is_bot_managed": "api/roles.html#disnake.RoleTags.is_bot_managed", "disnake.RoleTags.is_premium_subscriber": "api/roles.html#disnake.RoleTags.is_premium_subscriber", "disnake.RoleTags.is_integration": "api/roles.html#disnake.RoleTags.is_integration", "disnake.StageInstance": "api/stage_instances.html#disnake.StageInstance", "disnake.StageInstance.id": "api/stage_instances.html#disnake.StageInstance.id", "disnake.StageInstance.guild": "api/stage_instances.html#disnake.StageInstance.guild", "disnake.StageInstance.channel_id": "api/stage_instances.html#disnake.StageInstance.channel_id", "disnake.StageInstance.topic": "api/stage_instances.html#disnake.StageInstance.topic", "disnake.StageInstance.privacy_level": "api/stage_instances.html#disnake.StageInstance.privacy_level", "disnake.StageInstance.guild_scheduled_event_id": "api/stage_instances.html#disnake.StageInstance.guild_scheduled_event_id", "disnake.StageInstance.channel": "api/stage_instances.html#disnake.StageInstance.channel", "disnake.StageInstance.discoverable_disabled": "api/stage_instances.html#disnake.StageInstance.discoverable_disabled", "disnake.StageInstance.is_public": "api/stage_instances.html#disnake.StageInstance.is_public", "disnake.StageInstance.guild_scheduled_event": "api/stage_instances.html#disnake.StageInstance.guild_scheduled_event", "disnake.StageInstance.edit": "api/stage_instances.html#disnake.StageInstance.edit", "disnake.StageInstance.delete": "api/stage_instances.html#disnake.StageInstance.delete", "disnake.StagePrivacyLevel": "api/stage_instances.html#disnake.StagePrivacyLevel", "disnake.StagePrivacyLevel.public": "api/stage_instances.html#disnake.StagePrivacyLevel.public", "disnake.StagePrivacyLevel.closed": "api/stage_instances.html#disnake.StagePrivacyLevel.closed", "disnake.StagePrivacyLevel.guild_only": "api/stage_instances.html#disnake.StagePrivacyLevel.guild_only", "disnake.Sticker": "api/stickers.html#disnake.Sticker", "disnake.Sticker.name": "api/stickers.html#disnake.Sticker.name", "disnake.Sticker.id": "api/stickers.html#disnake.Sticker.id", "disnake.Sticker.description": "api/stickers.html#disnake.Sticker.description", "disnake.Sticker.pack_id": "api/stickers.html#disnake.Sticker.pack_id", "disnake.Sticker.format": "api/stickers.html#disnake.Sticker.format", "disnake.Sticker.url": "api/stickers.html#disnake.Sticker.url", "disnake.Sticker.created_at": "api/stickers.html#disnake.Sticker.created_at", "disnake.Sticker.read": "api/stickers.html#disnake.Sticker.read", "disnake.Sticker.save": "api/stickers.html#disnake.Sticker.save", "disnake.Sticker.to_file": "api/stickers.html#disnake.Sticker.to_file", "disnake.StandardSticker": "api/stickers.html#disnake.StandardSticker", "disnake.StandardSticker.name": "api/stickers.html#disnake.StandardSticker.name", "disnake.StandardSticker.id": "api/stickers.html#disnake.StandardSticker.id", "disnake.StandardSticker.description": "api/stickers.html#disnake.StandardSticker.description", "disnake.StandardSticker.pack_id": "api/stickers.html#disnake.StandardSticker.pack_id", "disnake.StandardSticker.format": "api/stickers.html#disnake.StandardSticker.format", "disnake.StandardSticker.tags": "api/stickers.html#disnake.StandardSticker.tags", "disnake.StandardSticker.sort_value": "api/stickers.html#disnake.StandardSticker.sort_value", "disnake.StandardSticker.pack": "api/stickers.html#disnake.StandardSticker.pack", "disnake.StandardSticker.created_at": "api/stickers.html#disnake.StandardSticker.created_at", "disnake.StandardSticker.read": "api/stickers.html#disnake.StandardSticker.read", "disnake.StandardSticker.save": "api/stickers.html#disnake.StandardSticker.save", "disnake.StandardSticker.to_file": "api/stickers.html#disnake.StandardSticker.to_file", "disnake.GuildSticker": "api/stickers.html#disnake.GuildSticker", "disnake.GuildSticker.name": "api/stickers.html#disnake.GuildSticker.name", "disnake.GuildSticker.id": "api/stickers.html#disnake.GuildSticker.id", "disnake.GuildSticker.description": "api/stickers.html#disnake.GuildSticker.description", "disnake.GuildSticker.format": "api/stickers.html#disnake.GuildSticker.format", "disnake.GuildSticker.available": "api/stickers.html#disnake.GuildSticker.available", "disnake.GuildSticker.guild_id": "api/stickers.html#disnake.GuildSticker.guild_id", "disnake.GuildSticker.user": "api/stickers.html#disnake.GuildSticker.user", "disnake.GuildSticker.emoji": "api/stickers.html#disnake.GuildSticker.emoji", "disnake.GuildSticker.guild": "api/stickers.html#disnake.GuildSticker.guild", "disnake.GuildSticker.edit": "api/stickers.html#disnake.GuildSticker.edit", "disnake.GuildSticker.delete": "api/stickers.html#disnake.GuildSticker.delete", "disnake.GuildSticker.created_at": "api/stickers.html#disnake.GuildSticker.created_at", "disnake.GuildSticker.read": "api/stickers.html#disnake.GuildSticker.read", "disnake.GuildSticker.save": "api/stickers.html#disnake.GuildSticker.save", "disnake.GuildSticker.to_file": "api/stickers.html#disnake.GuildSticker.to_file", "disnake.StickerItem": "api/stickers.html#disnake.StickerItem", "disnake.StickerItem.name": "api/stickers.html#disnake.StickerItem.name", "disnake.StickerItem.id": "api/stickers.html#disnake.StickerItem.id", "disnake.StickerItem.format": "api/stickers.html#disnake.StickerItem.format", "disnake.StickerItem.url": "api/stickers.html#disnake.StickerItem.url", "disnake.StickerItem.fetch": "api/stickers.html#disnake.StickerItem.fetch", "disnake.StickerItem.read": "api/stickers.html#disnake.StickerItem.read", "disnake.StickerItem.save": "api/stickers.html#disnake.StickerItem.save", "disnake.StickerItem.to_file": "api/stickers.html#disnake.StickerItem.to_file", "disnake.StickerPack": "api/stickers.html#disnake.StickerPack", "disnake.StickerPack.name": "api/stickers.html#disnake.StickerPack.name", "disnake.StickerPack.description": "api/stickers.html#disnake.StickerPack.description", "disnake.StickerPack.id": "api/stickers.html#disnake.StickerPack.id", "disnake.StickerPack.stickers": "api/stickers.html#disnake.StickerPack.stickers", "disnake.StickerPack.sku_id": "api/stickers.html#disnake.StickerPack.sku_id", "disnake.StickerPack.cover_sticker_id": "api/stickers.html#disnake.StickerPack.cover_sticker_id", "disnake.StickerPack.cover_sticker": "api/stickers.html#disnake.StickerPack.cover_sticker", "disnake.StickerPack.banner": "api/stickers.html#disnake.StickerPack.banner", "disnake.StickerType": "api/stickers.html#disnake.StickerType", "disnake.StickerType.standard": "api/stickers.html#disnake.StickerType.standard", "disnake.StickerType.guild": "api/stickers.html#disnake.StickerType.guild", "disnake.StickerFormatType": "api/stickers.html#disnake.StickerFormatType", "disnake.StickerFormatType.png": "api/stickers.html#disnake.StickerFormatType.png", "disnake.StickerFormatType.apng": "api/stickers.html#disnake.StickerFormatType.apng", "disnake.StickerFormatType.lottie": "api/stickers.html#disnake.StickerFormatType.lottie", "disnake.ui.View": "api/ui.html#disnake.ui.View", "disnake.ui.View.timeout": "api/ui.html#disnake.ui.View.timeout", "disnake.ui.View.children": "api/ui.html#disnake.ui.View.children", "disnake.ui.View.from_message": "api/ui.html#disnake.ui.View.from_message", "disnake.ui.View.add_item": "api/ui.html#disnake.ui.View.add_item", "disnake.ui.View.remove_item": "api/ui.html#disnake.ui.View.remove_item", "disnake.ui.View.clear_items": "api/ui.html#disnake.ui.View.clear_items", "disnake.ui.View.interaction_check": "api/ui.html#disnake.ui.View.interaction_check", "disnake.ui.View.on_timeout": "api/ui.html#disnake.ui.View.on_timeout", "disnake.ui.View.on_error": "api/ui.html#disnake.ui.View.on_error", "disnake.ui.View.stop": "api/ui.html#disnake.ui.View.stop", "disnake.ui.View.is_finished": "api/ui.html#disnake.ui.View.is_finished", "disnake.ui.View.is_dispatching": "api/ui.html#disnake.ui.View.is_dispatching", "disnake.ui.View.is_persistent": "api/ui.html#disnake.ui.View.is_persistent", "disnake.ui.View.wait": "api/ui.html#disnake.ui.View.wait", "disnake.ui.ActionRow": "api/ui.html#disnake.ui.ActionRow", "disnake.ui.ActionRow.children": "api/ui.html#disnake.ui.ActionRow.children", "disnake.ui.ActionRow.append_item": "api/ui.html#disnake.ui.ActionRow.append_item", "disnake.ui.ActionRow.insert_item": "api/ui.html#disnake.ui.ActionRow.insert_item", "disnake.ui.ActionRow.add_button": "api/ui.html#disnake.ui.ActionRow.add_button", "disnake.ui.ActionRow.add_select": "api/ui.html#disnake.ui.ActionRow.add_select", "disnake.ui.ActionRow.add_text_input": "api/ui.html#disnake.ui.ActionRow.add_text_input", "disnake.ui.ActionRow.clear_items": "api/ui.html#disnake.ui.ActionRow.clear_items", "disnake.ui.ActionRow.remove_item": "api/ui.html#disnake.ui.ActionRow.remove_item", "disnake.ui.ActionRow.pop": "api/ui.html#disnake.ui.ActionRow.pop", "disnake.ui.ActionRow.with_modal_components": "api/ui.html#disnake.ui.ActionRow.with_modal_components", "disnake.ui.ActionRow.with_message_components": "api/ui.html#disnake.ui.ActionRow.with_message_components", "disnake.ui.ActionRow.rows_from_message": "api/ui.html#disnake.ui.ActionRow.rows_from_message", "disnake.ui.ActionRow.walk_components": "api/ui.html#disnake.ui.ActionRow.walk_components", "disnake.ui.Item": "api/ui.html#disnake.ui.Item", "disnake.ui.Item.view": "api/ui.html#disnake.ui.Item.view", "disnake.ui.Item.callback": "api/ui.html#disnake.ui.Item.callback", "disnake.ui.WrappedComponent": "api/ui.html#disnake.ui.WrappedComponent", "disnake.ui.Button": "api/ui.html#disnake.ui.Button", "disnake.ui.Button.style": "api/ui.html#disnake.ui.Button.style", "disnake.ui.Button.custom_id": "api/ui.html#disnake.ui.Button.custom_id", "disnake.ui.Button.url": "api/ui.html#disnake.ui.Button.url", "disnake.ui.Button.callback": "api/ui.html#disnake.ui.Button.callback", "disnake.ui.Button.disabled": "api/ui.html#disnake.ui.Button.disabled", "disnake.ui.Button.view": "api/ui.html#disnake.ui.Button.view", "disnake.ui.Button.label": "api/ui.html#disnake.ui.Button.label", "disnake.ui.Button.emoji": "api/ui.html#disnake.ui.Button.emoji", "disnake.ui.BaseSelect": "api/ui.html#disnake.ui.BaseSelect", "disnake.ui.BaseSelect.custom_id": "api/ui.html#disnake.ui.BaseSelect.custom_id", "disnake.ui.BaseSelect.placeholder": "api/ui.html#disnake.ui.BaseSelect.placeholder", "disnake.ui.BaseSelect.min_values": "api/ui.html#disnake.ui.BaseSelect.min_values", "disnake.ui.BaseSelect.max_values": "api/ui.html#disnake.ui.BaseSelect.max_values", "disnake.ui.BaseSelect.disabled": "api/ui.html#disnake.ui.BaseSelect.disabled", "disnake.ui.BaseSelect.callback": "api/ui.html#disnake.ui.BaseSelect.callback", "disnake.ui.BaseSelect.view": "api/ui.html#disnake.ui.BaseSelect.view", "disnake.ui.BaseSelect.is_dispatchable": "api/ui.html#disnake.ui.BaseSelect.is_dispatchable", "disnake.ui.Select": "api/ui.html#disnake.ui.Select", "disnake.ui.Select.values": "api/ui.html#disnake.ui.Select.values", "disnake.ui.Select.options": "api/ui.html#disnake.ui.Select.options", "disnake.ui.Select.add_option": "api/ui.html#disnake.ui.Select.add_option", "disnake.ui.Select.append_option": "api/ui.html#disnake.ui.Select.append_option", "disnake.ui.Select.callback": "api/ui.html#disnake.ui.Select.callback", "disnake.ui.Select.custom_id": "api/ui.html#disnake.ui.Select.custom_id", "disnake.ui.Select.disabled": "api/ui.html#disnake.ui.Select.disabled", "disnake.ui.Select.is_dispatchable": "api/ui.html#disnake.ui.Select.is_dispatchable", "disnake.ui.Select.max_values": "api/ui.html#disnake.ui.Select.max_values", "disnake.ui.Select.min_values": "api/ui.html#disnake.ui.Select.min_values", "disnake.ui.Select.placeholder": "api/ui.html#disnake.ui.Select.placeholder", "disnake.ui.Select.view": "api/ui.html#disnake.ui.Select.view", "disnake.ui.Modal": "api/ui.html#disnake.ui.Modal", "disnake.ui.Modal.append_component": "api/ui.html#disnake.ui.Modal.append_component", "disnake.ui.Modal.add_text_input": "api/ui.html#disnake.ui.Modal.add_text_input", "disnake.ui.Modal.callback": "api/ui.html#disnake.ui.Modal.callback", "disnake.ui.Modal.on_error": "api/ui.html#disnake.ui.Modal.on_error", "disnake.ui.Modal.on_timeout": "api/ui.html#disnake.ui.Modal.on_timeout", "disnake.ui.TextInput": "api/ui.html#disnake.ui.TextInput", "disnake.ui.TextInput.style": "api/ui.html#disnake.ui.TextInput.style", "disnake.ui.TextInput.label": "api/ui.html#disnake.ui.TextInput.label", "disnake.ui.TextInput.custom_id": "api/ui.html#disnake.ui.TextInput.custom_id", "disnake.ui.TextInput.placeholder": "api/ui.html#disnake.ui.TextInput.placeholder", "disnake.ui.TextInput.value": "api/ui.html#disnake.ui.TextInput.value", "disnake.ui.TextInput.required": "api/ui.html#disnake.ui.TextInput.required", "disnake.ui.TextInput.min_length": "api/ui.html#disnake.ui.TextInput.min_length", "disnake.ui.TextInput.max_length": "api/ui.html#disnake.ui.TextInput.max_length", "disnake.ui.button": "api/ui.html#disnake.ui.button", "disnake.ui.select": "api/ui.html#disnake.ui.select", "disnake.User": "api/users.html#disnake.User", "disnake.User.name": "api/users.html#disnake.User.name", "disnake.User.id": "api/users.html#disnake.User.id", "disnake.User.discriminator": "api/users.html#disnake.User.discriminator", "disnake.User.bot": "api/users.html#disnake.User.bot", "disnake.User.system": "api/users.html#disnake.User.system", "disnake.User.history": "api/users.html#disnake.User.history", "disnake.User.typing": "api/users.html#disnake.User.typing", "disnake.User.dm_channel": "api/users.html#disnake.User.dm_channel", "disnake.User.mutual_guilds": "api/users.html#disnake.User.mutual_guilds", "disnake.User.accent_color": "api/users.html#disnake.User.accent_color", "disnake.User.accent_colour": "api/users.html#disnake.User.accent_colour", "disnake.User.avatar": "api/users.html#disnake.User.avatar", "disnake.User.banner": "api/users.html#disnake.User.banner", "disnake.User.color": "api/users.html#disnake.User.color", "disnake.User.colour": "api/users.html#disnake.User.colour", "disnake.User.create_dm": "api/users.html#disnake.User.create_dm", "disnake.User.created_at": "api/users.html#disnake.User.created_at", "disnake.User.default_avatar": "api/users.html#disnake.User.default_avatar", "disnake.User.display_avatar": "api/users.html#disnake.User.display_avatar", "disnake.User.display_name": "api/users.html#disnake.User.display_name", "disnake.User.fetch_message": "api/users.html#disnake.User.fetch_message", "disnake.User.mention": "api/users.html#disnake.User.mention", "disnake.User.mentioned_in": "api/users.html#disnake.User.mentioned_in", "disnake.User.pins": "api/users.html#disnake.User.pins", "disnake.User.public_flags": "api/users.html#disnake.User.public_flags", "disnake.User.send": "api/users.html#disnake.User.send", "disnake.User.trigger_typing": "api/users.html#disnake.User.trigger_typing", "disnake.PublicUserFlags": "api/users.html#disnake.PublicUserFlags", "disnake.PublicUserFlags.value": "api/users.html#disnake.PublicUserFlags.value", "disnake.PublicUserFlags.staff": "api/users.html#disnake.PublicUserFlags.staff", "disnake.PublicUserFlags.partner": "api/users.html#disnake.PublicUserFlags.partner", "disnake.PublicUserFlags.hypesquad": "api/users.html#disnake.PublicUserFlags.hypesquad", "disnake.PublicUserFlags.bug_hunter": "api/users.html#disnake.PublicUserFlags.bug_hunter", "disnake.PublicUserFlags.hypesquad_bravery": "api/users.html#disnake.PublicUserFlags.hypesquad_bravery", "disnake.PublicUserFlags.hypesquad_brilliance": "api/users.html#disnake.PublicUserFlags.hypesquad_brilliance", "disnake.PublicUserFlags.hypesquad_balance": "api/users.html#disnake.PublicUserFlags.hypesquad_balance", "disnake.PublicUserFlags.early_supporter": "api/users.html#disnake.PublicUserFlags.early_supporter", "disnake.PublicUserFlags.team_user": "api/users.html#disnake.PublicUserFlags.team_user", "disnake.PublicUserFlags.system": "api/users.html#disnake.PublicUserFlags.system", "disnake.PublicUserFlags.bug_hunter_level_2": "api/users.html#disnake.PublicUserFlags.bug_hunter_level_2", "disnake.PublicUserFlags.verified_bot": "api/users.html#disnake.PublicUserFlags.verified_bot", "disnake.PublicUserFlags.verified_bot_developer": "api/users.html#disnake.PublicUserFlags.verified_bot_developer", "disnake.PublicUserFlags.early_verified_bot_developer": "api/users.html#disnake.PublicUserFlags.early_verified_bot_developer", "disnake.PublicUserFlags.discord_certified_moderator": "api/users.html#disnake.PublicUserFlags.discord_certified_moderator", "disnake.PublicUserFlags.http_interactions_bot": "api/users.html#disnake.PublicUserFlags.http_interactions_bot", "disnake.PublicUserFlags.spammer": "api/users.html#disnake.PublicUserFlags.spammer", "disnake.PublicUserFlags.all": "api/users.html#disnake.PublicUserFlags.all", "disnake.UserFlags": "api/users.html#disnake.UserFlags", "disnake.UserFlags.staff": "api/users.html#disnake.UserFlags.staff", "disnake.UserFlags.partner": "api/users.html#disnake.UserFlags.partner", "disnake.UserFlags.hypesquad": "api/users.html#disnake.UserFlags.hypesquad", "disnake.UserFlags.bug_hunter": "api/users.html#disnake.UserFlags.bug_hunter", "disnake.UserFlags.mfa_sms": "api/users.html#disnake.UserFlags.mfa_sms", "disnake.UserFlags.premium_promo_dismissed": "api/users.html#disnake.UserFlags.premium_promo_dismissed", "disnake.UserFlags.hypesquad_bravery": "api/users.html#disnake.UserFlags.hypesquad_bravery", "disnake.UserFlags.hypesquad_brilliance": "api/users.html#disnake.UserFlags.hypesquad_brilliance", "disnake.UserFlags.hypesquad_balance": "api/users.html#disnake.UserFlags.hypesquad_balance", "disnake.UserFlags.early_supporter": "api/users.html#disnake.UserFlags.early_supporter", "disnake.UserFlags.team_user": "api/users.html#disnake.UserFlags.team_user", "disnake.UserFlags.system": "api/users.html#disnake.UserFlags.system", "disnake.UserFlags.has_unread_urgent_messages": "api/users.html#disnake.UserFlags.has_unread_urgent_messages", "disnake.UserFlags.bug_hunter_level_2": "api/users.html#disnake.UserFlags.bug_hunter_level_2", "disnake.UserFlags.verified_bot": "api/users.html#disnake.UserFlags.verified_bot", "disnake.UserFlags.verified_bot_developer": "api/users.html#disnake.UserFlags.verified_bot_developer", "disnake.UserFlags.discord_certified_moderator": "api/users.html#disnake.UserFlags.discord_certified_moderator", "disnake.UserFlags.http_interactions_bot": "api/users.html#disnake.UserFlags.http_interactions_bot", "disnake.UserFlags.spammer": "api/users.html#disnake.UserFlags.spammer", "disnake.DefaultAvatar": "api/users.html#disnake.DefaultAvatar", "disnake.DefaultAvatar.blurple": "api/users.html#disnake.DefaultAvatar.blurple", "disnake.DefaultAvatar.grey": "api/users.html#disnake.DefaultAvatar.grey", "disnake.DefaultAvatar.gray": "api/users.html#disnake.DefaultAvatar.gray", "disnake.DefaultAvatar.green": "api/users.html#disnake.DefaultAvatar.green", "disnake.DefaultAvatar.orange": "api/users.html#disnake.DefaultAvatar.orange", "disnake.DefaultAvatar.red": "api/users.html#disnake.DefaultAvatar.red", "disnake.utils.find": "api/utilities.html#disnake.utils.find", "disnake.utils.get": "api/utilities.html#disnake.utils.get", "disnake.utils.snowflake_time": "api/utilities.html#disnake.utils.snowflake_time", "disnake.utils.oauth_url": "api/utilities.html#disnake.utils.oauth_url", "disnake.utils.remove_markdown": "api/utilities.html#disnake.utils.remove_markdown", "disnake.utils.escape_markdown": "api/utilities.html#disnake.utils.escape_markdown", "disnake.utils.escape_mentions": "api/utilities.html#disnake.utils.escape_mentions", "disnake.utils.resolve_invite": "api/utilities.html#disnake.utils.resolve_invite", "disnake.utils.resolve_template": "api/utilities.html#disnake.utils.resolve_template", "disnake.utils.sleep_until": "api/utilities.html#disnake.utils.sleep_until", "disnake.utils.utcnow": "api/utilities.html#disnake.utils.utcnow", "disnake.utils.format_dt": "api/utilities.html#disnake.utils.format_dt", "disnake.utils.as_chunks": "api/utilities.html#disnake.utils.as_chunks", "disnake.utils.search_directory": "api/utilities.html#disnake.utils.search_directory", "disnake.utils.as_valid_locale": "api/utilities.html#disnake.utils.as_valid_locale", "disnake.VoiceClient": "api/voice.html#disnake.VoiceClient", "disnake.VoiceClient.session_id": "api/voice.html#disnake.VoiceClient.session_id", "disnake.VoiceClient.token": "api/voice.html#disnake.VoiceClient.token", "disnake.VoiceClient.endpoint": "api/voice.html#disnake.VoiceClient.endpoint", "disnake.VoiceClient.channel": "api/voice.html#disnake.VoiceClient.channel", "disnake.VoiceClient.loop": "api/voice.html#disnake.VoiceClient.loop", "disnake.VoiceClient.guild": "api/voice.html#disnake.VoiceClient.guild", "disnake.VoiceClient.user": "api/voice.html#disnake.VoiceClient.user", "disnake.VoiceClient.latency": "api/voice.html#disnake.VoiceClient.latency", "disnake.VoiceClient.average_latency": "api/voice.html#disnake.VoiceClient.average_latency", "disnake.VoiceClient.disconnect": "api/voice.html#disnake.VoiceClient.disconnect", "disnake.VoiceClient.move_to": "api/voice.html#disnake.VoiceClient.move_to", "disnake.VoiceClient.is_connected": "api/voice.html#disnake.VoiceClient.is_connected", "disnake.VoiceClient.play": "api/voice.html#disnake.VoiceClient.play", "disnake.VoiceClient.is_playing": "api/voice.html#disnake.VoiceClient.is_playing", "disnake.VoiceClient.is_paused": "api/voice.html#disnake.VoiceClient.is_paused", "disnake.VoiceClient.stop": "api/voice.html#disnake.VoiceClient.stop", "disnake.VoiceClient.pause": "api/voice.html#disnake.VoiceClient.pause", "disnake.VoiceClient.resume": "api/voice.html#disnake.VoiceClient.resume", "disnake.VoiceClient.source": "api/voice.html#disnake.VoiceClient.source", "disnake.VoiceClient.send_audio_packet": "api/voice.html#disnake.VoiceClient.send_audio_packet", "disnake.VoiceProtocol": "api/voice.html#disnake.VoiceProtocol", "disnake.VoiceProtocol.on_voice_state_update": "api/voice.html#disnake.VoiceProtocol.on_voice_state_update", "disnake.VoiceProtocol.on_voice_server_update": "api/voice.html#disnake.VoiceProtocol.on_voice_server_update", "disnake.VoiceProtocol.connect": "api/voice.html#disnake.VoiceProtocol.connect", "disnake.VoiceProtocol.disconnect": "api/voice.html#disnake.VoiceProtocol.disconnect", "disnake.VoiceProtocol.cleanup": "api/voice.html#disnake.VoiceProtocol.cleanup", "disnake.AudioSource": "api/voice.html#disnake.AudioSource", "disnake.AudioSource.read": "api/voice.html#disnake.AudioSource.read", "disnake.AudioSource.is_opus": "api/voice.html#disnake.AudioSource.is_opus", "disnake.AudioSource.cleanup": "api/voice.html#disnake.AudioSource.cleanup", "disnake.PCMAudio": "api/voice.html#disnake.PCMAudio", "disnake.PCMAudio.stream": "api/voice.html#disnake.PCMAudio.stream", "disnake.PCMAudio.read": "api/voice.html#disnake.PCMAudio.read", "disnake.FFmpegAudio": "api/voice.html#disnake.FFmpegAudio", "disnake.FFmpegAudio.cleanup": "api/voice.html#disnake.FFmpegAudio.cleanup", "disnake.FFmpegPCMAudio": "api/voice.html#disnake.FFmpegPCMAudio", "disnake.FFmpegPCMAudio.read": "api/voice.html#disnake.FFmpegPCMAudio.read", "disnake.FFmpegPCMAudio.is_opus": "api/voice.html#disnake.FFmpegPCMAudio.is_opus", "disnake.FFmpegOpusAudio": "api/voice.html#disnake.FFmpegOpusAudio", "disnake.FFmpegOpusAudio.from_probe": "api/voice.html#disnake.FFmpegOpusAudio.from_probe", "disnake.FFmpegOpusAudio.probe": "api/voice.html#disnake.FFmpegOpusAudio.probe", "disnake.FFmpegOpusAudio.read": "api/voice.html#disnake.FFmpegOpusAudio.read", "disnake.FFmpegOpusAudio.is_opus": "api/voice.html#disnake.FFmpegOpusAudio.is_opus", "disnake.PCMVolumeTransformer": "api/voice.html#disnake.PCMVolumeTransformer", "disnake.PCMVolumeTransformer.volume": "api/voice.html#disnake.PCMVolumeTransformer.volume", "disnake.PCMVolumeTransformer.cleanup": "api/voice.html#disnake.PCMVolumeTransformer.cleanup", "disnake.PCMVolumeTransformer.read": "api/voice.html#disnake.PCMVolumeTransformer.read", "disnake.opus.load_opus": "api/voice.html#disnake.opus.load_opus", "disnake.opus.is_loaded": "api/voice.html#disnake.opus.is_loaded", "disnake.VoiceRegion": "api/voice.html#disnake.VoiceRegion", "disnake.VoiceRegion.id": "api/voice.html#disnake.VoiceRegion.id", "disnake.VoiceRegion.name": "api/voice.html#disnake.VoiceRegion.name", "disnake.VoiceRegion.optimal": "api/voice.html#disnake.VoiceRegion.optimal", "disnake.VoiceRegion.deprecated": "api/voice.html#disnake.VoiceRegion.deprecated", "disnake.VoiceRegion.custom": "api/voice.html#disnake.VoiceRegion.custom", "disnake.PartyType": "api/voice.html#disnake.PartyType", "disnake.PartyType.poker": "api/voice.html#disnake.PartyType.poker", "disnake.PartyType.betrayal": "api/voice.html#disnake.PartyType.betrayal", "disnake.PartyType.fishing": "api/voice.html#disnake.PartyType.fishing", "disnake.PartyType.chess": "api/voice.html#disnake.PartyType.chess", "disnake.PartyType.letter_tile": "api/voice.html#disnake.PartyType.letter_tile", "disnake.PartyType.word_snack": "api/voice.html#disnake.PartyType.word_snack", "disnake.PartyType.doodle_crew": "api/voice.html#disnake.PartyType.doodle_crew", "disnake.PartyType.checkers": "api/voice.html#disnake.PartyType.checkers", "disnake.PartyType.spellcast": "api/voice.html#disnake.PartyType.spellcast", "disnake.PartyType.watch_together": "api/voice.html#disnake.PartyType.watch_together", "disnake.PartyType.sketch_heads": "api/voice.html#disnake.PartyType.sketch_heads", "disnake.PartyType.ocho": "api/voice.html#disnake.PartyType.ocho", "disnake.Webhook": "api/webhooks.html#disnake.Webhook", "disnake.Webhook.id": "api/webhooks.html#disnake.Webhook.id", "disnake.Webhook.type": "api/webhooks.html#disnake.Webhook.type", "disnake.Webhook.token": "api/webhooks.html#disnake.Webhook.token", "disnake.Webhook.guild_id": "api/webhooks.html#disnake.Webhook.guild_id", "disnake.Webhook.channel_id": "api/webhooks.html#disnake.Webhook.channel_id", "disnake.Webhook.user": "api/webhooks.html#disnake.Webhook.user", "disnake.Webhook.name": "api/webhooks.html#disnake.Webhook.name", "disnake.Webhook.source_guild": "api/webhooks.html#disnake.Webhook.source_guild", "disnake.Webhook.source_channel": "api/webhooks.html#disnake.Webhook.source_channel", "disnake.Webhook.application_id": "api/webhooks.html#disnake.Webhook.application_id", "disnake.Webhook.url": "api/webhooks.html#disnake.Webhook.url", "disnake.Webhook.partial": "api/webhooks.html#disnake.Webhook.partial", "disnake.Webhook.from_url": "api/webhooks.html#disnake.Webhook.from_url", "disnake.Webhook.fetch": "api/webhooks.html#disnake.Webhook.fetch", "disnake.Webhook.delete": "api/webhooks.html#disnake.Webhook.delete", "disnake.Webhook.edit": "api/webhooks.html#disnake.Webhook.edit", "disnake.Webhook.avatar": "api/webhooks.html#disnake.Webhook.avatar", "disnake.Webhook.channel": "api/webhooks.html#disnake.Webhook.channel", "disnake.Webhook.created_at": "api/webhooks.html#disnake.Webhook.created_at", "disnake.Webhook.guild": "api/webhooks.html#disnake.Webhook.guild", "disnake.Webhook.is_authenticated": "api/webhooks.html#disnake.Webhook.is_authenticated", "disnake.Webhook.is_partial": "api/webhooks.html#disnake.Webhook.is_partial", "disnake.Webhook.send": "api/webhooks.html#disnake.Webhook.send", "disnake.Webhook.fetch_message": "api/webhooks.html#disnake.Webhook.fetch_message", "disnake.Webhook.edit_message": "api/webhooks.html#disnake.Webhook.edit_message", "disnake.Webhook.delete_message": "api/webhooks.html#disnake.Webhook.delete_message", "disnake.WebhookMessage": "api/webhooks.html#disnake.WebhookMessage", "disnake.WebhookMessage.edit": "api/webhooks.html#disnake.WebhookMessage.edit", "disnake.WebhookMessage.delete": "api/webhooks.html#disnake.WebhookMessage.delete", "disnake.SyncWebhook": "api/webhooks.html#disnake.SyncWebhook", "disnake.SyncWebhook.id": "api/webhooks.html#disnake.SyncWebhook.id", "disnake.SyncWebhook.type": "api/webhooks.html#disnake.SyncWebhook.type", "disnake.SyncWebhook.token": "api/webhooks.html#disnake.SyncWebhook.token", "disnake.SyncWebhook.guild_id": "api/webhooks.html#disnake.SyncWebhook.guild_id", "disnake.SyncWebhook.channel_id": "api/webhooks.html#disnake.SyncWebhook.channel_id", "disnake.SyncWebhook.user": "api/webhooks.html#disnake.SyncWebhook.user", "disnake.SyncWebhook.name": "api/webhooks.html#disnake.SyncWebhook.name", "disnake.SyncWebhook.source_guild": "api/webhooks.html#disnake.SyncWebhook.source_guild", "disnake.SyncWebhook.source_channel": "api/webhooks.html#disnake.SyncWebhook.source_channel", "disnake.SyncWebhook.application_id": "api/webhooks.html#disnake.SyncWebhook.application_id", "disnake.SyncWebhook.url": "api/webhooks.html#disnake.SyncWebhook.url", "disnake.SyncWebhook.partial": "api/webhooks.html#disnake.SyncWebhook.partial", "disnake.SyncWebhook.from_url": "api/webhooks.html#disnake.SyncWebhook.from_url", "disnake.SyncWebhook.fetch": "api/webhooks.html#disnake.SyncWebhook.fetch", "disnake.SyncWebhook.delete": "api/webhooks.html#disnake.SyncWebhook.delete", "disnake.SyncWebhook.edit": "api/webhooks.html#disnake.SyncWebhook.edit", "disnake.SyncWebhook.send": "api/webhooks.html#disnake.SyncWebhook.send", "disnake.SyncWebhook.fetch_message": "api/webhooks.html#disnake.SyncWebhook.fetch_message", "disnake.SyncWebhook.avatar": "api/webhooks.html#disnake.SyncWebhook.avatar", "disnake.SyncWebhook.channel": "api/webhooks.html#disnake.SyncWebhook.channel", "disnake.SyncWebhook.created_at": "api/webhooks.html#disnake.SyncWebhook.created_at", "disnake.SyncWebhook.edit_message": "api/webhooks.html#disnake.SyncWebhook.edit_message", "disnake.SyncWebhook.guild": "api/webhooks.html#disnake.SyncWebhook.guild", "disnake.SyncWebhook.is_authenticated": "api/webhooks.html#disnake.SyncWebhook.is_authenticated", "disnake.SyncWebhook.is_partial": "api/webhooks.html#disnake.SyncWebhook.is_partial", "disnake.SyncWebhook.delete_message": "api/webhooks.html#disnake.SyncWebhook.delete_message", "disnake.SyncWebhookMessage": "api/webhooks.html#disnake.SyncWebhookMessage", "disnake.SyncWebhookMessage.edit": "api/webhooks.html#disnake.SyncWebhookMessage.edit", "disnake.SyncWebhookMessage.delete": "api/webhooks.html#disnake.SyncWebhookMessage.delete", "disnake.PartialWebhookGuild": "api/webhooks.html#disnake.PartialWebhookGuild", "disnake.PartialWebhookGuild.id": "api/webhooks.html#disnake.PartialWebhookGuild.id", "disnake.PartialWebhookGuild.name": "api/webhooks.html#disnake.PartialWebhookGuild.name", "disnake.PartialWebhookGuild.icon": "api/webhooks.html#disnake.PartialWebhookGuild.icon", "disnake.PartialWebhookChannel": "api/webhooks.html#disnake.PartialWebhookChannel", "disnake.PartialWebhookChannel.id": "api/webhooks.html#disnake.PartialWebhookChannel.id", "disnake.PartialWebhookChannel.name": "api/webhooks.html#disnake.PartialWebhookChannel.name", "disnake.WebhookType": "api/webhooks.html#disnake.WebhookType", "disnake.WebhookType.incoming": "api/webhooks.html#disnake.WebhookType.incoming", "disnake.WebhookType.channel_follower": "api/webhooks.html#disnake.WebhookType.channel_follower", "disnake.WebhookType.application": "api/webhooks.html#disnake.WebhookType.application", "disnake.Widget": "api/widgets.html#disnake.Widget", "disnake.Widget.id": "api/widgets.html#disnake.Widget.id", "disnake.Widget.name": "api/widgets.html#disnake.Widget.name", "disnake.Widget.channels": "api/widgets.html#disnake.Widget.channels", "disnake.Widget.members": "api/widgets.html#disnake.Widget.members", "disnake.Widget.presence_count": "api/widgets.html#disnake.Widget.presence_count", "disnake.Widget.created_at": "api/widgets.html#disnake.Widget.created_at", "disnake.Widget.json_url": "api/widgets.html#disnake.Widget.json_url", "disnake.Widget.invite_url": "api/widgets.html#disnake.Widget.invite_url", "disnake.Widget.fetch_invite": "api/widgets.html#disnake.Widget.fetch_invite", "disnake.Widget.edit": "api/widgets.html#disnake.Widget.edit", "disnake.Widget.image_url": "api/widgets.html#disnake.Widget.image_url", "disnake.WidgetSettings": "api/widgets.html#disnake.WidgetSettings", "disnake.WidgetSettings.guild": "api/widgets.html#disnake.WidgetSettings.guild", "disnake.WidgetSettings.enabled": "api/widgets.html#disnake.WidgetSettings.enabled", "disnake.WidgetSettings.channel_id": "api/widgets.html#disnake.WidgetSettings.channel_id", "disnake.WidgetSettings.channel": "api/widgets.html#disnake.WidgetSettings.channel", "disnake.WidgetSettings.edit": "api/widgets.html#disnake.WidgetSettings.edit", "disnake.WidgetChannel": "api/widgets.html#disnake.WidgetChannel", "disnake.WidgetChannel.id": "api/widgets.html#disnake.WidgetChannel.id", "disnake.WidgetChannel.name": "api/widgets.html#disnake.WidgetChannel.name", "disnake.WidgetChannel.position": "api/widgets.html#disnake.WidgetChannel.position", "disnake.WidgetChannel.mention": "api/widgets.html#disnake.WidgetChannel.mention", "disnake.WidgetChannel.created_at": "api/widgets.html#disnake.WidgetChannel.created_at", "disnake.WidgetMember": "api/widgets.html#disnake.WidgetMember", "disnake.WidgetMember.id": "api/widgets.html#disnake.WidgetMember.id", "disnake.WidgetMember.name": "api/widgets.html#disnake.WidgetMember.name", "disnake.WidgetMember.discriminator": "api/widgets.html#disnake.WidgetMember.discriminator", "disnake.WidgetMember.status": "api/widgets.html#disnake.WidgetMember.status", "disnake.WidgetMember.activity": "api/widgets.html#disnake.WidgetMember.activity", "disnake.WidgetMember.deafened": "api/widgets.html#disnake.WidgetMember.deafened", "disnake.WidgetMember.muted": "api/widgets.html#disnake.WidgetMember.muted", "disnake.WidgetMember.suppress": "api/widgets.html#disnake.WidgetMember.suppress", "disnake.WidgetMember.connected_channel": "api/widgets.html#disnake.WidgetMember.connected_channel", "disnake.WidgetMember.avatar": "api/widgets.html#disnake.WidgetMember.avatar", "disnake.WidgetMember.display_name": "api/widgets.html#disnake.WidgetMember.display_name", "disnake.WidgetMember.display_avatar": "api/widgets.html#disnake.WidgetMember.display_avatar", "disnake.WidgetStyle": "api/widgets.html#disnake.WidgetStyle", "disnake.WidgetStyle.shield": "api/widgets.html#disnake.WidgetStyle.shield", "disnake.WidgetStyle.banner1": "api/widgets.html#disnake.WidgetStyle.banner1", "disnake.WidgetStyle.banner2": "api/widgets.html#disnake.WidgetStyle.banner2", "disnake.WidgetStyle.banner3": "api/widgets.html#disnake.WidgetStyle.banner3", "disnake.WidgetStyle.banner4": "api/widgets.html#disnake.WidgetStyle.banner4", "disnake.ext.commands.InvokableApplicationCommand": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableApplicationCommand", "disnake.ext.commands.InvokableApplicationCommand.name": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableApplicationCommand.name", "disnake.ext.commands.InvokableApplicationCommand.qualified_name": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableApplicationCommand.qualified_name", "disnake.ext.commands.InvokableApplicationCommand.body": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableApplicationCommand.body", "disnake.ext.commands.InvokableApplicationCommand.callback": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableApplicationCommand.callback", "disnake.ext.commands.InvokableApplicationCommand.cog": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableApplicationCommand.cog", "disnake.ext.commands.InvokableApplicationCommand.checks": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableApplicationCommand.checks", "disnake.ext.commands.InvokableApplicationCommand.guild_ids": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableApplicationCommand.guild_ids", "disnake.ext.commands.InvokableApplicationCommand.auto_sync": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableApplicationCommand.auto_sync", "disnake.ext.commands.InvokableApplicationCommand.extras": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableApplicationCommand.extras", "disnake.ext.commands.InvokableApplicationCommand.before_invoke": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableApplicationCommand.before_invoke", "disnake.ext.commands.InvokableApplicationCommand.after_invoke": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableApplicationCommand.after_invoke", "disnake.ext.commands.InvokableApplicationCommand.error": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableApplicationCommand.error", "disnake.ext.commands.InvokableApplicationCommand.copy": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableApplicationCommand.copy", "disnake.ext.commands.InvokableApplicationCommand.dm_permission": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableApplicationCommand.dm_permission", "disnake.ext.commands.InvokableApplicationCommand.default_member_permissions": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableApplicationCommand.default_member_permissions", "disnake.ext.commands.InvokableApplicationCommand.add_check": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableApplicationCommand.add_check", "disnake.ext.commands.InvokableApplicationCommand.remove_check": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableApplicationCommand.remove_check", "disnake.ext.commands.InvokableApplicationCommand.is_on_cooldown": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableApplicationCommand.is_on_cooldown", "disnake.ext.commands.InvokableApplicationCommand.reset_cooldown": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableApplicationCommand.reset_cooldown", "disnake.ext.commands.InvokableApplicationCommand.get_cooldown_retry_after": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableApplicationCommand.get_cooldown_retry_after", "disnake.ext.commands.InvokableApplicationCommand.invoke": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableApplicationCommand.invoke", "disnake.ext.commands.InvokableApplicationCommand.has_error_handler": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableApplicationCommand.has_error_handler", "disnake.ext.commands.InvokableApplicationCommand.cog_name": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableApplicationCommand.cog_name", "disnake.ext.commands.InvokableApplicationCommand.can_run": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableApplicationCommand.can_run", "disnake.ext.commands.InvokableSlashCommand": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableSlashCommand", "disnake.ext.commands.InvokableSlashCommand.name": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableSlashCommand.name", "disnake.ext.commands.InvokableSlashCommand.qualified_name": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableSlashCommand.qualified_name", "disnake.ext.commands.InvokableSlashCommand.body": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableSlashCommand.body", "disnake.ext.commands.InvokableSlashCommand.callback": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableSlashCommand.callback", "disnake.ext.commands.InvokableSlashCommand.cog": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableSlashCommand.cog", "disnake.ext.commands.InvokableSlashCommand.checks": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableSlashCommand.checks", "disnake.ext.commands.InvokableSlashCommand.guild_ids": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableSlashCommand.guild_ids", "disnake.ext.commands.InvokableSlashCommand.connectors": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableSlashCommand.connectors", "disnake.ext.commands.InvokableSlashCommand.auto_sync": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableSlashCommand.auto_sync", "disnake.ext.commands.InvokableSlashCommand.extras": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableSlashCommand.extras", "disnake.ext.commands.InvokableSlashCommand.parent": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableSlashCommand.parent", "disnake.ext.commands.InvokableSlashCommand.sub_command": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableSlashCommand.sub_command", "disnake.ext.commands.InvokableSlashCommand.sub_command_group": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableSlashCommand.sub_command_group", "disnake.ext.commands.InvokableSlashCommand.after_invoke": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableSlashCommand.after_invoke", "disnake.ext.commands.InvokableSlashCommand.before_invoke": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableSlashCommand.before_invoke", "disnake.ext.commands.InvokableSlashCommand.error": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableSlashCommand.error", "disnake.ext.commands.InvokableSlashCommand.root_parent": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableSlashCommand.root_parent", "disnake.ext.commands.InvokableSlashCommand.parents": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableSlashCommand.parents", "disnake.ext.commands.InvokableSlashCommand.autocomplete": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableSlashCommand.autocomplete", "disnake.ext.commands.InvokableSlashCommand.invoke": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableSlashCommand.invoke", "disnake.ext.commands.SubCommand": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommand", "disnake.ext.commands.SubCommand.name": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommand.name", "disnake.ext.commands.SubCommand.qualified_name": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommand.qualified_name", "disnake.ext.commands.SubCommand.parent": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommand.parent", "disnake.ext.commands.SubCommand.option": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommand.option", "disnake.ext.commands.SubCommand.callback": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommand.callback", "disnake.ext.commands.SubCommand.cog": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommand.cog", "disnake.ext.commands.SubCommand.checks": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommand.checks", "disnake.ext.commands.SubCommand.connectors": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommand.connectors", "disnake.ext.commands.SubCommand.extras": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommand.extras", "disnake.ext.commands.SubCommand.after_invoke": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommand.after_invoke", "disnake.ext.commands.SubCommand.before_invoke": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommand.before_invoke", "disnake.ext.commands.SubCommand.error": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommand.error", "disnake.ext.commands.SubCommand.root_parent": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommand.root_parent", "disnake.ext.commands.SubCommand.parents": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommand.parents", "disnake.ext.commands.SubCommand.invoke": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommand.invoke", "disnake.ext.commands.SubCommand.autocomplete": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommand.autocomplete", "disnake.ext.commands.SubCommandGroup": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommandGroup", "disnake.ext.commands.SubCommandGroup.name": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommandGroup.name", "disnake.ext.commands.SubCommandGroup.qualified_name": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommandGroup.qualified_name", "disnake.ext.commands.SubCommandGroup.parent": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommandGroup.parent", "disnake.ext.commands.SubCommandGroup.option": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommandGroup.option", "disnake.ext.commands.SubCommandGroup.callback": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommandGroup.callback", "disnake.ext.commands.SubCommandGroup.cog": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommandGroup.cog", "disnake.ext.commands.SubCommandGroup.checks": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommandGroup.checks", "disnake.ext.commands.SubCommandGroup.extras": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommandGroup.extras", "disnake.ext.commands.SubCommandGroup.sub_command": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommandGroup.sub_command", "disnake.ext.commands.SubCommandGroup.after_invoke": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommandGroup.after_invoke", "disnake.ext.commands.SubCommandGroup.before_invoke": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommandGroup.before_invoke", "disnake.ext.commands.SubCommandGroup.error": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommandGroup.error", "disnake.ext.commands.SubCommandGroup.root_parent": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommandGroup.root_parent", "disnake.ext.commands.SubCommandGroup.parents": "ext/commands/api/app_commands.html#disnake.ext.commands.SubCommandGroup.parents", "disnake.ext.commands.InvokableUserCommand": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableUserCommand", "disnake.ext.commands.InvokableUserCommand.name": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableUserCommand.name", "disnake.ext.commands.InvokableUserCommand.qualified_name": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableUserCommand.qualified_name", "disnake.ext.commands.InvokableUserCommand.body": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableUserCommand.body", "disnake.ext.commands.InvokableUserCommand.callback": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableUserCommand.callback", "disnake.ext.commands.InvokableUserCommand.cog": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableUserCommand.cog", "disnake.ext.commands.InvokableUserCommand.checks": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableUserCommand.checks", "disnake.ext.commands.InvokableUserCommand.guild_ids": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableUserCommand.guild_ids", "disnake.ext.commands.InvokableUserCommand.auto_sync": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableUserCommand.auto_sync", "disnake.ext.commands.InvokableUserCommand.extras": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableUserCommand.extras", "disnake.ext.commands.InvokableUserCommand.after_invoke": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableUserCommand.after_invoke", "disnake.ext.commands.InvokableUserCommand.before_invoke": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableUserCommand.before_invoke", "disnake.ext.commands.InvokableUserCommand.error": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableUserCommand.error", "disnake.ext.commands.InvokableUserCommand.__call__": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableUserCommand.__call__", "disnake.ext.commands.InvokableMessageCommand": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableMessageCommand", "disnake.ext.commands.InvokableMessageCommand.name": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableMessageCommand.name", "disnake.ext.commands.InvokableMessageCommand.qualified_name": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableMessageCommand.qualified_name", "disnake.ext.commands.InvokableMessageCommand.body": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableMessageCommand.body", "disnake.ext.commands.InvokableMessageCommand.callback": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableMessageCommand.callback", "disnake.ext.commands.InvokableMessageCommand.cog": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableMessageCommand.cog", "disnake.ext.commands.InvokableMessageCommand.checks": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableMessageCommand.checks", "disnake.ext.commands.InvokableMessageCommand.guild_ids": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableMessageCommand.guild_ids", "disnake.ext.commands.InvokableMessageCommand.auto_sync": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableMessageCommand.auto_sync", "disnake.ext.commands.InvokableMessageCommand.extras": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableMessageCommand.extras", "disnake.ext.commands.InvokableMessageCommand.after_invoke": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableMessageCommand.after_invoke", "disnake.ext.commands.InvokableMessageCommand.before_invoke": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableMessageCommand.before_invoke", "disnake.ext.commands.InvokableMessageCommand.error": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableMessageCommand.error", "disnake.ext.commands.InvokableMessageCommand.__call__": "ext/commands/api/app_commands.html#disnake.ext.commands.InvokableMessageCommand.__call__", "disnake.ext.commands.Injection": "ext/commands/api/app_commands.html#disnake.ext.commands.Injection", "disnake.ext.commands.Injection.function": "ext/commands/api/app_commands.html#disnake.ext.commands.Injection.function", "disnake.ext.commands.Injection.autocompleters": "ext/commands/api/app_commands.html#disnake.ext.commands.Injection.autocompleters", "disnake.ext.commands.Injection.autocomplete": "ext/commands/api/app_commands.html#disnake.ext.commands.Injection.autocomplete", "disnake.ext.commands.Injection.__call__": "ext/commands/api/app_commands.html#disnake.ext.commands.Injection.__call__", "disnake.ext.commands.ParamInfo": "ext/commands/api/app_commands.html#disnake.ext.commands.ParamInfo", "disnake.ext.commands.LargeInt": "ext/commands/api/app_commands.html#disnake.ext.commands.LargeInt", "disnake.ext.commands.Range": "ext/commands/api/app_commands.html#disnake.ext.commands.Range", "disnake.ext.commands.String": "ext/commands/api/app_commands.html#disnake.ext.commands.String", "disnake.ext.commands.Param": "ext/commands/api/app_commands.html#disnake.ext.commands.Param", "disnake.ext.commands.slash_command": "ext/commands/api/app_commands.html#disnake.ext.commands.slash_command", "disnake.ext.commands.message_command": "ext/commands/api/app_commands.html#disnake.ext.commands.message_command", "disnake.ext.commands.user_command": "ext/commands/api/app_commands.html#disnake.ext.commands.user_command", "disnake.ext.commands.inject": "ext/commands/api/app_commands.html#disnake.ext.commands.inject", "disnake.ext.commands.register_injection": "ext/commands/api/app_commands.html#disnake.ext.commands.register_injection", "disnake.ext.commands.injection": "ext/commands/api/app_commands.html#disnake.ext.commands.injection", "disnake.ext.commands.Bot": "ext/commands/api/bots.html#disnake.ext.commands.Bot", "disnake.ext.commands.Bot.command_prefix": "ext/commands/api/bots.html#disnake.ext.commands.Bot.command_prefix", "disnake.ext.commands.Bot.case_insensitive": "ext/commands/api/bots.html#disnake.ext.commands.Bot.case_insensitive", "disnake.ext.commands.Bot.description": "ext/commands/api/bots.html#disnake.ext.commands.Bot.description", "disnake.ext.commands.Bot.help_command": "ext/commands/api/bots.html#disnake.ext.commands.Bot.help_command", "disnake.ext.commands.Bot.owner_id": "ext/commands/api/bots.html#disnake.ext.commands.Bot.owner_id", "disnake.ext.commands.Bot.owner_ids": "ext/commands/api/bots.html#disnake.ext.commands.Bot.owner_ids", "disnake.ext.commands.Bot.strip_after_prefix": "ext/commands/api/bots.html#disnake.ext.commands.Bot.strip_after_prefix", "disnake.ext.commands.Bot.reload": "ext/commands/api/bots.html#disnake.ext.commands.Bot.reload", "disnake.ext.commands.Bot.i18n": "ext/commands/api/bots.html#disnake.ext.commands.Bot.i18n", "disnake.ext.commands.Bot.after_invoke": "ext/commands/api/bots.html#disnake.ext.commands.Bot.after_invoke", "disnake.ext.commands.Bot.after_slash_command_invoke": "ext/commands/api/bots.html#disnake.ext.commands.Bot.after_slash_command_invoke", "disnake.ext.commands.Bot.after_user_command_invoke": "ext/commands/api/bots.html#disnake.ext.commands.Bot.after_user_command_invoke", "disnake.ext.commands.Bot.after_message_command_invoke": "ext/commands/api/bots.html#disnake.ext.commands.Bot.after_message_command_invoke", "disnake.ext.commands.Bot.before_invoke": "ext/commands/api/bots.html#disnake.ext.commands.Bot.before_invoke", "disnake.ext.commands.Bot.before_slash_command_invoke": "ext/commands/api/bots.html#disnake.ext.commands.Bot.before_slash_command_invoke", "disnake.ext.commands.Bot.before_user_command_invoke": "ext/commands/api/bots.html#disnake.ext.commands.Bot.before_user_command_invoke", "disnake.ext.commands.Bot.before_message_command_invoke": "ext/commands/api/bots.html#disnake.ext.commands.Bot.before_message_command_invoke", "disnake.ext.commands.Bot.check": "ext/commands/api/bots.html#disnake.ext.commands.Bot.check", "disnake.ext.commands.Bot.check_once": "ext/commands/api/bots.html#disnake.ext.commands.Bot.check_once", "disnake.ext.commands.Bot.command": "ext/commands/api/bots.html#disnake.ext.commands.Bot.command", "disnake.ext.commands.Bot.slash_command": "ext/commands/api/bots.html#disnake.ext.commands.Bot.slash_command", "disnake.ext.commands.Bot.user_command": "ext/commands/api/bots.html#disnake.ext.commands.Bot.user_command", "disnake.ext.commands.Bot.message_command": "ext/commands/api/bots.html#disnake.ext.commands.Bot.message_command", "disnake.ext.commands.Bot.event": "ext/commands/api/bots.html#disnake.ext.commands.Bot.event", "disnake.ext.commands.Bot.group": "ext/commands/api/bots.html#disnake.ext.commands.Bot.group", "disnake.ext.commands.Bot.listen": "ext/commands/api/bots.html#disnake.ext.commands.Bot.listen", "disnake.ext.commands.Bot.activity": "ext/commands/api/bots.html#disnake.ext.commands.Bot.activity", "disnake.ext.commands.Bot.add_app_command_check": "ext/commands/api/bots.html#disnake.ext.commands.Bot.add_app_command_check", "disnake.ext.commands.Bot.add_check": "ext/commands/api/bots.html#disnake.ext.commands.Bot.add_check", "disnake.ext.commands.Bot.add_cog": "ext/commands/api/bots.html#disnake.ext.commands.Bot.add_cog", "disnake.ext.commands.Bot.add_command": "ext/commands/api/bots.html#disnake.ext.commands.Bot.add_command", "disnake.ext.commands.Bot.add_listener": "ext/commands/api/bots.html#disnake.ext.commands.Bot.add_listener", "disnake.ext.commands.Bot.add_message_command": "ext/commands/api/bots.html#disnake.ext.commands.Bot.add_message_command", "disnake.ext.commands.Bot.add_slash_command": "ext/commands/api/bots.html#disnake.ext.commands.Bot.add_slash_command", "disnake.ext.commands.Bot.add_user_command": "ext/commands/api/bots.html#disnake.ext.commands.Bot.add_user_command", "disnake.ext.commands.Bot.add_view": "ext/commands/api/bots.html#disnake.ext.commands.Bot.add_view", "disnake.ext.commands.Bot.allowed_mentions": "ext/commands/api/bots.html#disnake.ext.commands.Bot.allowed_mentions", "disnake.ext.commands.Bot.application_command_check": "ext/commands/api/bots.html#disnake.ext.commands.Bot.application_command_check", "disnake.ext.commands.Bot.application_commands": "ext/commands/api/bots.html#disnake.ext.commands.Bot.application_commands", "disnake.ext.commands.Bot.application_flags": "ext/commands/api/bots.html#disnake.ext.commands.Bot.application_flags", "disnake.ext.commands.Bot.application_id": "ext/commands/api/bots.html#disnake.ext.commands.Bot.application_id", "disnake.ext.commands.Bot.application_info": "ext/commands/api/bots.html#disnake.ext.commands.Bot.application_info", "disnake.ext.commands.Bot.before_identify_hook": "ext/commands/api/bots.html#disnake.ext.commands.Bot.before_identify_hook", "disnake.ext.commands.Bot.bulk_fetch_command_permissions": "ext/commands/api/bots.html#disnake.ext.commands.Bot.bulk_fetch_command_permissions", "disnake.ext.commands.Bot.bulk_overwrite_global_commands": "ext/commands/api/bots.html#disnake.ext.commands.Bot.bulk_overwrite_global_commands", "disnake.ext.commands.Bot.bulk_overwrite_guild_commands": "ext/commands/api/bots.html#disnake.ext.commands.Bot.bulk_overwrite_guild_commands", "disnake.ext.commands.Bot.cached_messages": "ext/commands/api/bots.html#disnake.ext.commands.Bot.cached_messages", "disnake.ext.commands.Bot.change_presence": "ext/commands/api/bots.html#disnake.ext.commands.Bot.change_presence", "disnake.ext.commands.Bot.clear": "ext/commands/api/bots.html#disnake.ext.commands.Bot.clear", "disnake.ext.commands.Bot.close": "ext/commands/api/bots.html#disnake.ext.commands.Bot.close", "disnake.ext.commands.Bot.cogs": "ext/commands/api/bots.html#disnake.ext.commands.Bot.cogs", "disnake.ext.commands.Bot.commands": "ext/commands/api/bots.html#disnake.ext.commands.Bot.commands", "disnake.ext.commands.Bot.connect": "ext/commands/api/bots.html#disnake.ext.commands.Bot.connect", "disnake.ext.commands.Bot.create_dm": "ext/commands/api/bots.html#disnake.ext.commands.Bot.create_dm", "disnake.ext.commands.Bot.create_global_command": "ext/commands/api/bots.html#disnake.ext.commands.Bot.create_global_command", "disnake.ext.commands.Bot.create_guild": "ext/commands/api/bots.html#disnake.ext.commands.Bot.create_guild", "disnake.ext.commands.Bot.create_guild_command": "ext/commands/api/bots.html#disnake.ext.commands.Bot.create_guild_command", "disnake.ext.commands.Bot.delete_global_command": "ext/commands/api/bots.html#disnake.ext.commands.Bot.delete_global_command", "disnake.ext.commands.Bot.delete_guild_command": "ext/commands/api/bots.html#disnake.ext.commands.Bot.delete_guild_command", "disnake.ext.commands.Bot.delete_invite": "ext/commands/api/bots.html#disnake.ext.commands.Bot.delete_invite", "disnake.ext.commands.Bot.edit_global_command": "ext/commands/api/bots.html#disnake.ext.commands.Bot.edit_global_command", "disnake.ext.commands.Bot.edit_guild_command": "ext/commands/api/bots.html#disnake.ext.commands.Bot.edit_guild_command", "disnake.ext.commands.Bot.emojis": "ext/commands/api/bots.html#disnake.ext.commands.Bot.emojis", "disnake.ext.commands.Bot.extensions": "ext/commands/api/bots.html#disnake.ext.commands.Bot.extensions", "disnake.ext.commands.Bot.fetch_channel": "ext/commands/api/bots.html#disnake.ext.commands.Bot.fetch_channel", "disnake.ext.commands.Bot.fetch_command_permissions": "ext/commands/api/bots.html#disnake.ext.commands.Bot.fetch_command_permissions", "disnake.ext.commands.Bot.fetch_global_command": "ext/commands/api/bots.html#disnake.ext.commands.Bot.fetch_global_command", "disnake.ext.commands.Bot.fetch_global_commands": "ext/commands/api/bots.html#disnake.ext.commands.Bot.fetch_global_commands", "disnake.ext.commands.Bot.fetch_guild": "ext/commands/api/bots.html#disnake.ext.commands.Bot.fetch_guild", "disnake.ext.commands.Bot.fetch_guild_command": "ext/commands/api/bots.html#disnake.ext.commands.Bot.fetch_guild_command", "disnake.ext.commands.Bot.fetch_guild_commands": "ext/commands/api/bots.html#disnake.ext.commands.Bot.fetch_guild_commands", "disnake.ext.commands.Bot.fetch_guild_preview": "ext/commands/api/bots.html#disnake.ext.commands.Bot.fetch_guild_preview", "disnake.ext.commands.Bot.fetch_guilds": "ext/commands/api/bots.html#disnake.ext.commands.Bot.fetch_guilds", "disnake.ext.commands.Bot.fetch_invite": "ext/commands/api/bots.html#disnake.ext.commands.Bot.fetch_invite", "disnake.ext.commands.Bot.fetch_premium_sticker_packs": "ext/commands/api/bots.html#disnake.ext.commands.Bot.fetch_premium_sticker_packs", "disnake.ext.commands.Bot.fetch_stage_instance": "ext/commands/api/bots.html#disnake.ext.commands.Bot.fetch_stage_instance", "disnake.ext.commands.Bot.fetch_sticker": "ext/commands/api/bots.html#disnake.ext.commands.Bot.fetch_sticker", "disnake.ext.commands.Bot.fetch_template": "ext/commands/api/bots.html#disnake.ext.commands.Bot.fetch_template", "disnake.ext.commands.Bot.fetch_user": "ext/commands/api/bots.html#disnake.ext.commands.Bot.fetch_user", "disnake.ext.commands.Bot.fetch_voice_regions": "ext/commands/api/bots.html#disnake.ext.commands.Bot.fetch_voice_regions", "disnake.ext.commands.Bot.fetch_webhook": "ext/commands/api/bots.html#disnake.ext.commands.Bot.fetch_webhook", "disnake.ext.commands.Bot.fetch_widget": "ext/commands/api/bots.html#disnake.ext.commands.Bot.fetch_widget", "disnake.ext.commands.Bot.get_all_channels": "ext/commands/api/bots.html#disnake.ext.commands.Bot.get_all_channels", "disnake.ext.commands.Bot.get_all_members": "ext/commands/api/bots.html#disnake.ext.commands.Bot.get_all_members", "disnake.ext.commands.Bot.get_channel": "ext/commands/api/bots.html#disnake.ext.commands.Bot.get_channel", "disnake.ext.commands.Bot.get_cog": "ext/commands/api/bots.html#disnake.ext.commands.Bot.get_cog", "disnake.ext.commands.Bot.get_command": "ext/commands/api/bots.html#disnake.ext.commands.Bot.get_command", "disnake.ext.commands.Bot.get_context": "ext/commands/api/bots.html#disnake.ext.commands.Bot.get_context", "disnake.ext.commands.Bot.get_emoji": "ext/commands/api/bots.html#disnake.ext.commands.Bot.get_emoji", "disnake.ext.commands.Bot.get_global_command": "ext/commands/api/bots.html#disnake.ext.commands.Bot.get_global_command", "disnake.ext.commands.Bot.get_global_command_named": "ext/commands/api/bots.html#disnake.ext.commands.Bot.get_global_command_named", "disnake.ext.commands.Bot.get_guild": "ext/commands/api/bots.html#disnake.ext.commands.Bot.get_guild", "disnake.ext.commands.Bot.get_guild_application_commands": "ext/commands/api/bots.html#disnake.ext.commands.Bot.get_guild_application_commands", "disnake.ext.commands.Bot.get_guild_command": "ext/commands/api/bots.html#disnake.ext.commands.Bot.get_guild_command", "disnake.ext.commands.Bot.get_guild_command_named": "ext/commands/api/bots.html#disnake.ext.commands.Bot.get_guild_command_named", "disnake.ext.commands.Bot.get_guild_message_commands": "ext/commands/api/bots.html#disnake.ext.commands.Bot.get_guild_message_commands", "disnake.ext.commands.Bot.get_guild_slash_commands": "ext/commands/api/bots.html#disnake.ext.commands.Bot.get_guild_slash_commands", "disnake.ext.commands.Bot.get_guild_user_commands": "ext/commands/api/bots.html#disnake.ext.commands.Bot.get_guild_user_commands", "disnake.ext.commands.Bot.get_message": "ext/commands/api/bots.html#disnake.ext.commands.Bot.get_message", "disnake.ext.commands.Bot.get_message_command": "ext/commands/api/bots.html#disnake.ext.commands.Bot.get_message_command", "disnake.ext.commands.Bot.get_or_fetch_user": "ext/commands/api/bots.html#disnake.ext.commands.Bot.get_or_fetch_user", "disnake.ext.commands.Bot.get_partial_messageable": "ext/commands/api/bots.html#disnake.ext.commands.Bot.get_partial_messageable", "disnake.ext.commands.Bot.get_prefix": "ext/commands/api/bots.html#disnake.ext.commands.Bot.get_prefix", "disnake.ext.commands.Bot.get_slash_command": "ext/commands/api/bots.html#disnake.ext.commands.Bot.get_slash_command", "disnake.ext.commands.Bot.get_stage_instance": "ext/commands/api/bots.html#disnake.ext.commands.Bot.get_stage_instance", "disnake.ext.commands.Bot.get_sticker": "ext/commands/api/bots.html#disnake.ext.commands.Bot.get_sticker", "disnake.ext.commands.Bot.get_user": "ext/commands/api/bots.html#disnake.ext.commands.Bot.get_user", "disnake.ext.commands.Bot.get_user_command": "ext/commands/api/bots.html#disnake.ext.commands.Bot.get_user_command", "disnake.ext.commands.Bot.getch_user": "ext/commands/api/bots.html#disnake.ext.commands.Bot.getch_user", "disnake.ext.commands.Bot.global_application_commands": "ext/commands/api/bots.html#disnake.ext.commands.Bot.global_application_commands", "disnake.ext.commands.Bot.global_message_commands": "ext/commands/api/bots.html#disnake.ext.commands.Bot.global_message_commands", "disnake.ext.commands.Bot.global_slash_commands": "ext/commands/api/bots.html#disnake.ext.commands.Bot.global_slash_commands", "disnake.ext.commands.Bot.global_user_commands": "ext/commands/api/bots.html#disnake.ext.commands.Bot.global_user_commands", "disnake.ext.commands.Bot.guilds": "ext/commands/api/bots.html#disnake.ext.commands.Bot.guilds", "disnake.ext.commands.Bot.intents": "ext/commands/api/bots.html#disnake.ext.commands.Bot.intents", "disnake.ext.commands.Bot.invoke": "ext/commands/api/bots.html#disnake.ext.commands.Bot.invoke", "disnake.ext.commands.Bot.is_closed": "ext/commands/api/bots.html#disnake.ext.commands.Bot.is_closed", "disnake.ext.commands.Bot.is_owner": "ext/commands/api/bots.html#disnake.ext.commands.Bot.is_owner", "disnake.ext.commands.Bot.is_ready": "ext/commands/api/bots.html#disnake.ext.commands.Bot.is_ready", "disnake.ext.commands.Bot.is_ws_ratelimited": "ext/commands/api/bots.html#disnake.ext.commands.Bot.is_ws_ratelimited", "disnake.ext.commands.Bot.latency": "ext/commands/api/bots.html#disnake.ext.commands.Bot.latency", "disnake.ext.commands.Bot.load_extension": "ext/commands/api/bots.html#disnake.ext.commands.Bot.load_extension", "disnake.ext.commands.Bot.load_extensions": "ext/commands/api/bots.html#disnake.ext.commands.Bot.load_extensions", "disnake.ext.commands.Bot.login": "ext/commands/api/bots.html#disnake.ext.commands.Bot.login", "disnake.ext.commands.Bot.message_command_check": "ext/commands/api/bots.html#disnake.ext.commands.Bot.message_command_check", "disnake.ext.commands.Bot.message_command_check_once": "ext/commands/api/bots.html#disnake.ext.commands.Bot.message_command_check_once", "disnake.ext.commands.Bot.message_commands": "ext/commands/api/bots.html#disnake.ext.commands.Bot.message_commands", "disnake.ext.commands.Bot.on_command_error": "ext/commands/api/bots.html#disnake.ext.commands.Bot.on_command_error", "disnake.ext.commands.Bot.on_error": "ext/commands/api/bots.html#disnake.ext.commands.Bot.on_error", "disnake.ext.commands.Bot.on_gateway_error": "ext/commands/api/bots.html#disnake.ext.commands.Bot.on_gateway_error", "disnake.ext.commands.Bot.on_message_command_error": "ext/commands/api/bots.html#disnake.ext.commands.Bot.on_message_command_error", "disnake.ext.commands.Bot.on_slash_command_error": "ext/commands/api/bots.html#disnake.ext.commands.Bot.on_slash_command_error", "disnake.ext.commands.Bot.on_user_command_error": "ext/commands/api/bots.html#disnake.ext.commands.Bot.on_user_command_error", "disnake.ext.commands.Bot.persistent_views": "ext/commands/api/bots.html#disnake.ext.commands.Bot.persistent_views", "disnake.ext.commands.Bot.private_channels": "ext/commands/api/bots.html#disnake.ext.commands.Bot.private_channels", "disnake.ext.commands.Bot.process_app_command_autocompletion": "ext/commands/api/bots.html#disnake.ext.commands.Bot.process_app_command_autocompletion", "disnake.ext.commands.Bot.process_application_commands": "ext/commands/api/bots.html#disnake.ext.commands.Bot.process_application_commands", "disnake.ext.commands.Bot.process_commands": "ext/commands/api/bots.html#disnake.ext.commands.Bot.process_commands", "disnake.ext.commands.Bot.reload_extension": "ext/commands/api/bots.html#disnake.ext.commands.Bot.reload_extension", "disnake.ext.commands.Bot.remove_app_command_check": "ext/commands/api/bots.html#disnake.ext.commands.Bot.remove_app_command_check", "disnake.ext.commands.Bot.remove_check": "ext/commands/api/bots.html#disnake.ext.commands.Bot.remove_check", "disnake.ext.commands.Bot.remove_cog": "ext/commands/api/bots.html#disnake.ext.commands.Bot.remove_cog", "disnake.ext.commands.Bot.remove_command": "ext/commands/api/bots.html#disnake.ext.commands.Bot.remove_command", "disnake.ext.commands.Bot.remove_listener": "ext/commands/api/bots.html#disnake.ext.commands.Bot.remove_listener", "disnake.ext.commands.Bot.remove_message_command": "ext/commands/api/bots.html#disnake.ext.commands.Bot.remove_message_command", "disnake.ext.commands.Bot.remove_slash_command": "ext/commands/api/bots.html#disnake.ext.commands.Bot.remove_slash_command", "disnake.ext.commands.Bot.remove_user_command": "ext/commands/api/bots.html#disnake.ext.commands.Bot.remove_user_command", "disnake.ext.commands.Bot.run": "ext/commands/api/bots.html#disnake.ext.commands.Bot.run", "disnake.ext.commands.Bot.slash_command_check": "ext/commands/api/bots.html#disnake.ext.commands.Bot.slash_command_check", "disnake.ext.commands.Bot.slash_command_check_once": "ext/commands/api/bots.html#disnake.ext.commands.Bot.slash_command_check_once", "disnake.ext.commands.Bot.slash_commands": "ext/commands/api/bots.html#disnake.ext.commands.Bot.slash_commands", "disnake.ext.commands.Bot.start": "ext/commands/api/bots.html#disnake.ext.commands.Bot.start", "disnake.ext.commands.Bot.status": "ext/commands/api/bots.html#disnake.ext.commands.Bot.status", "disnake.ext.commands.Bot.stickers": "ext/commands/api/bots.html#disnake.ext.commands.Bot.stickers", "disnake.ext.commands.Bot.unload_extension": "ext/commands/api/bots.html#disnake.ext.commands.Bot.unload_extension", "disnake.ext.commands.Bot.user": "ext/commands/api/bots.html#disnake.ext.commands.Bot.user", "disnake.ext.commands.Bot.user_command_check": "ext/commands/api/bots.html#disnake.ext.commands.Bot.user_command_check", "disnake.ext.commands.Bot.user_command_check_once": "ext/commands/api/bots.html#disnake.ext.commands.Bot.user_command_check_once", "disnake.ext.commands.Bot.user_commands": "ext/commands/api/bots.html#disnake.ext.commands.Bot.user_commands", "disnake.ext.commands.Bot.users": "ext/commands/api/bots.html#disnake.ext.commands.Bot.users", "disnake.ext.commands.Bot.voice_clients": "ext/commands/api/bots.html#disnake.ext.commands.Bot.voice_clients", "disnake.ext.commands.Bot.wait_for": "ext/commands/api/bots.html#disnake.ext.commands.Bot.wait_for", "disnake.ext.commands.Bot.wait_until_first_connect": "ext/commands/api/bots.html#disnake.ext.commands.Bot.wait_until_first_connect", "disnake.ext.commands.Bot.wait_until_ready": "ext/commands/api/bots.html#disnake.ext.commands.Bot.wait_until_ready", "disnake.ext.commands.Bot.walk_commands": "ext/commands/api/bots.html#disnake.ext.commands.Bot.walk_commands", "disnake.ext.commands.AutoShardedBot": "ext/commands/api/bots.html#disnake.ext.commands.AutoShardedBot", "disnake.ext.commands.InteractionBot": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot", "disnake.ext.commands.InteractionBot.owner_id": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.owner_id", "disnake.ext.commands.InteractionBot.owner_ids": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.owner_ids", "disnake.ext.commands.InteractionBot.reload": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.reload", "disnake.ext.commands.InteractionBot.i18n": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.i18n", "disnake.ext.commands.InteractionBot.after_slash_command_invoke": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.after_slash_command_invoke", "disnake.ext.commands.InteractionBot.after_user_command_invoke": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.after_user_command_invoke", "disnake.ext.commands.InteractionBot.after_message_command_invoke": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.after_message_command_invoke", "disnake.ext.commands.InteractionBot.before_slash_command_invoke": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.before_slash_command_invoke", "disnake.ext.commands.InteractionBot.before_user_command_invoke": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.before_user_command_invoke", "disnake.ext.commands.InteractionBot.before_message_command_invoke": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.before_message_command_invoke", "disnake.ext.commands.InteractionBot.application_command_check": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.application_command_check", "disnake.ext.commands.InteractionBot.slash_command_check": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.slash_command_check", "disnake.ext.commands.InteractionBot.user_command_check": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.user_command_check", "disnake.ext.commands.InteractionBot.message_command_check": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.message_command_check", "disnake.ext.commands.InteractionBot.slash_command_check_once": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.slash_command_check_once", "disnake.ext.commands.InteractionBot.user_command_check_once": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.user_command_check_once", "disnake.ext.commands.InteractionBot.message_command_check_once": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.message_command_check_once", "disnake.ext.commands.InteractionBot.slash_command": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.slash_command", "disnake.ext.commands.InteractionBot.user_command": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.user_command", "disnake.ext.commands.InteractionBot.message_command": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.message_command", "disnake.ext.commands.InteractionBot.event": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.event", "disnake.ext.commands.InteractionBot.listen": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.listen", "disnake.ext.commands.InteractionBot.activity": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.activity", "disnake.ext.commands.InteractionBot.add_app_command_check": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.add_app_command_check", "disnake.ext.commands.InteractionBot.add_cog": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.add_cog", "disnake.ext.commands.InteractionBot.add_listener": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.add_listener", "disnake.ext.commands.InteractionBot.add_message_command": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.add_message_command", "disnake.ext.commands.InteractionBot.add_slash_command": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.add_slash_command", "disnake.ext.commands.InteractionBot.add_user_command": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.add_user_command", "disnake.ext.commands.InteractionBot.add_view": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.add_view", "disnake.ext.commands.InteractionBot.allowed_mentions": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.allowed_mentions", "disnake.ext.commands.InteractionBot.application_commands": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.application_commands", "disnake.ext.commands.InteractionBot.application_flags": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.application_flags", "disnake.ext.commands.InteractionBot.application_id": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.application_id", "disnake.ext.commands.InteractionBot.application_info": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.application_info", "disnake.ext.commands.InteractionBot.before_identify_hook": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.before_identify_hook", "disnake.ext.commands.InteractionBot.bulk_fetch_command_permissions": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.bulk_fetch_command_permissions", "disnake.ext.commands.InteractionBot.bulk_overwrite_global_commands": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.bulk_overwrite_global_commands", "disnake.ext.commands.InteractionBot.bulk_overwrite_guild_commands": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.bulk_overwrite_guild_commands", "disnake.ext.commands.InteractionBot.cached_messages": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.cached_messages", "disnake.ext.commands.InteractionBot.change_presence": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.change_presence", "disnake.ext.commands.InteractionBot.clear": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.clear", "disnake.ext.commands.InteractionBot.close": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.close", "disnake.ext.commands.InteractionBot.cogs": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.cogs", "disnake.ext.commands.InteractionBot.connect": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.connect", "disnake.ext.commands.InteractionBot.create_dm": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.create_dm", "disnake.ext.commands.InteractionBot.create_global_command": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.create_global_command", "disnake.ext.commands.InteractionBot.create_guild": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.create_guild", "disnake.ext.commands.InteractionBot.create_guild_command": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.create_guild_command", "disnake.ext.commands.InteractionBot.delete_global_command": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.delete_global_command", "disnake.ext.commands.InteractionBot.delete_guild_command": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.delete_guild_command", "disnake.ext.commands.InteractionBot.delete_invite": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.delete_invite", "disnake.ext.commands.InteractionBot.edit_global_command": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.edit_global_command", "disnake.ext.commands.InteractionBot.edit_guild_command": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.edit_guild_command", "disnake.ext.commands.InteractionBot.emojis": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.emojis", "disnake.ext.commands.InteractionBot.extensions": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.extensions", "disnake.ext.commands.InteractionBot.fetch_channel": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.fetch_channel", "disnake.ext.commands.InteractionBot.fetch_command_permissions": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.fetch_command_permissions", "disnake.ext.commands.InteractionBot.fetch_global_command": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.fetch_global_command", "disnake.ext.commands.InteractionBot.fetch_global_commands": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.fetch_global_commands", "disnake.ext.commands.InteractionBot.fetch_guild": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.fetch_guild", "disnake.ext.commands.InteractionBot.fetch_guild_command": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.fetch_guild_command", "disnake.ext.commands.InteractionBot.fetch_guild_commands": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.fetch_guild_commands", "disnake.ext.commands.InteractionBot.fetch_guild_preview": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.fetch_guild_preview", "disnake.ext.commands.InteractionBot.fetch_guilds": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.fetch_guilds", "disnake.ext.commands.InteractionBot.fetch_invite": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.fetch_invite", "disnake.ext.commands.InteractionBot.fetch_premium_sticker_packs": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.fetch_premium_sticker_packs", "disnake.ext.commands.InteractionBot.fetch_stage_instance": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.fetch_stage_instance", "disnake.ext.commands.InteractionBot.fetch_sticker": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.fetch_sticker", "disnake.ext.commands.InteractionBot.fetch_template": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.fetch_template", "disnake.ext.commands.InteractionBot.fetch_user": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.fetch_user", "disnake.ext.commands.InteractionBot.fetch_voice_regions": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.fetch_voice_regions", "disnake.ext.commands.InteractionBot.fetch_webhook": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.fetch_webhook", "disnake.ext.commands.InteractionBot.fetch_widget": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.fetch_widget", "disnake.ext.commands.InteractionBot.get_all_channels": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.get_all_channels", "disnake.ext.commands.InteractionBot.get_all_members": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.get_all_members", "disnake.ext.commands.InteractionBot.get_channel": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.get_channel", "disnake.ext.commands.InteractionBot.get_cog": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.get_cog", "disnake.ext.commands.InteractionBot.get_emoji": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.get_emoji", "disnake.ext.commands.InteractionBot.get_global_command": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.get_global_command", "disnake.ext.commands.InteractionBot.get_global_command_named": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.get_global_command_named", "disnake.ext.commands.InteractionBot.get_guild": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.get_guild", "disnake.ext.commands.InteractionBot.get_guild_application_commands": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.get_guild_application_commands", "disnake.ext.commands.InteractionBot.get_guild_command": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.get_guild_command", "disnake.ext.commands.InteractionBot.get_guild_command_named": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.get_guild_command_named", "disnake.ext.commands.InteractionBot.get_guild_message_commands": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.get_guild_message_commands", "disnake.ext.commands.InteractionBot.get_guild_slash_commands": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.get_guild_slash_commands", "disnake.ext.commands.InteractionBot.get_guild_user_commands": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.get_guild_user_commands", "disnake.ext.commands.InteractionBot.get_message": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.get_message", "disnake.ext.commands.InteractionBot.get_message_command": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.get_message_command", "disnake.ext.commands.InteractionBot.get_or_fetch_user": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.get_or_fetch_user", "disnake.ext.commands.InteractionBot.get_partial_messageable": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.get_partial_messageable", "disnake.ext.commands.InteractionBot.get_slash_command": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.get_slash_command", "disnake.ext.commands.InteractionBot.get_stage_instance": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.get_stage_instance", "disnake.ext.commands.InteractionBot.get_sticker": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.get_sticker", "disnake.ext.commands.InteractionBot.get_user": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.get_user", "disnake.ext.commands.InteractionBot.get_user_command": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.get_user_command", "disnake.ext.commands.InteractionBot.getch_user": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.getch_user", "disnake.ext.commands.InteractionBot.global_application_commands": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.global_application_commands", "disnake.ext.commands.InteractionBot.global_message_commands": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.global_message_commands", "disnake.ext.commands.InteractionBot.global_slash_commands": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.global_slash_commands", "disnake.ext.commands.InteractionBot.global_user_commands": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.global_user_commands", "disnake.ext.commands.InteractionBot.guilds": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.guilds", "disnake.ext.commands.InteractionBot.intents": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.intents", "disnake.ext.commands.InteractionBot.is_closed": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.is_closed", "disnake.ext.commands.InteractionBot.is_owner": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.is_owner", "disnake.ext.commands.InteractionBot.is_ready": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.is_ready", "disnake.ext.commands.InteractionBot.is_ws_ratelimited": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.is_ws_ratelimited", "disnake.ext.commands.InteractionBot.latency": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.latency", "disnake.ext.commands.InteractionBot.load_extension": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.load_extension", "disnake.ext.commands.InteractionBot.load_extensions": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.load_extensions", "disnake.ext.commands.InteractionBot.login": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.login", "disnake.ext.commands.InteractionBot.message_commands": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.message_commands", "disnake.ext.commands.InteractionBot.on_error": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.on_error", "disnake.ext.commands.InteractionBot.on_gateway_error": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.on_gateway_error", "disnake.ext.commands.InteractionBot.on_message_command_error": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.on_message_command_error", "disnake.ext.commands.InteractionBot.on_slash_command_error": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.on_slash_command_error", "disnake.ext.commands.InteractionBot.on_user_command_error": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.on_user_command_error", "disnake.ext.commands.InteractionBot.persistent_views": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.persistent_views", "disnake.ext.commands.InteractionBot.private_channels": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.private_channels", "disnake.ext.commands.InteractionBot.process_app_command_autocompletion": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.process_app_command_autocompletion", "disnake.ext.commands.InteractionBot.process_application_commands": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.process_application_commands", "disnake.ext.commands.InteractionBot.reload_extension": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.reload_extension", "disnake.ext.commands.InteractionBot.remove_app_command_check": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.remove_app_command_check", "disnake.ext.commands.InteractionBot.remove_cog": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.remove_cog", "disnake.ext.commands.InteractionBot.remove_listener": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.remove_listener", "disnake.ext.commands.InteractionBot.remove_message_command": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.remove_message_command", "disnake.ext.commands.InteractionBot.remove_slash_command": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.remove_slash_command", "disnake.ext.commands.InteractionBot.remove_user_command": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.remove_user_command", "disnake.ext.commands.InteractionBot.run": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.run", "disnake.ext.commands.InteractionBot.slash_commands": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.slash_commands", "disnake.ext.commands.InteractionBot.start": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.start", "disnake.ext.commands.InteractionBot.status": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.status", "disnake.ext.commands.InteractionBot.stickers": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.stickers", "disnake.ext.commands.InteractionBot.unload_extension": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.unload_extension", "disnake.ext.commands.InteractionBot.user": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.user", "disnake.ext.commands.InteractionBot.user_commands": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.user_commands", "disnake.ext.commands.InteractionBot.users": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.users", "disnake.ext.commands.InteractionBot.voice_clients": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.voice_clients", "disnake.ext.commands.InteractionBot.wait_for": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.wait_for", "disnake.ext.commands.InteractionBot.wait_until_first_connect": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.wait_until_first_connect", "disnake.ext.commands.InteractionBot.wait_until_ready": "ext/commands/api/bots.html#disnake.ext.commands.InteractionBot.wait_until_ready", "disnake.ext.commands.AutoShardedInteractionBot": "ext/commands/api/bots.html#disnake.ext.commands.AutoShardedInteractionBot", "disnake.ext.commands.Cooldown": "ext/commands/api/checks.html#disnake.ext.commands.Cooldown", "disnake.ext.commands.Cooldown.rate": "ext/commands/api/checks.html#disnake.ext.commands.Cooldown.rate", "disnake.ext.commands.Cooldown.per": "ext/commands/api/checks.html#disnake.ext.commands.Cooldown.per", "disnake.ext.commands.Cooldown.get_tokens": "ext/commands/api/checks.html#disnake.ext.commands.Cooldown.get_tokens", "disnake.ext.commands.Cooldown.get_retry_after": "ext/commands/api/checks.html#disnake.ext.commands.Cooldown.get_retry_after", "disnake.ext.commands.Cooldown.update_rate_limit": "ext/commands/api/checks.html#disnake.ext.commands.Cooldown.update_rate_limit", "disnake.ext.commands.Cooldown.reset": "ext/commands/api/checks.html#disnake.ext.commands.Cooldown.reset", "disnake.ext.commands.Cooldown.copy": "ext/commands/api/checks.html#disnake.ext.commands.Cooldown.copy", "disnake.ext.commands.BucketType": "ext/commands/api/checks.html#disnake.ext.commands.BucketType", "disnake.ext.commands.BucketType.default": "ext/commands/api/checks.html#disnake.ext.commands.BucketType.default", "disnake.ext.commands.BucketType.user": "ext/commands/api/checks.html#disnake.ext.commands.BucketType.user", "disnake.ext.commands.BucketType.guild": "ext/commands/api/checks.html#disnake.ext.commands.BucketType.guild", "disnake.ext.commands.BucketType.channel": "ext/commands/api/checks.html#disnake.ext.commands.BucketType.channel", "disnake.ext.commands.BucketType.member": "ext/commands/api/checks.html#disnake.ext.commands.BucketType.member", "disnake.ext.commands.BucketType.category": "ext/commands/api/checks.html#disnake.ext.commands.BucketType.category", "disnake.ext.commands.BucketType.role": "ext/commands/api/checks.html#disnake.ext.commands.BucketType.role", "disnake.ext.commands.check": "ext/commands/api/checks.html#disnake.ext.commands.check", "disnake.ext.commands.check_any": "ext/commands/api/checks.html#disnake.ext.commands.check_any", "disnake.ext.commands.has_role": "ext/commands/api/checks.html#disnake.ext.commands.has_role", "disnake.ext.commands.has_permissions": "ext/commands/api/checks.html#disnake.ext.commands.has_permissions", "disnake.ext.commands.has_guild_permissions": "ext/commands/api/checks.html#disnake.ext.commands.has_guild_permissions", "disnake.ext.commands.has_any_role": "ext/commands/api/checks.html#disnake.ext.commands.has_any_role", "disnake.ext.commands.bot_has_role": "ext/commands/api/checks.html#disnake.ext.commands.bot_has_role", "disnake.ext.commands.bot_has_permissions": "ext/commands/api/checks.html#disnake.ext.commands.bot_has_permissions", "disnake.ext.commands.bot_has_guild_permissions": "ext/commands/api/checks.html#disnake.ext.commands.bot_has_guild_permissions", "disnake.ext.commands.bot_has_any_role": "ext/commands/api/checks.html#disnake.ext.commands.bot_has_any_role", "disnake.ext.commands.cooldown": "ext/commands/api/checks.html#disnake.ext.commands.cooldown", "disnake.ext.commands.dynamic_cooldown": "ext/commands/api/checks.html#disnake.ext.commands.dynamic_cooldown", "disnake.ext.commands.max_concurrency": "ext/commands/api/checks.html#disnake.ext.commands.max_concurrency", "disnake.ext.commands.before_invoke": "ext/commands/api/checks.html#disnake.ext.commands.before_invoke", "disnake.ext.commands.after_invoke": "ext/commands/api/checks.html#disnake.ext.commands.after_invoke", "disnake.ext.commands.guild_only": "ext/commands/api/checks.html#disnake.ext.commands.guild_only", "disnake.ext.commands.dm_only": "ext/commands/api/checks.html#disnake.ext.commands.dm_only", "disnake.ext.commands.is_owner": "ext/commands/api/checks.html#disnake.ext.commands.is_owner", "disnake.ext.commands.is_nsfw": "ext/commands/api/checks.html#disnake.ext.commands.is_nsfw", "disnake.ext.commands.default_member_permissions": "ext/commands/api/checks.html#disnake.ext.commands.default_member_permissions", "disnake.ext.commands.Context": "ext/commands/api/context.html#disnake.ext.commands.Context", "disnake.ext.commands.Context.message": "ext/commands/api/context.html#disnake.ext.commands.Context.message", "disnake.ext.commands.Context.bot": "ext/commands/api/context.html#disnake.ext.commands.Context.bot", "disnake.ext.commands.Context.args": "ext/commands/api/context.html#disnake.ext.commands.Context.args", "disnake.ext.commands.Context.kwargs": "ext/commands/api/context.html#disnake.ext.commands.Context.kwargs", "disnake.ext.commands.Context.current_parameter": "ext/commands/api/context.html#disnake.ext.commands.Context.current_parameter", "disnake.ext.commands.Context.prefix": "ext/commands/api/context.html#disnake.ext.commands.Context.prefix", "disnake.ext.commands.Context.command": "ext/commands/api/context.html#disnake.ext.commands.Context.command", "disnake.ext.commands.Context.invoked_with": "ext/commands/api/context.html#disnake.ext.commands.Context.invoked_with", "disnake.ext.commands.Context.invoked_parents": "ext/commands/api/context.html#disnake.ext.commands.Context.invoked_parents", "disnake.ext.commands.Context.invoked_subcommand": "ext/commands/api/context.html#disnake.ext.commands.Context.invoked_subcommand", "disnake.ext.commands.Context.subcommand_passed": "ext/commands/api/context.html#disnake.ext.commands.Context.subcommand_passed", "disnake.ext.commands.Context.command_failed": "ext/commands/api/context.html#disnake.ext.commands.Context.command_failed", "disnake.ext.commands.Context.history": "ext/commands/api/context.html#disnake.ext.commands.Context.history", "disnake.ext.commands.Context.typing": "ext/commands/api/context.html#disnake.ext.commands.Context.typing", "disnake.ext.commands.Context.invoke": "ext/commands/api/context.html#disnake.ext.commands.Context.invoke", "disnake.ext.commands.Context.reinvoke": "ext/commands/api/context.html#disnake.ext.commands.Context.reinvoke", "disnake.ext.commands.Context.valid": "ext/commands/api/context.html#disnake.ext.commands.Context.valid", "disnake.ext.commands.Context.clean_prefix": "ext/commands/api/context.html#disnake.ext.commands.Context.clean_prefix", "disnake.ext.commands.Context.cog": "ext/commands/api/context.html#disnake.ext.commands.Context.cog", "disnake.ext.commands.Context.guild": "ext/commands/api/context.html#disnake.ext.commands.Context.guild", "disnake.ext.commands.Context.channel": "ext/commands/api/context.html#disnake.ext.commands.Context.channel", "disnake.ext.commands.Context.author": "ext/commands/api/context.html#disnake.ext.commands.Context.author", "disnake.ext.commands.Context.me": "ext/commands/api/context.html#disnake.ext.commands.Context.me", "disnake.ext.commands.Context.voice_client": "ext/commands/api/context.html#disnake.ext.commands.Context.voice_client", "disnake.ext.commands.Context.send_help": "ext/commands/api/context.html#disnake.ext.commands.Context.send_help", "disnake.ext.commands.Context.reply": "ext/commands/api/context.html#disnake.ext.commands.Context.reply", "disnake.ext.commands.Context.fetch_message": "ext/commands/api/context.html#disnake.ext.commands.Context.fetch_message", "disnake.ext.commands.Context.pins": "ext/commands/api/context.html#disnake.ext.commands.Context.pins", "disnake.ext.commands.Context.send": "ext/commands/api/context.html#disnake.ext.commands.Context.send", "disnake.ext.commands.Context.trigger_typing": "ext/commands/api/context.html#disnake.ext.commands.Context.trigger_typing", "disnake.ext.commands.Converter": "ext/commands/api/converters.html#disnake.ext.commands.Converter", "disnake.ext.commands.Converter.convert": "ext/commands/api/converters.html#disnake.ext.commands.Converter.convert", "disnake.ext.commands.ObjectConverter": "ext/commands/api/converters.html#disnake.ext.commands.ObjectConverter", "disnake.ext.commands.ObjectConverter.convert": "ext/commands/api/converters.html#disnake.ext.commands.ObjectConverter.convert", "disnake.ext.commands.MemberConverter": "ext/commands/api/converters.html#disnake.ext.commands.MemberConverter", "disnake.ext.commands.MemberConverter.convert": "ext/commands/api/converters.html#disnake.ext.commands.MemberConverter.convert", "disnake.ext.commands.UserConverter": "ext/commands/api/converters.html#disnake.ext.commands.UserConverter", "disnake.ext.commands.UserConverter.convert": "ext/commands/api/converters.html#disnake.ext.commands.UserConverter.convert", "disnake.ext.commands.MessageConverter": "ext/commands/api/converters.html#disnake.ext.commands.MessageConverter", "disnake.ext.commands.MessageConverter.convert": "ext/commands/api/converters.html#disnake.ext.commands.MessageConverter.convert", "disnake.ext.commands.PartialMessageConverter": "ext/commands/api/converters.html#disnake.ext.commands.PartialMessageConverter", "disnake.ext.commands.PartialMessageConverter.convert": "ext/commands/api/converters.html#disnake.ext.commands.PartialMessageConverter.convert", "disnake.ext.commands.GuildChannelConverter": "ext/commands/api/converters.html#disnake.ext.commands.GuildChannelConverter", "disnake.ext.commands.GuildChannelConverter.convert": "ext/commands/api/converters.html#disnake.ext.commands.GuildChannelConverter.convert", "disnake.ext.commands.TextChannelConverter": "ext/commands/api/converters.html#disnake.ext.commands.TextChannelConverter", "disnake.ext.commands.TextChannelConverter.convert": "ext/commands/api/converters.html#disnake.ext.commands.TextChannelConverter.convert", "disnake.ext.commands.VoiceChannelConverter": "ext/commands/api/converters.html#disnake.ext.commands.VoiceChannelConverter", "disnake.ext.commands.VoiceChannelConverter.convert": "ext/commands/api/converters.html#disnake.ext.commands.VoiceChannelConverter.convert", "disnake.ext.commands.StageChannelConverter": "ext/commands/api/converters.html#disnake.ext.commands.StageChannelConverter", "disnake.ext.commands.StageChannelConverter.convert": "ext/commands/api/converters.html#disnake.ext.commands.StageChannelConverter.convert", "disnake.ext.commands.CategoryChannelConverter": "ext/commands/api/converters.html#disnake.ext.commands.CategoryChannelConverter", "disnake.ext.commands.CategoryChannelConverter.convert": "ext/commands/api/converters.html#disnake.ext.commands.CategoryChannelConverter.convert", "disnake.ext.commands.ForumChannelConverter": "ext/commands/api/converters.html#disnake.ext.commands.ForumChannelConverter", "disnake.ext.commands.ForumChannelConverter.convert": "ext/commands/api/converters.html#disnake.ext.commands.ForumChannelConverter.convert", "disnake.ext.commands.ThreadConverter": "ext/commands/api/converters.html#disnake.ext.commands.ThreadConverter", "disnake.ext.commands.ThreadConverter.convert": "ext/commands/api/converters.html#disnake.ext.commands.ThreadConverter.convert", "disnake.ext.commands.ColourConverter": "ext/commands/api/converters.html#disnake.ext.commands.ColourConverter", "disnake.ext.commands.ColourConverter.convert": "ext/commands/api/converters.html#disnake.ext.commands.ColourConverter.convert", "disnake.ext.commands.RoleConverter": "ext/commands/api/converters.html#disnake.ext.commands.RoleConverter", "disnake.ext.commands.RoleConverter.convert": "ext/commands/api/converters.html#disnake.ext.commands.RoleConverter.convert", "disnake.ext.commands.GameConverter": "ext/commands/api/converters.html#disnake.ext.commands.GameConverter", "disnake.ext.commands.GameConverter.convert": "ext/commands/api/converters.html#disnake.ext.commands.GameConverter.convert", "disnake.ext.commands.InviteConverter": "ext/commands/api/converters.html#disnake.ext.commands.InviteConverter", "disnake.ext.commands.InviteConverter.convert": "ext/commands/api/converters.html#disnake.ext.commands.InviteConverter.convert", "disnake.ext.commands.GuildConverter": "ext/commands/api/converters.html#disnake.ext.commands.GuildConverter", "disnake.ext.commands.GuildConverter.convert": "ext/commands/api/converters.html#disnake.ext.commands.GuildConverter.convert", "disnake.ext.commands.EmojiConverter": "ext/commands/api/converters.html#disnake.ext.commands.EmojiConverter", "disnake.ext.commands.EmojiConverter.convert": "ext/commands/api/converters.html#disnake.ext.commands.EmojiConverter.convert", "disnake.ext.commands.PartialEmojiConverter": "ext/commands/api/converters.html#disnake.ext.commands.PartialEmojiConverter", "disnake.ext.commands.PartialEmojiConverter.convert": "ext/commands/api/converters.html#disnake.ext.commands.PartialEmojiConverter.convert", "disnake.ext.commands.GuildStickerConverter": "ext/commands/api/converters.html#disnake.ext.commands.GuildStickerConverter", "disnake.ext.commands.GuildStickerConverter.convert": "ext/commands/api/converters.html#disnake.ext.commands.GuildStickerConverter.convert", "disnake.ext.commands.PermissionsConverter": "ext/commands/api/converters.html#disnake.ext.commands.PermissionsConverter", "disnake.ext.commands.PermissionsConverter.convert": "ext/commands/api/converters.html#disnake.ext.commands.PermissionsConverter.convert", "disnake.ext.commands.GuildScheduledEventConverter": "ext/commands/api/converters.html#disnake.ext.commands.GuildScheduledEventConverter", "disnake.ext.commands.GuildScheduledEventConverter.convert": "ext/commands/api/converters.html#disnake.ext.commands.GuildScheduledEventConverter.convert", "disnake.ext.commands.clean_content": "ext/commands/api/converters.html#disnake.ext.commands.clean_content", "disnake.ext.commands.clean_content.fix_channel_mentions": "ext/commands/api/converters.html#disnake.ext.commands.clean_content.fix_channel_mentions", "disnake.ext.commands.clean_content.use_nicknames": "ext/commands/api/converters.html#disnake.ext.commands.clean_content.use_nicknames", "disnake.ext.commands.clean_content.escape_markdown": "ext/commands/api/converters.html#disnake.ext.commands.clean_content.escape_markdown", "disnake.ext.commands.clean_content.remove_markdown": "ext/commands/api/converters.html#disnake.ext.commands.clean_content.remove_markdown", "disnake.ext.commands.clean_content.convert": "ext/commands/api/converters.html#disnake.ext.commands.clean_content.convert", "disnake.ext.commands.Greedy": "ext/commands/api/converters.html#disnake.ext.commands.Greedy", "disnake.ext.commands.FlagConverter": "ext/commands/api/converters.html#disnake.ext.commands.FlagConverter", "disnake.ext.commands.FlagConverter.get_flags": "ext/commands/api/converters.html#disnake.ext.commands.FlagConverter.get_flags", "disnake.ext.commands.FlagConverter.convert": "ext/commands/api/converters.html#disnake.ext.commands.FlagConverter.convert", "disnake.ext.commands.Flag": "ext/commands/api/converters.html#disnake.ext.commands.Flag", "disnake.ext.commands.Flag.name": "ext/commands/api/converters.html#disnake.ext.commands.Flag.name", "disnake.ext.commands.Flag.aliases": "ext/commands/api/converters.html#disnake.ext.commands.Flag.aliases", "disnake.ext.commands.Flag.attribute": "ext/commands/api/converters.html#disnake.ext.commands.Flag.attribute", "disnake.ext.commands.Flag.default": "ext/commands/api/converters.html#disnake.ext.commands.Flag.default", "disnake.ext.commands.Flag.annotation": "ext/commands/api/converters.html#disnake.ext.commands.Flag.annotation", "disnake.ext.commands.Flag.max_args": "ext/commands/api/converters.html#disnake.ext.commands.Flag.max_args", "disnake.ext.commands.Flag.override": "ext/commands/api/converters.html#disnake.ext.commands.Flag.override", "disnake.ext.commands.Flag.required": "ext/commands/api/converters.html#disnake.ext.commands.Flag.required", "disnake.ext.commands.run_converters": "ext/commands/api/converters.html#disnake.ext.commands.run_converters", "disnake.ext.commands.converter_method": "ext/commands/api/converters.html#disnake.ext.commands.converter_method", "disnake.ext.commands.flag": "ext/commands/api/converters.html#disnake.ext.commands.flag", "disnake.ext.commands.on_command_error": "ext/commands/api/events.html#disnake.ext.commands.on_command_error", "disnake.ext.commands.on_command": "ext/commands/api/events.html#disnake.ext.commands.on_command", "disnake.ext.commands.on_command_completion": "ext/commands/api/events.html#disnake.ext.commands.on_command_completion", "disnake.ext.commands.on_slash_command_error": "ext/commands/api/events.html#disnake.ext.commands.on_slash_command_error", "disnake.ext.commands.on_slash_command": "ext/commands/api/events.html#disnake.ext.commands.on_slash_command", "disnake.ext.commands.on_slash_command_completion": "ext/commands/api/events.html#disnake.ext.commands.on_slash_command_completion", "disnake.ext.commands.on_user_command_error": "ext/commands/api/events.html#disnake.ext.commands.on_user_command_error", "disnake.ext.commands.on_user_command": "ext/commands/api/events.html#disnake.ext.commands.on_user_command", "disnake.ext.commands.on_user_command_completion": "ext/commands/api/events.html#disnake.ext.commands.on_user_command_completion", "disnake.ext.commands.on_message_command_error": "ext/commands/api/events.html#disnake.ext.commands.on_message_command_error", "disnake.ext.commands.on_message_command": "ext/commands/api/events.html#disnake.ext.commands.on_message_command", "disnake.ext.commands.on_message_command_completion": "ext/commands/api/events.html#disnake.ext.commands.on_message_command_completion", "disnake.ext.commands.CommandError": "ext/commands/api/exceptions.html#disnake.ext.commands.CommandError", "disnake.ext.commands.ConversionError": "ext/commands/api/exceptions.html#disnake.ext.commands.ConversionError", "disnake.ext.commands.ConversionError.converter": "ext/commands/api/exceptions.html#disnake.ext.commands.ConversionError.converter", "disnake.ext.commands.ConversionError.original": "ext/commands/api/exceptions.html#disnake.ext.commands.ConversionError.original", "disnake.ext.commands.MissingRequiredArgument": "ext/commands/api/exceptions.html#disnake.ext.commands.MissingRequiredArgument", "disnake.ext.commands.MissingRequiredArgument.param": "ext/commands/api/exceptions.html#disnake.ext.commands.MissingRequiredArgument.param", "disnake.ext.commands.ArgumentParsingError": "ext/commands/api/exceptions.html#disnake.ext.commands.ArgumentParsingError", "disnake.ext.commands.UnexpectedQuoteError": "ext/commands/api/exceptions.html#disnake.ext.commands.UnexpectedQuoteError", "disnake.ext.commands.UnexpectedQuoteError.quote": "ext/commands/api/exceptions.html#disnake.ext.commands.UnexpectedQuoteError.quote", "disnake.ext.commands.InvalidEndOfQuotedStringError": "ext/commands/api/exceptions.html#disnake.ext.commands.InvalidEndOfQuotedStringError", "disnake.ext.commands.InvalidEndOfQuotedStringError.char": "ext/commands/api/exceptions.html#disnake.ext.commands.InvalidEndOfQuotedStringError.char", "disnake.ext.commands.ExpectedClosingQuoteError": "ext/commands/api/exceptions.html#disnake.ext.commands.ExpectedClosingQuoteError", "disnake.ext.commands.ExpectedClosingQuoteError.close_quote": "ext/commands/api/exceptions.html#disnake.ext.commands.ExpectedClosingQuoteError.close_quote", "disnake.ext.commands.BadArgument": "ext/commands/api/exceptions.html#disnake.ext.commands.BadArgument", "disnake.ext.commands.BadUnionArgument": "ext/commands/api/exceptions.html#disnake.ext.commands.BadUnionArgument", "disnake.ext.commands.BadUnionArgument.param": "ext/commands/api/exceptions.html#disnake.ext.commands.BadUnionArgument.param", "disnake.ext.commands.BadUnionArgument.converters": "ext/commands/api/exceptions.html#disnake.ext.commands.BadUnionArgument.converters", "disnake.ext.commands.BadUnionArgument.errors": "ext/commands/api/exceptions.html#disnake.ext.commands.BadUnionArgument.errors", "disnake.ext.commands.BadLiteralArgument": "ext/commands/api/exceptions.html#disnake.ext.commands.BadLiteralArgument", "disnake.ext.commands.BadLiteralArgument.param": "ext/commands/api/exceptions.html#disnake.ext.commands.BadLiteralArgument.param", "disnake.ext.commands.BadLiteralArgument.literals": "ext/commands/api/exceptions.html#disnake.ext.commands.BadLiteralArgument.literals", "disnake.ext.commands.BadLiteralArgument.errors": "ext/commands/api/exceptions.html#disnake.ext.commands.BadLiteralArgument.errors", "disnake.ext.commands.PrivateMessageOnly": "ext/commands/api/exceptions.html#disnake.ext.commands.PrivateMessageOnly", "disnake.ext.commands.NoPrivateMessage": "ext/commands/api/exceptions.html#disnake.ext.commands.NoPrivateMessage", "disnake.ext.commands.CheckFailure": "ext/commands/api/exceptions.html#disnake.ext.commands.CheckFailure", "disnake.ext.commands.CheckAnyFailure": "ext/commands/api/exceptions.html#disnake.ext.commands.CheckAnyFailure", "disnake.ext.commands.CheckAnyFailure.errors": "ext/commands/api/exceptions.html#disnake.ext.commands.CheckAnyFailure.errors", "disnake.ext.commands.CheckAnyFailure.checks": "ext/commands/api/exceptions.html#disnake.ext.commands.CheckAnyFailure.checks", "disnake.ext.commands.CommandNotFound": "ext/commands/api/exceptions.html#disnake.ext.commands.CommandNotFound", "disnake.ext.commands.DisabledCommand": "ext/commands/api/exceptions.html#disnake.ext.commands.DisabledCommand", "disnake.ext.commands.CommandInvokeError": "ext/commands/api/exceptions.html#disnake.ext.commands.CommandInvokeError", "disnake.ext.commands.CommandInvokeError.original": "ext/commands/api/exceptions.html#disnake.ext.commands.CommandInvokeError.original", "disnake.ext.commands.TooManyArguments": "ext/commands/api/exceptions.html#disnake.ext.commands.TooManyArguments", "disnake.ext.commands.UserInputError": "ext/commands/api/exceptions.html#disnake.ext.commands.UserInputError", "disnake.ext.commands.CommandOnCooldown": "ext/commands/api/exceptions.html#disnake.ext.commands.CommandOnCooldown", "disnake.ext.commands.CommandOnCooldown.cooldown": "ext/commands/api/exceptions.html#disnake.ext.commands.CommandOnCooldown.cooldown", "disnake.ext.commands.CommandOnCooldown.type": "ext/commands/api/exceptions.html#disnake.ext.commands.CommandOnCooldown.type", "disnake.ext.commands.CommandOnCooldown.retry_after": "ext/commands/api/exceptions.html#disnake.ext.commands.CommandOnCooldown.retry_after", "disnake.ext.commands.MaxConcurrencyReached": "ext/commands/api/exceptions.html#disnake.ext.commands.MaxConcurrencyReached", "disnake.ext.commands.MaxConcurrencyReached.number": "ext/commands/api/exceptions.html#disnake.ext.commands.MaxConcurrencyReached.number", "disnake.ext.commands.MaxConcurrencyReached.per": "ext/commands/api/exceptions.html#disnake.ext.commands.MaxConcurrencyReached.per", "disnake.ext.commands.NotOwner": "ext/commands/api/exceptions.html#disnake.ext.commands.NotOwner", "disnake.ext.commands.ObjectNotFound": "ext/commands/api/exceptions.html#disnake.ext.commands.ObjectNotFound", "disnake.ext.commands.ObjectNotFound.argument": "ext/commands/api/exceptions.html#disnake.ext.commands.ObjectNotFound.argument", "disnake.ext.commands.MessageNotFound": "ext/commands/api/exceptions.html#disnake.ext.commands.MessageNotFound", "disnake.ext.commands.MessageNotFound.argument": "ext/commands/api/exceptions.html#disnake.ext.commands.MessageNotFound.argument", "disnake.ext.commands.MemberNotFound": "ext/commands/api/exceptions.html#disnake.ext.commands.MemberNotFound", "disnake.ext.commands.MemberNotFound.argument": "ext/commands/api/exceptions.html#disnake.ext.commands.MemberNotFound.argument", "disnake.ext.commands.GuildNotFound": "ext/commands/api/exceptions.html#disnake.ext.commands.GuildNotFound", "disnake.ext.commands.GuildNotFound.argument": "ext/commands/api/exceptions.html#disnake.ext.commands.GuildNotFound.argument", "disnake.ext.commands.UserNotFound": "ext/commands/api/exceptions.html#disnake.ext.commands.UserNotFound", "disnake.ext.commands.UserNotFound.argument": "ext/commands/api/exceptions.html#disnake.ext.commands.UserNotFound.argument", "disnake.ext.commands.ChannelNotFound": "ext/commands/api/exceptions.html#disnake.ext.commands.ChannelNotFound", "disnake.ext.commands.ChannelNotFound.argument": "ext/commands/api/exceptions.html#disnake.ext.commands.ChannelNotFound.argument", "disnake.ext.commands.ChannelNotReadable": "ext/commands/api/exceptions.html#disnake.ext.commands.ChannelNotReadable", "disnake.ext.commands.ChannelNotReadable.argument": "ext/commands/api/exceptions.html#disnake.ext.commands.ChannelNotReadable.argument", "disnake.ext.commands.ThreadNotFound": "ext/commands/api/exceptions.html#disnake.ext.commands.ThreadNotFound", "disnake.ext.commands.ThreadNotFound.argument": "ext/commands/api/exceptions.html#disnake.ext.commands.ThreadNotFound.argument", "disnake.ext.commands.BadColourArgument": "ext/commands/api/exceptions.html#disnake.ext.commands.BadColourArgument", "disnake.ext.commands.BadColourArgument.argument": "ext/commands/api/exceptions.html#disnake.ext.commands.BadColourArgument.argument", "disnake.ext.commands.RoleNotFound": "ext/commands/api/exceptions.html#disnake.ext.commands.RoleNotFound", "disnake.ext.commands.RoleNotFound.argument": "ext/commands/api/exceptions.html#disnake.ext.commands.RoleNotFound.argument", "disnake.ext.commands.BadInviteArgument": "ext/commands/api/exceptions.html#disnake.ext.commands.BadInviteArgument", "disnake.ext.commands.EmojiNotFound": "ext/commands/api/exceptions.html#disnake.ext.commands.EmojiNotFound", "disnake.ext.commands.EmojiNotFound.argument": "ext/commands/api/exceptions.html#disnake.ext.commands.EmojiNotFound.argument", "disnake.ext.commands.PartialEmojiConversionFailure": "ext/commands/api/exceptions.html#disnake.ext.commands.PartialEmojiConversionFailure", "disnake.ext.commands.PartialEmojiConversionFailure.argument": "ext/commands/api/exceptions.html#disnake.ext.commands.PartialEmojiConversionFailure.argument", "disnake.ext.commands.GuildStickerNotFound": "ext/commands/api/exceptions.html#disnake.ext.commands.GuildStickerNotFound", "disnake.ext.commands.GuildStickerNotFound.argument": "ext/commands/api/exceptions.html#disnake.ext.commands.GuildStickerNotFound.argument", "disnake.ext.commands.GuildScheduledEventNotFound": "ext/commands/api/exceptions.html#disnake.ext.commands.GuildScheduledEventNotFound", "disnake.ext.commands.GuildScheduledEventNotFound.argument": "ext/commands/api/exceptions.html#disnake.ext.commands.GuildScheduledEventNotFound.argument", "disnake.ext.commands.BadBoolArgument": "ext/commands/api/exceptions.html#disnake.ext.commands.BadBoolArgument", "disnake.ext.commands.BadBoolArgument.argument": "ext/commands/api/exceptions.html#disnake.ext.commands.BadBoolArgument.argument", "disnake.ext.commands.LargeIntConversionFailure": "ext/commands/api/exceptions.html#disnake.ext.commands.LargeIntConversionFailure", "disnake.ext.commands.LargeIntConversionFailure.argument": "ext/commands/api/exceptions.html#disnake.ext.commands.LargeIntConversionFailure.argument", "disnake.ext.commands.MissingPermissions": "ext/commands/api/exceptions.html#disnake.ext.commands.MissingPermissions", "disnake.ext.commands.MissingPermissions.missing_permissions": "ext/commands/api/exceptions.html#disnake.ext.commands.MissingPermissions.missing_permissions", "disnake.ext.commands.BotMissingPermissions": "ext/commands/api/exceptions.html#disnake.ext.commands.BotMissingPermissions", "disnake.ext.commands.BotMissingPermissions.missing_permissions": "ext/commands/api/exceptions.html#disnake.ext.commands.BotMissingPermissions.missing_permissions", "disnake.ext.commands.MissingRole": "ext/commands/api/exceptions.html#disnake.ext.commands.MissingRole", "disnake.ext.commands.MissingRole.missing_role": "ext/commands/api/exceptions.html#disnake.ext.commands.MissingRole.missing_role", "disnake.ext.commands.BotMissingRole": "ext/commands/api/exceptions.html#disnake.ext.commands.BotMissingRole", "disnake.ext.commands.BotMissingRole.missing_role": "ext/commands/api/exceptions.html#disnake.ext.commands.BotMissingRole.missing_role", "disnake.ext.commands.MissingAnyRole": "ext/commands/api/exceptions.html#disnake.ext.commands.MissingAnyRole", "disnake.ext.commands.MissingAnyRole.missing_roles": "ext/commands/api/exceptions.html#disnake.ext.commands.MissingAnyRole.missing_roles", "disnake.ext.commands.BotMissingAnyRole": "ext/commands/api/exceptions.html#disnake.ext.commands.BotMissingAnyRole", "disnake.ext.commands.BotMissingAnyRole.missing_roles": "ext/commands/api/exceptions.html#disnake.ext.commands.BotMissingAnyRole.missing_roles", "disnake.ext.commands.NSFWChannelRequired": "ext/commands/api/exceptions.html#disnake.ext.commands.NSFWChannelRequired", "disnake.ext.commands.FlagError": "ext/commands/api/exceptions.html#disnake.ext.commands.FlagError", "disnake.ext.commands.BadFlagArgument": "ext/commands/api/exceptions.html#disnake.ext.commands.BadFlagArgument", "disnake.ext.commands.BadFlagArgument.flag": "ext/commands/api/exceptions.html#disnake.ext.commands.BadFlagArgument.flag", "disnake.ext.commands.MissingFlagArgument": "ext/commands/api/exceptions.html#disnake.ext.commands.MissingFlagArgument", "disnake.ext.commands.MissingFlagArgument.flag": "ext/commands/api/exceptions.html#disnake.ext.commands.MissingFlagArgument.flag", "disnake.ext.commands.TooManyFlags": "ext/commands/api/exceptions.html#disnake.ext.commands.TooManyFlags", "disnake.ext.commands.TooManyFlags.flag": "ext/commands/api/exceptions.html#disnake.ext.commands.TooManyFlags.flag", "disnake.ext.commands.TooManyFlags.values": "ext/commands/api/exceptions.html#disnake.ext.commands.TooManyFlags.values", "disnake.ext.commands.MissingRequiredFlag": "ext/commands/api/exceptions.html#disnake.ext.commands.MissingRequiredFlag", "disnake.ext.commands.MissingRequiredFlag.flag": "ext/commands/api/exceptions.html#disnake.ext.commands.MissingRequiredFlag.flag", "disnake.ext.commands.ExtensionError": "ext/commands/api/exceptions.html#disnake.ext.commands.ExtensionError", "disnake.ext.commands.ExtensionError.name": "ext/commands/api/exceptions.html#disnake.ext.commands.ExtensionError.name", "disnake.ext.commands.ExtensionAlreadyLoaded": "ext/commands/api/exceptions.html#disnake.ext.commands.ExtensionAlreadyLoaded", "disnake.ext.commands.ExtensionNotLoaded": "ext/commands/api/exceptions.html#disnake.ext.commands.ExtensionNotLoaded", "disnake.ext.commands.NoEntryPointError": "ext/commands/api/exceptions.html#disnake.ext.commands.NoEntryPointError", "disnake.ext.commands.ExtensionFailed": "ext/commands/api/exceptions.html#disnake.ext.commands.ExtensionFailed", "disnake.ext.commands.ExtensionFailed.name": "ext/commands/api/exceptions.html#disnake.ext.commands.ExtensionFailed.name", "disnake.ext.commands.ExtensionFailed.original": "ext/commands/api/exceptions.html#disnake.ext.commands.ExtensionFailed.original", "disnake.ext.commands.ExtensionNotFound": "ext/commands/api/exceptions.html#disnake.ext.commands.ExtensionNotFound", "disnake.ext.commands.ExtensionNotFound.name": "ext/commands/api/exceptions.html#disnake.ext.commands.ExtensionNotFound.name", "disnake.ext.commands.CommandRegistrationError": "ext/commands/api/exceptions.html#disnake.ext.commands.CommandRegistrationError", "disnake.ext.commands.CommandRegistrationError.name": "ext/commands/api/exceptions.html#disnake.ext.commands.CommandRegistrationError.name", "disnake.ext.commands.CommandRegistrationError.alias_conflict": "ext/commands/api/exceptions.html#disnake.ext.commands.CommandRegistrationError.alias_conflict", "disnake.ext.commands.MessageContentPrefixWarning": "ext/commands/api/exceptions.html#disnake.ext.commands.MessageContentPrefixWarning", "disnake.ext.commands.HelpCommand": "ext/commands/api/help_commands.html#disnake.ext.commands.HelpCommand", "disnake.ext.commands.HelpCommand.context": "ext/commands/api/help_commands.html#disnake.ext.commands.HelpCommand.context", "disnake.ext.commands.HelpCommand.show_hidden": "ext/commands/api/help_commands.html#disnake.ext.commands.HelpCommand.show_hidden", "disnake.ext.commands.HelpCommand.verify_checks": "ext/commands/api/help_commands.html#disnake.ext.commands.HelpCommand.verify_checks", "disnake.ext.commands.HelpCommand.command_attrs": "ext/commands/api/help_commands.html#disnake.ext.commands.HelpCommand.command_attrs", "disnake.ext.commands.HelpCommand.add_check": "ext/commands/api/help_commands.html#disnake.ext.commands.HelpCommand.add_check", "disnake.ext.commands.HelpCommand.remove_check": "ext/commands/api/help_commands.html#disnake.ext.commands.HelpCommand.remove_check", "disnake.ext.commands.HelpCommand.get_bot_mapping": "ext/commands/api/help_commands.html#disnake.ext.commands.HelpCommand.get_bot_mapping", "disnake.ext.commands.HelpCommand.invoked_with": "ext/commands/api/help_commands.html#disnake.ext.commands.HelpCommand.invoked_with", "disnake.ext.commands.HelpCommand.get_command_signature": "ext/commands/api/help_commands.html#disnake.ext.commands.HelpCommand.get_command_signature", "disnake.ext.commands.HelpCommand.remove_mentions": "ext/commands/api/help_commands.html#disnake.ext.commands.HelpCommand.remove_mentions", "disnake.ext.commands.HelpCommand.cog": "ext/commands/api/help_commands.html#disnake.ext.commands.HelpCommand.cog", "disnake.ext.commands.HelpCommand.command_not_found": "ext/commands/api/help_commands.html#disnake.ext.commands.HelpCommand.command_not_found", "disnake.ext.commands.HelpCommand.subcommand_not_found": "ext/commands/api/help_commands.html#disnake.ext.commands.HelpCommand.subcommand_not_found", "disnake.ext.commands.HelpCommand.filter_commands": "ext/commands/api/help_commands.html#disnake.ext.commands.HelpCommand.filter_commands", "disnake.ext.commands.HelpCommand.get_max_size": "ext/commands/api/help_commands.html#disnake.ext.commands.HelpCommand.get_max_size", "disnake.ext.commands.HelpCommand.get_destination": "ext/commands/api/help_commands.html#disnake.ext.commands.HelpCommand.get_destination", "disnake.ext.commands.HelpCommand.send_error_message": "ext/commands/api/help_commands.html#disnake.ext.commands.HelpCommand.send_error_message", "disnake.ext.commands.HelpCommand.on_help_command_error": "ext/commands/api/help_commands.html#disnake.ext.commands.HelpCommand.on_help_command_error", "disnake.ext.commands.HelpCommand.send_bot_help": "ext/commands/api/help_commands.html#disnake.ext.commands.HelpCommand.send_bot_help", "disnake.ext.commands.HelpCommand.send_cog_help": "ext/commands/api/help_commands.html#disnake.ext.commands.HelpCommand.send_cog_help", "disnake.ext.commands.HelpCommand.send_group_help": "ext/commands/api/help_commands.html#disnake.ext.commands.HelpCommand.send_group_help", "disnake.ext.commands.HelpCommand.send_command_help": "ext/commands/api/help_commands.html#disnake.ext.commands.HelpCommand.send_command_help", "disnake.ext.commands.HelpCommand.prepare_help_command": "ext/commands/api/help_commands.html#disnake.ext.commands.HelpCommand.prepare_help_command", "disnake.ext.commands.HelpCommand.command_callback": "ext/commands/api/help_commands.html#disnake.ext.commands.HelpCommand.command_callback", "disnake.ext.commands.DefaultHelpCommand": "ext/commands/api/help_commands.html#disnake.ext.commands.DefaultHelpCommand", "disnake.ext.commands.DefaultHelpCommand.width": "ext/commands/api/help_commands.html#disnake.ext.commands.DefaultHelpCommand.width", "disnake.ext.commands.DefaultHelpCommand.sort_commands": "ext/commands/api/help_commands.html#disnake.ext.commands.DefaultHelpCommand.sort_commands", "disnake.ext.commands.DefaultHelpCommand.dm_help": "ext/commands/api/help_commands.html#disnake.ext.commands.DefaultHelpCommand.dm_help", "disnake.ext.commands.DefaultHelpCommand.dm_help_threshold": "ext/commands/api/help_commands.html#disnake.ext.commands.DefaultHelpCommand.dm_help_threshold", "disnake.ext.commands.DefaultHelpCommand.indent": "ext/commands/api/help_commands.html#disnake.ext.commands.DefaultHelpCommand.indent", "disnake.ext.commands.DefaultHelpCommand.commands_heading": "ext/commands/api/help_commands.html#disnake.ext.commands.DefaultHelpCommand.commands_heading", "disnake.ext.commands.DefaultHelpCommand.no_category": "ext/commands/api/help_commands.html#disnake.ext.commands.DefaultHelpCommand.no_category", "disnake.ext.commands.DefaultHelpCommand.paginator": "ext/commands/api/help_commands.html#disnake.ext.commands.DefaultHelpCommand.paginator", "disnake.ext.commands.DefaultHelpCommand.shorten_text": "ext/commands/api/help_commands.html#disnake.ext.commands.DefaultHelpCommand.shorten_text", "disnake.ext.commands.DefaultHelpCommand.get_ending_note": "ext/commands/api/help_commands.html#disnake.ext.commands.DefaultHelpCommand.get_ending_note", "disnake.ext.commands.DefaultHelpCommand.add_indented_commands": "ext/commands/api/help_commands.html#disnake.ext.commands.DefaultHelpCommand.add_indented_commands", "disnake.ext.commands.DefaultHelpCommand.send_pages": "ext/commands/api/help_commands.html#disnake.ext.commands.DefaultHelpCommand.send_pages", "disnake.ext.commands.DefaultHelpCommand.add_command_formatting": "ext/commands/api/help_commands.html#disnake.ext.commands.DefaultHelpCommand.add_command_formatting", "disnake.ext.commands.DefaultHelpCommand.get_destination": "ext/commands/api/help_commands.html#disnake.ext.commands.DefaultHelpCommand.get_destination", "disnake.ext.commands.MinimalHelpCommand": "ext/commands/api/help_commands.html#disnake.ext.commands.MinimalHelpCommand", "disnake.ext.commands.MinimalHelpCommand.sort_commands": "ext/commands/api/help_commands.html#disnake.ext.commands.MinimalHelpCommand.sort_commands", "disnake.ext.commands.MinimalHelpCommand.commands_heading": "ext/commands/api/help_commands.html#disnake.ext.commands.MinimalHelpCommand.commands_heading", "disnake.ext.commands.MinimalHelpCommand.aliases_heading": "ext/commands/api/help_commands.html#disnake.ext.commands.MinimalHelpCommand.aliases_heading", "disnake.ext.commands.MinimalHelpCommand.dm_help": "ext/commands/api/help_commands.html#disnake.ext.commands.MinimalHelpCommand.dm_help", "disnake.ext.commands.MinimalHelpCommand.dm_help_threshold": "ext/commands/api/help_commands.html#disnake.ext.commands.MinimalHelpCommand.dm_help_threshold", "disnake.ext.commands.MinimalHelpCommand.no_category": "ext/commands/api/help_commands.html#disnake.ext.commands.MinimalHelpCommand.no_category", "disnake.ext.commands.MinimalHelpCommand.paginator": "ext/commands/api/help_commands.html#disnake.ext.commands.MinimalHelpCommand.paginator", "disnake.ext.commands.MinimalHelpCommand.send_pages": "ext/commands/api/help_commands.html#disnake.ext.commands.MinimalHelpCommand.send_pages", "disnake.ext.commands.MinimalHelpCommand.get_opening_note": "ext/commands/api/help_commands.html#disnake.ext.commands.MinimalHelpCommand.get_opening_note", "disnake.ext.commands.MinimalHelpCommand.get_command_signature": "ext/commands/api/help_commands.html#disnake.ext.commands.MinimalHelpCommand.get_command_signature", "disnake.ext.commands.MinimalHelpCommand.get_ending_note": "ext/commands/api/help_commands.html#disnake.ext.commands.MinimalHelpCommand.get_ending_note", "disnake.ext.commands.MinimalHelpCommand.add_bot_commands_formatting": "ext/commands/api/help_commands.html#disnake.ext.commands.MinimalHelpCommand.add_bot_commands_formatting", "disnake.ext.commands.MinimalHelpCommand.add_subcommand_formatting": "ext/commands/api/help_commands.html#disnake.ext.commands.MinimalHelpCommand.add_subcommand_formatting", "disnake.ext.commands.MinimalHelpCommand.add_aliases_formatting": "ext/commands/api/help_commands.html#disnake.ext.commands.MinimalHelpCommand.add_aliases_formatting", "disnake.ext.commands.MinimalHelpCommand.add_command_formatting": "ext/commands/api/help_commands.html#disnake.ext.commands.MinimalHelpCommand.add_command_formatting", "disnake.ext.commands.MinimalHelpCommand.get_destination": "ext/commands/api/help_commands.html#disnake.ext.commands.MinimalHelpCommand.get_destination", "disnake.ext.commands.Cog": "ext/commands/api/misc.html#disnake.ext.commands.Cog", "disnake.ext.commands.Cog.get_commands": "ext/commands/api/misc.html#disnake.ext.commands.Cog.get_commands", "disnake.ext.commands.Cog.get_application_commands": "ext/commands/api/misc.html#disnake.ext.commands.Cog.get_application_commands", "disnake.ext.commands.Cog.get_slash_commands": "ext/commands/api/misc.html#disnake.ext.commands.Cog.get_slash_commands", "disnake.ext.commands.Cog.get_user_commands": "ext/commands/api/misc.html#disnake.ext.commands.Cog.get_user_commands", "disnake.ext.commands.Cog.get_message_commands": "ext/commands/api/misc.html#disnake.ext.commands.Cog.get_message_commands", "disnake.ext.commands.Cog.qualified_name": "ext/commands/api/misc.html#disnake.ext.commands.Cog.qualified_name", "disnake.ext.commands.Cog.description": "ext/commands/api/misc.html#disnake.ext.commands.Cog.description", "disnake.ext.commands.Cog.walk_commands": "ext/commands/api/misc.html#disnake.ext.commands.Cog.walk_commands", "disnake.ext.commands.Cog.get_listeners": "ext/commands/api/misc.html#disnake.ext.commands.Cog.get_listeners", "disnake.ext.commands.Cog.listener": "ext/commands/api/misc.html#disnake.ext.commands.Cog.listener", "disnake.ext.commands.Cog.has_error_handler": "ext/commands/api/misc.html#disnake.ext.commands.Cog.has_error_handler", "disnake.ext.commands.Cog.has_slash_error_handler": "ext/commands/api/misc.html#disnake.ext.commands.Cog.has_slash_error_handler", "disnake.ext.commands.Cog.has_user_error_handler": "ext/commands/api/misc.html#disnake.ext.commands.Cog.has_user_error_handler", "disnake.ext.commands.Cog.has_message_error_handler": "ext/commands/api/misc.html#disnake.ext.commands.Cog.has_message_error_handler", "disnake.ext.commands.Cog.cog_load": "ext/commands/api/misc.html#disnake.ext.commands.Cog.cog_load", "disnake.ext.commands.Cog.cog_unload": "ext/commands/api/misc.html#disnake.ext.commands.Cog.cog_unload", "disnake.ext.commands.Cog.bot_check_once": "ext/commands/api/misc.html#disnake.ext.commands.Cog.bot_check_once", "disnake.ext.commands.Cog.bot_check": "ext/commands/api/misc.html#disnake.ext.commands.Cog.bot_check", "disnake.ext.commands.Cog.bot_slash_command_check_once": "ext/commands/api/misc.html#disnake.ext.commands.Cog.bot_slash_command_check_once", "disnake.ext.commands.Cog.bot_slash_command_check": "ext/commands/api/misc.html#disnake.ext.commands.Cog.bot_slash_command_check", "disnake.ext.commands.Cog.bot_user_command_check_once": "ext/commands/api/misc.html#disnake.ext.commands.Cog.bot_user_command_check_once", "disnake.ext.commands.Cog.bot_user_command_check": "ext/commands/api/misc.html#disnake.ext.commands.Cog.bot_user_command_check", "disnake.ext.commands.Cog.bot_message_command_check_once": "ext/commands/api/misc.html#disnake.ext.commands.Cog.bot_message_command_check_once", "disnake.ext.commands.Cog.bot_message_command_check": "ext/commands/api/misc.html#disnake.ext.commands.Cog.bot_message_command_check", "disnake.ext.commands.Cog.cog_check": "ext/commands/api/misc.html#disnake.ext.commands.Cog.cog_check", "disnake.ext.commands.Cog.cog_slash_command_check": "ext/commands/api/misc.html#disnake.ext.commands.Cog.cog_slash_command_check", "disnake.ext.commands.Cog.cog_user_command_check": "ext/commands/api/misc.html#disnake.ext.commands.Cog.cog_user_command_check", "disnake.ext.commands.Cog.cog_message_command_check": "ext/commands/api/misc.html#disnake.ext.commands.Cog.cog_message_command_check", "disnake.ext.commands.Cog.cog_command_error": "ext/commands/api/misc.html#disnake.ext.commands.Cog.cog_command_error", "disnake.ext.commands.Cog.cog_slash_command_error": "ext/commands/api/misc.html#disnake.ext.commands.Cog.cog_slash_command_error", "disnake.ext.commands.Cog.cog_user_command_error": "ext/commands/api/misc.html#disnake.ext.commands.Cog.cog_user_command_error", "disnake.ext.commands.Cog.cog_message_command_error": "ext/commands/api/misc.html#disnake.ext.commands.Cog.cog_message_command_error", "disnake.ext.commands.Cog.cog_before_invoke": "ext/commands/api/misc.html#disnake.ext.commands.Cog.cog_before_invoke", "disnake.ext.commands.Cog.cog_after_invoke": "ext/commands/api/misc.html#disnake.ext.commands.Cog.cog_after_invoke", "disnake.ext.commands.Cog.cog_before_slash_command_invoke": "ext/commands/api/misc.html#disnake.ext.commands.Cog.cog_before_slash_command_invoke", "disnake.ext.commands.Cog.cog_after_slash_command_invoke": "ext/commands/api/misc.html#disnake.ext.commands.Cog.cog_after_slash_command_invoke", "disnake.ext.commands.Cog.cog_before_user_command_invoke": "ext/commands/api/misc.html#disnake.ext.commands.Cog.cog_before_user_command_invoke", "disnake.ext.commands.Cog.cog_after_user_command_invoke": "ext/commands/api/misc.html#disnake.ext.commands.Cog.cog_after_user_command_invoke", "disnake.ext.commands.Cog.cog_before_message_command_invoke": "ext/commands/api/misc.html#disnake.ext.commands.Cog.cog_before_message_command_invoke", "disnake.ext.commands.Cog.cog_after_message_command_invoke": "ext/commands/api/misc.html#disnake.ext.commands.Cog.cog_after_message_command_invoke", "disnake.ext.commands.CogMeta": "ext/commands/api/misc.html#disnake.ext.commands.CogMeta", "disnake.ext.commands.CogMeta.name": "ext/commands/api/misc.html#disnake.ext.commands.CogMeta.name", "disnake.ext.commands.CogMeta.description": "ext/commands/api/misc.html#disnake.ext.commands.CogMeta.description", "disnake.ext.commands.CogMeta.command_attrs": "ext/commands/api/misc.html#disnake.ext.commands.CogMeta.command_attrs", "disnake.ext.commands.CogMeta.slash_command_attrs": "ext/commands/api/misc.html#disnake.ext.commands.CogMeta.slash_command_attrs", "disnake.ext.commands.CogMeta.user_command_attrs": "ext/commands/api/misc.html#disnake.ext.commands.CogMeta.user_command_attrs", "disnake.ext.commands.CogMeta.message_command_attrs": "ext/commands/api/misc.html#disnake.ext.commands.CogMeta.message_command_attrs", "disnake.ext.commands.Paginator": "ext/commands/api/misc.html#disnake.ext.commands.Paginator", "disnake.ext.commands.Paginator.prefix": "ext/commands/api/misc.html#disnake.ext.commands.Paginator.prefix", "disnake.ext.commands.Paginator.suffix": "ext/commands/api/misc.html#disnake.ext.commands.Paginator.suffix", "disnake.ext.commands.Paginator.max_size": "ext/commands/api/misc.html#disnake.ext.commands.Paginator.max_size", "disnake.ext.commands.Paginator.linesep": "ext/commands/api/misc.html#disnake.ext.commands.Paginator.linesep", "disnake.ext.commands.Paginator.clear": "ext/commands/api/misc.html#disnake.ext.commands.Paginator.clear", "disnake.ext.commands.Paginator.add_line": "ext/commands/api/misc.html#disnake.ext.commands.Paginator.add_line", "disnake.ext.commands.Paginator.close_page": "ext/commands/api/misc.html#disnake.ext.commands.Paginator.close_page", "disnake.ext.commands.Paginator.pages": "ext/commands/api/misc.html#disnake.ext.commands.Paginator.pages", "disnake.ext.commands.Command": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command", "disnake.ext.commands.Command.name": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.name", "disnake.ext.commands.Command.callback": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.callback", "disnake.ext.commands.Command.help": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.help", "disnake.ext.commands.Command.brief": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.brief", "disnake.ext.commands.Command.usage": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.usage", "disnake.ext.commands.Command.aliases": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.aliases", "disnake.ext.commands.Command.enabled": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.enabled", "disnake.ext.commands.Command.parent": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.parent", "disnake.ext.commands.Command.cog": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.cog", "disnake.ext.commands.Command.checks": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.checks", "disnake.ext.commands.Command.description": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.description", "disnake.ext.commands.Command.hidden": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.hidden", "disnake.ext.commands.Command.rest_is_raw": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.rest_is_raw", "disnake.ext.commands.Command.invoked_subcommand": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.invoked_subcommand", "disnake.ext.commands.Command.require_var_positional": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.require_var_positional", "disnake.ext.commands.Command.ignore_extra": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.ignore_extra", "disnake.ext.commands.Command.cooldown_after_parsing": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.cooldown_after_parsing", "disnake.ext.commands.Command.extras": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.extras", "disnake.ext.commands.Command.after_invoke": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.after_invoke", "disnake.ext.commands.Command.before_invoke": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.before_invoke", "disnake.ext.commands.Command.error": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.error", "disnake.ext.commands.Command.add_check": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.add_check", "disnake.ext.commands.Command.remove_check": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.remove_check", "disnake.ext.commands.Command.update": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.update", "disnake.ext.commands.Command.__call__": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.__call__", "disnake.ext.commands.Command.copy": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.copy", "disnake.ext.commands.Command.clean_params": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.clean_params", "disnake.ext.commands.Command.full_parent_name": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.full_parent_name", "disnake.ext.commands.Command.parents": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.parents", "disnake.ext.commands.Command.root_parent": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.root_parent", "disnake.ext.commands.Command.qualified_name": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.qualified_name", "disnake.ext.commands.Command.is_on_cooldown": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.is_on_cooldown", "disnake.ext.commands.Command.reset_cooldown": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.reset_cooldown", "disnake.ext.commands.Command.get_cooldown_retry_after": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.get_cooldown_retry_after", "disnake.ext.commands.Command.has_error_handler": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.has_error_handler", "disnake.ext.commands.Command.cog_name": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.cog_name", "disnake.ext.commands.Command.short_doc": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.short_doc", "disnake.ext.commands.Command.signature": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.signature", "disnake.ext.commands.Command.can_run": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Command.can_run", "disnake.ext.commands.Group": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group", "disnake.ext.commands.Group.invoke_without_command": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.invoke_without_command", "disnake.ext.commands.Group.case_insensitive": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.case_insensitive", "disnake.ext.commands.Group.after_invoke": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.after_invoke", "disnake.ext.commands.Group.before_invoke": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.before_invoke", "disnake.ext.commands.Group.command": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.command", "disnake.ext.commands.Group.error": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.error", "disnake.ext.commands.Group.group": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.group", "disnake.ext.commands.Group.copy": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.copy", "disnake.ext.commands.Group.add_check": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.add_check", "disnake.ext.commands.Group.add_command": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.add_command", "disnake.ext.commands.Group.can_run": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.can_run", "disnake.ext.commands.Group.clean_params": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.clean_params", "disnake.ext.commands.Group.cog_name": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.cog_name", "disnake.ext.commands.Group.commands": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.commands", "disnake.ext.commands.Group.full_parent_name": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.full_parent_name", "disnake.ext.commands.Group.get_command": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.get_command", "disnake.ext.commands.Group.get_cooldown_retry_after": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.get_cooldown_retry_after", "disnake.ext.commands.Group.has_error_handler": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.has_error_handler", "disnake.ext.commands.Group.is_on_cooldown": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.is_on_cooldown", "disnake.ext.commands.Group.parents": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.parents", "disnake.ext.commands.Group.qualified_name": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.qualified_name", "disnake.ext.commands.Group.remove_check": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.remove_check", "disnake.ext.commands.Group.remove_command": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.remove_command", "disnake.ext.commands.Group.reset_cooldown": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.reset_cooldown", "disnake.ext.commands.Group.root_parent": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.root_parent", "disnake.ext.commands.Group.short_doc": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.short_doc", "disnake.ext.commands.Group.signature": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.signature", "disnake.ext.commands.Group.update": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.update", "disnake.ext.commands.Group.walk_commands": "ext/commands/api/prefix_commands.html#disnake.ext.commands.Group.walk_commands", "disnake.ext.commands.GroupMixin": "ext/commands/api/prefix_commands.html#disnake.ext.commands.GroupMixin", "disnake.ext.commands.GroupMixin.all_commands": "ext/commands/api/prefix_commands.html#disnake.ext.commands.GroupMixin.all_commands", "disnake.ext.commands.GroupMixin.case_insensitive": "ext/commands/api/prefix_commands.html#disnake.ext.commands.GroupMixin.case_insensitive", "disnake.ext.commands.GroupMixin.command": "ext/commands/api/prefix_commands.html#disnake.ext.commands.GroupMixin.command", "disnake.ext.commands.GroupMixin.group": "ext/commands/api/prefix_commands.html#disnake.ext.commands.GroupMixin.group", "disnake.ext.commands.GroupMixin.commands": "ext/commands/api/prefix_commands.html#disnake.ext.commands.GroupMixin.commands", "disnake.ext.commands.GroupMixin.add_command": "ext/commands/api/prefix_commands.html#disnake.ext.commands.GroupMixin.add_command", "disnake.ext.commands.GroupMixin.remove_command": "ext/commands/api/prefix_commands.html#disnake.ext.commands.GroupMixin.remove_command", "disnake.ext.commands.GroupMixin.walk_commands": "ext/commands/api/prefix_commands.html#disnake.ext.commands.GroupMixin.walk_commands", "disnake.ext.commands.GroupMixin.get_command": "ext/commands/api/prefix_commands.html#disnake.ext.commands.GroupMixin.get_command", "disnake.ext.commands.command": "ext/commands/api/prefix_commands.html#disnake.ext.commands.command", "disnake.ext.commands.group": "ext/commands/api/prefix_commands.html#disnake.ext.commands.group", "disnake.ext.commands.when_mentioned": "ext/commands/api/prefix_commands.html#disnake.ext.commands.when_mentioned", "disnake.ext.commands.when_mentioned_or": "ext/commands/api/prefix_commands.html#disnake.ext.commands.when_mentioned_or", "disnake.ext.tasks.Loop": "ext/tasks/index.html#disnake.ext.tasks.Loop", "disnake.ext.tasks.Loop.after_loop": "ext/tasks/index.html#disnake.ext.tasks.Loop.after_loop", "disnake.ext.tasks.Loop.before_loop": "ext/tasks/index.html#disnake.ext.tasks.Loop.before_loop", "disnake.ext.tasks.Loop.error": "ext/tasks/index.html#disnake.ext.tasks.Loop.error", "disnake.ext.tasks.Loop.seconds": "ext/tasks/index.html#disnake.ext.tasks.Loop.seconds", "disnake.ext.tasks.Loop.minutes": "ext/tasks/index.html#disnake.ext.tasks.Loop.minutes", "disnake.ext.tasks.Loop.hours": "ext/tasks/index.html#disnake.ext.tasks.Loop.hours", "disnake.ext.tasks.Loop.time": "ext/tasks/index.html#disnake.ext.tasks.Loop.time", "disnake.ext.tasks.Loop.current_loop": "ext/tasks/index.html#disnake.ext.tasks.Loop.current_loop", "disnake.ext.tasks.Loop.next_iteration": "ext/tasks/index.html#disnake.ext.tasks.Loop.next_iteration", "disnake.ext.tasks.Loop.__call__": "ext/tasks/index.html#disnake.ext.tasks.Loop.__call__", "disnake.ext.tasks.Loop.start": "ext/tasks/index.html#disnake.ext.tasks.Loop.start", "disnake.ext.tasks.Loop.stop": "ext/tasks/index.html#disnake.ext.tasks.Loop.stop", "disnake.ext.tasks.Loop.cancel": "ext/tasks/index.html#disnake.ext.tasks.Loop.cancel", "disnake.ext.tasks.Loop.restart": "ext/tasks/index.html#disnake.ext.tasks.Loop.restart", "disnake.ext.tasks.Loop.add_exception_type": "ext/tasks/index.html#disnake.ext.tasks.Loop.add_exception_type", "disnake.ext.tasks.Loop.clear_exception_types": "ext/tasks/index.html#disnake.ext.tasks.Loop.clear_exception_types", "disnake.ext.tasks.Loop.remove_exception_type": "ext/tasks/index.html#disnake.ext.tasks.Loop.remove_exception_type", "disnake.ext.tasks.Loop.get_task": "ext/tasks/index.html#disnake.ext.tasks.Loop.get_task", "disnake.ext.tasks.Loop.is_being_cancelled": "ext/tasks/index.html#disnake.ext.tasks.Loop.is_being_cancelled", "disnake.ext.tasks.Loop.failed": "ext/tasks/index.html#disnake.ext.tasks.Loop.failed", "disnake.ext.tasks.Loop.is_running": "ext/tasks/index.html#disnake.ext.tasks.Loop.is_running", "disnake.ext.tasks.Loop.change_interval": "ext/tasks/index.html#disnake.ext.tasks.Loop.change_interval", "disnake.ext.tasks.loop": "ext/tasks/index.html#disnake.ext.tasks.loop"};